@@ -35,6 +35,7 @@ import setuptools # avoid UserWarning "Distutils was imported before Setuptools"
 
 import sys
 import os
+import logging
 from os.path import join, dirname
 
 from .setup_info import SETUP_INFO
@@ -45,6 +46,10 @@ srcref_url = 'https://gitlab.com/lino-framework/lino/blob/master/%s'
 # srcref_url = 'https://github.com/lino-framework/lino/tree/master/%s'
 # doc_trees = ['docs']
 
+# The Lino logger is meant to be used by most Lino code
+logger = logging.getLogger('lino')
+
+
 if sys.version_info[0] > 2:
     PYAFTER26 = True
 elif sys.version_info[0] == 2 and sys.version_info[1] > 6:
@@ -57,6 +62,13 @@ warnings.filterwarnings(
     "error", "DateTimeField .* received a naive datetime (.*) while time zone support is active.",
     RuntimeWarning, "django.db.models.fields")
 
+warnings.filterwarnings(
+    "ignore", "Accessing the database during app initialization is discouraged\. To fix this warning, avoid executing queries in AppConfig\.ready\(\) or when your app modules are imported\.",
+    RuntimeWarning, "django.db.backends.utils")
+
+# from django.utils.deprecation import RemovedInDjango50Warning
+# warnings.filterwarnings("error", "", RemovedInDjango50Warning)
+
 # doesn't work here because that's too late:
 # warnings.filterwarnings(
 #     "ignore", "Distutils was imported before Setuptools. This usage is discouraged and may exhibit undesirable behaviors or errors. Please use Setuptools' objects directly or at least import Setuptools first.",
@@ -128,10 +140,10 @@ def startup(settings_module=None):
     if settings_module:
         os.environ['DJANGO_SETTINGS_MODULE'] = settings_module
 
-    # print("20221102 startup() 1")
+    # print("20231019 startup() 1")
     import django
     django.setup()
-    # print("20221102 startup() 2")
+    # print("20231019 startup() 2")
 
 
 class AppConfig(AppConfig):
