@@ -1,14 +1,16 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2022 Rumma & Ko Ltd
+# Copyright 2011-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
+
+# import logging ; logger = logging.getLogger(__name__)
 
 # logger.info("20140227 dd.py a")
 
 import time
-from asgiref.sync import sync_to_async
+# from asgiref.sync import sync_to_async
 
 from django.conf import settings
 from django.db.models import *
@@ -27,6 +29,7 @@ from lino.core.utils import inrange_filter
 from lino.core.utils import full_model_name
 
 from lino.core.model import Model
+
 "Shortcut to :class:`lino.core.model.Model`."
 
 from lino.core.merge import MergeAction
@@ -54,7 +57,6 @@ from lino.core.actions import SubmitDetail, SubmitInsert
 from lino.core.choicelists import ChoiceList, Choice
 from lino.core.workflows import State, Workflow, ChangeStateAction
 
-
 from lino.core.fields import fields_list, ImportedFields
 from lino.core.fields import Dummy, DummyField
 from lino.core.fields import TimeField
@@ -72,7 +74,7 @@ from lino.core.fields import DatePickerField
 from lino.core.fields import PasswordField
 from lino.core.fields import MonthField
 from lino.core.fields import PercentageField
-#~ from lino.core.fields import LinkedForeignKey
+# ~ from lino.core.fields import LinkedForeignKey
 from lino.core.fields import QuantityField
 from lino.core.fields import DurationField
 from lino.core.fields import HtmlBox, PriceField, RichTextField
@@ -99,7 +101,6 @@ from lino.core.layouts import DetailLayout, InsertLayout, Panel
 from lino.core.layouts import ParamsLayout, ActionParamsLayout
 from lino.core.layouts import DummyPanel
 
-
 from lino.core.signals import on_ui_created, pre_ui_delete, on_ui_updated
 
 # from lino.core.signals import database_connected
@@ -121,7 +122,7 @@ from django.db.models.signals import class_prepared
 from django.db.backends.signals import connection_created
 
 from django.dispatch import receiver
-#~ from lino.core import signals
+# ~ from lino.core import signals
 
 
 from django.db.models.fields import NOT_PROVIDED
@@ -135,10 +136,11 @@ from lino.core.inject import do_when_prepared, when_prepared
 
 from lino.core.utils import ParameterPanel, PseudoRequest
 
-from lino.utils import IncompleteDate
+from lino.utils import IncompleteDate, read_exception
 
 from lino.utils.format_date import fdm, fdl, fdf, fdmy
 from lino.utils.format_date import fds as fds_
+from lino.utils.format_date import ftl
 
 
 def fds(d):
@@ -146,12 +148,14 @@ def fds(d):
         return fds_(d.as_date())
     return fds_(d)
 
+
 # backward compatibility
 dtos = fds
 from lino.utils.format_date import fdl as dtosl
 
 babelitem = settings.SITE.babelitem
 field2kw = settings.SITE.field2kw
+# urlkwargs = settings.SITE.urlkwargs
 
 from lino.utils.mldbc.fields import BabelTextField
 from lino.utils.mldbc.fields import BabelCharField, LanguageField
@@ -162,11 +166,14 @@ from importlib import import_module
 
 decfmt = settings.SITE.decfmt
 str2kw = settings.SITE.str2kw
+str2dict = settings.SITE.str2dict
 
 
 def today(*args, **kwargs):
     # make it serializable for Django migrations
     return settings.SITE.today(*args, **kwargs)
+
+
 # today = settings.SITE.today
 strftime = settings.SITE.strftime
 demo_date = settings.SITE.demo_date
@@ -186,53 +193,42 @@ babelattr = settings.SITE.babelattr
 plugins = settings.SITE.plugins
 format_currency = settings.SITE.format_currency
 
-
 from django.utils import translation
+
 get_language = translation.get_language
 
 from lino.core.roles import SiteStaff, SiteUser, SiteAdmin, login_required
 
-# logger.info("20140227 dd.py b %s", site)
-
-try:
-    import schedule
-except ImportError as e:
-    # logger.info("schedule not installed (%s)", e)
-    schedule = None
-
-def job_schedule(fn):
-    class e_catcher:
-
-        def __call__(self, *args, **kwargs):
-            try:
-                fn(*args, **kwargs)
-            except Exception as e:
-                logging.getLogger('linod').exception(e)
-                from channels.layers import get_channel_layer
-                from asgiref.sync import async_to_sync
-                from lino.modlib.linod.utils import LINOD
-                async_to_sync(get_channel_layer().send)(LINOD, {'type': 'deferred.job', 'name': fn.__name__})
-                return schedule.CancelJob
-
-        def __repr__(self):
-            return fn.__name__
-
-        def __str__(self):
-            return fn.__name__
-
-    return e_catcher()
 
 def schedule_often(every=10):
     def decorator(func):
-        if settings.SITE.use_linod:
-            schedule.every(every).seconds.do(job_schedule(func))
-        return func
+        if True:  # settings.SITE.use_linod:
+            from lino.modlib.linod.choicelists import Procedures
+            Procedures.add_item(func, every_unit='secondly', every=every)
+            # Procedures.add_item(func.__name__, func.__name__, func.__name__,
+            #     every_unit='secondly', every_value=every, func=func)
+
     return decorator
 
 
-def schedule_daily(at="20:00"):
+def schedule_daily():
     def decorator(func):
-        if settings.SITE.use_linod:
-            schedule.every().day.at(at).do(job_schedule(func))
+        if True:  # settings.SITE.use_linod:
+            from lino.modlib.linod.choicelists import Procedures
+            Procedures.add_item(func, every_unit='daily', every=1)
+            # Procedures.add_item(func.__name__, func.__name__, func.__name__,
+            #     every_unit='daily', every_value=1, func=func)
         return func
+
+    return decorator
+
+def background_task(**kwargs):
+    def decorator(func):
+        if True:  # settings.SITE.use_linod:
+            from lino.modlib.linod.choicelists import Procedures
+            Procedures.add_item(func, **kwargs)
+            # Procedures.add_item(func.__name__, func.__name__, func.__name__,
+            #     func=func, **kwargs)
+        return func
+
     return decorator
