@@ -7,7 +7,7 @@ A selection of names to be used in tested documents.
 """
 
 import six  # TODO: remove here and then run all doctests
-
+import logging
 import django
 django.setup()
 from lino.api.shell import *
@@ -18,6 +18,7 @@ from django.db import connection, reset_queries as reset_sql_queries
 import json
 from bs4 import BeautifulSoup
 import textwrap
+from pprint import pprint, pformat
 
 from rstgen import table, ul
 import rstgen
@@ -32,13 +33,12 @@ from lino.utils import diag
 from lino.utils.sql import sql_summary
 from lino.core import actors, kernel
 from lino.core.menus import find_menu_item
+from lino import logger
 from lino.sphinxcontrib.actordoc import menuselection_text
-from pprint import pprint, pformat
 from lino.utils.diag import visible_for
 from lino.core.utils import full_model_name
 # from lino.core.utils import PseudoRequest
-from lino.core.site import html2text
-
+from lino.utils import html2text
 from lino.core.menus import Menu
 from lino.core.actions import ShowTable
 from lino.core.actions import register_params
@@ -72,6 +72,21 @@ def get_json_soup(username, uri, fieldname, **kwargs):
     """
     d = get_json_dict(username, uri, **kwargs)
     html = d['data'][fieldname]
+    return beautiful_soup(html)
+
+
+def beautiful_soup(html):
+    """Parse the given HTML into a BeautifulSoup object.
+
+    This supports URIs that return a `delayed_value`.
+    """
+    if isinstance(html, dict):
+        uri = "/" + html['delayed_value_url']
+        res = test_client.get(uri)
+        assert res.status_code == 200
+        d = json.loads(res.content.decode())
+        html = d['data']
+        # raise Exception("20230710 {}".format(html))
     return BeautifulSoup(html, 'lxml')
 
 
@@ -170,7 +185,7 @@ def show_menu_path(spec, language=None):
     Print the menu path of the given actor or action.
 
     Deprecated.  You should rather use
-    :meth:`lino.core.requests.BaseRequest.show_menu_path` which
+    :meth:`lino.core.requests.BaseRequest.show_menu_path`, which
     automatically sets the language of the user and works for any user
     type.
     """
@@ -203,7 +218,11 @@ def noblanklines(s):
 
 
 def show_choices(username, url, show_count=False):
-    """Print the choices returned via web client."""
+    """Print the choices returned via web client.
+
+    If `show_count` is `True`, show only the number of choices.
+
+    """
     test_client.force_login(rt.login(username).user)
     response = test_client.get(url, REMOTE_USER=username)
     if response.status_code != 200:
@@ -215,10 +234,10 @@ def show_choices(username, url, show_count=False):
     for r in result['rows']:
         print(r['text'])
         # print(r['value'], r['text'])
-
     if show_count:
         print("{} rows".format(result['count']))
 
+
 from django.db.models import Model
 from lino.core.actions import Action
 from lino.core.tables import AbstractTable
@@ -305,7 +324,7 @@ def fields_help(model, fieldnames=None, columns=False, all=None):
         all = fieldnames is not None
 
     cells = []
-    cols = ["Internal name", "Verbose name", "Help text"]
+    # cols = ["Internal name", "Verbose name", "Help text"]
     for fld in get_fields(model, fieldnames, columns):
         if fld is not None and hasattr(fld, 'verbose_name'):
             ht = fld.help_text or ''
@@ -373,12 +392,11 @@ def walk_menu_items(username=None, severe=True):
         items = []
         for mi in mnu.walk_items():
           if mi.bound_action:
-            if isinstance(mi.bound_action.action, ShowTable):
+            item = menuselection_text(mi) + " : "
+            if isinstance(mi.bound_action.action, ShowTable) and not mi.params:
                 mt = mi.bound_action.actor
                 url = 'api/{}/{}'.format(mt.app_label, mt.__name__)
                 url = str(settings.SITE.buildurl(url, fmt='json'))
-
-                item = menuselection_text(mi) + " : "
                 try:
                     response = test_client.get(url, REMOTE_USER=str(username))
                     result = check_json_result(
@@ -390,7 +408,9 @@ def walk_menu_items(username=None, severe=True):
                         raise
                     else:
                         item += str(e)
-                items.append(item)
+            else:
+                item += "(not tested)"
+            items.append(item)
 
         s = rstgen.ul(items)
         print(s)
@@ -561,8 +581,6 @@ def show_dashboard(username, **options):
     :mod:`django.contrib.humanize.templatetags.humanize`) ignores demo_date and
     therefore produces results that depend on the current date/time.
 
-
-
     """
     # request = PseudoRequest(username)
     rnd = settings.SITE.kernel.text_renderer
@@ -648,3 +666,7 @@ def walk_store_fields(only_detail_fields=False):
 
 
 # settings.SITE.kernel.check_virgin()
+def set_log_level(level):
+    logger.setLevel(level)
+    for handler in logger.handlers:
+        handler.setLevel(level)
