@@ -37,9 +37,9 @@ def show(*args, **kw):
     return login().show(*args, **kw)
 
 
-def send_email(*args, **kw):
-    "Shortcut to :meth:`lino.core.site.Site.send_email`."
-    return settings.SITE.send_email(*args, **kw)
+# def send_email(*args, **kw):
+#     "Shortcut to :meth:`lino.core.site.Site.send_email`."
+#     return settings.SITE.send_email(*args, **kw)
 
 
 def html_text(*args, **kw):
