@@ -273,7 +273,7 @@ class Tour(object):
         """
 
         if driver is None:
-            op = webdriver.FirefoxOptions();
+            op = webdriver.FirefoxOptions()
             op.headless = headless
             driver = webdriver.Firefox(options=op)
             # driver.set_page_load_timeout(10)
