@@ -7,7 +7,7 @@ decorator, and some of the standard actions.  See :ref:`dev.actions`.
 
 """
 
-import logging; logger = logging.getLogger(__name__)
+from lino import logger
 
 from django.utils.translation import gettext_lazy as _
 from django.utils.translation import gettext
@@ -254,12 +254,6 @@ class Action(Parametrizable, Permittable):
     """
     help_text = None
 
-    submit_form_data = False
-    """
-    Should the running of the action include all known form values in
-    the request.
-    """
-
     auto_save = True
     """
     What to do when this action is being called while the user is on a
@@ -492,8 +486,7 @@ class Action(Parametrizable, Permittable):
         """
         if instance is None:
             return self
-        return InstanceAction(
-            self, instance.get_default_table(), instance, owner)
+        return InstanceAction(self, None, instance, owner)
 
     # def get_a_href_target(self):
     #     return None
@@ -515,7 +508,7 @@ class Action(Parametrizable, Permittable):
     @classmethod
     def decorate(cls, *args, **kw):
         """
-        Return a decorator which turns an instance method on a model or a
+        Return a decorator that turns an instance method on a model or a
         class method on an actor into an action of this class.
 
         The decorated method will be installed as the actions's
@@ -607,6 +600,8 @@ class Action(Parametrizable, Permittable):
         return self.label or self.action_name
 
     def get_button_label(self, actor):
+        if self.button_text is not None:
+            return self.button_text
         if actor is None or actor.default_action is None:
             return self.label
         if self is actor.default_action.action:
@@ -614,7 +609,6 @@ class Action(Parametrizable, Permittable):
             # return actor.get_actor_label()  # 20200307
         else:
             return self.button_text or self.label
-            # since 20140923 return u"%s %s" % (self.label, actor.label)
 
     def full_name(self, actor):
         if self.action_name is None:
@@ -645,17 +639,6 @@ class Action(Parametrizable, Permittable):
         # return str(self.get_label())
         return str(self.get_label())
 
-    def unused__str__(self):
-        raise Exception("20121003 Must use full_name(actor)")
-        if self.defining_actor is None:
-            return repr(self)
-        if self.action_name is None:
-            return repr(self)
-        return str(self.defining_actor) + ':' + self.action_name
-
-    # ~ def set_permissions(self,*args,**kw)
-    # ~ self.permission = perms.factory(*args,**kw)
-
     def attach_to_workflow(self, wf, name):
         if self.action_name is not None:
             assert self.action_name == name
@@ -721,9 +704,8 @@ class Action(Parametrizable, Permittable):
 
     def run_from_ui(self, ar, **kwargs):
         """
-        Execute the action.  `ar` is an :class:`ActionRequest
-        <lino.core.requests.BaseRequest>` object representing the
-        context in which the action is running.
+        Execute the action.  `ar` is a :class:`BaseRequest
+        <lino.core.requests.BaseRequest>` object.
         """
         raise NotImplementedError(
             "%s has no run_from_ui() method" % self.__class__)
@@ -948,7 +930,9 @@ class ShowInsert(TableAction):
             return kw
         if 'data_record' in kw:
             return kw
-        # raise Exception("20150218 %s" % self)
+        if ar.ah.store is None:  # can happen when async
+            return kw
+        # raise Exception("20150218 %s" % ar.get_user())
         elem = self.create_instance(ar)
         rec = ar.elem2rec_insert(ar.ah, elem)
         kw.update(data_record=rec)
@@ -1025,7 +1009,6 @@ class SubmitDetail(SaveGridCell):
     help_text = _("Save changes in this form")
     label = _("Save")
     action_name = ShowDetail.save_action_name
-    submit_form_data = True
     callable_from = 'd'
 
     def run_from_ui(self, ar, **kw):
@@ -1033,12 +1016,15 @@ class SubmitDetail(SaveGridCell):
         for elem in ar.selected_rows:
             # logger.info("20210213b SubmitDetail %s", elem)
             elem.save_existing_instance(ar)
-            if not settings.SITE.is_installed("react"):
+            if ar.renderer.front_end.app_label != "react":
                 # No point in clos
                 if ar.actor.stay_in_grid:
                     ar.close_window()
                 else:
                     ar.goto_instance(elem)
+            else:
+                if len(ar.selected_rows) == 1:
+                    ar.set_response(data_record=ar.elem2rec_detailed(elem))
 
 
 class CreateRow(Action):
@@ -1053,12 +1039,12 @@ class CreateRow(Action):
     http_method = "POST"
 
     # select_rows = False
-    # submit_form_data = True
     def run_from_ui(self, ar, **kwargs):
         elem = ar.create_instance_from_request(**kwargs)
         self.save_new_instance(ar, elem)
 
     def save_new_instance(self, ar, elem):
+        elem.full_clean()
         elem.save_new_instance(ar)
         ar.success(_("%s has been created.") % obj2unicode(elem))
 
@@ -1090,8 +1076,8 @@ class CreateRow(Action):
 
         # print(19062017, "Ticket 1910")
         if ar.actor.handle_uploaded_files is None:
-            ar.set_response(rows=[ar.ah.store.row2list(ar, elem[0])])
-            ar.set_response(navinfo=navinfo(ar.data_iterator, elem[0]))
+            ar.set_response(rows=[ar.ah.store.row2list(ar, elems[0])])
+            ar.set_response(navinfo=navinfo(ar.data_iterator, elems[0]))
         else:
             # Must set text/html for file uploads, otherwise the
             # browser adds a <PRE></PRE> tag around the AJAX response.
@@ -1102,7 +1088,7 @@ class CreateRow(Action):
             # do not open a detail window on the new instance
             return
 
-        ar.goto_instance(elem[0])
+        ar.goto_instance(elems[0])
 
         # No need to ask refresh_all since closing the window will
         # automatically refresh the underlying window.
@@ -1232,6 +1218,7 @@ class WrappedAction(Action):
             if k not in kwargs:
                 kwargs[k] = getattr(bound_action.action, k)
         super().__init__(**kwargs)
+        # print("20230501 WrappedAction()", kwargs)
 
     def get_required_roles(self, actor):
         # print(self.bound_action, actor.required_roles | self.bound_action.required)
@@ -1266,14 +1253,14 @@ class MultipleRowAction(Action):
         n = 0
         for obj in ar.selected_rows:
             if not ar.response.get('success'):
-                ar.info("Aborting remaining rows")
+                ar.debug("Aborting remaining rows")
                 break
-            ar.info("%s for %s...", str(self.label), str(obj))
+            ar.debug("Run %s for %s...", self.label, obj)
             n += self.run_on_row(obj, ar)
             ar.set_response(refresh_all=True)
 
         msg = _("%d row(s) have been updated.") % n
-        ar.info(msg)
+        ar.debug(msg)
         # ~ ar.success(msg,**kw)
 
 
