@@ -9,7 +9,7 @@ See :doc:`/dev/actors`.
 
 """
 
-import logging; logger = logging.getLogger(__name__)
+from lino import logger
 
 import copy
 import traceback
@@ -20,8 +20,10 @@ from inspect import getmro
 from django.db import models
 from django.conf import settings
 from django.utils.translation import gettext_lazy as _
+from django.core.exceptions import BadRequest
 
 from lino.utils import isiterable
+from lino.utils import MissingRow
 from lino.core import fields
 from lino.core import actions
 from lino.core import layouts
@@ -95,9 +97,10 @@ def register_actor(a):
     if not a.abstract:
         # if not settings.SITE.is_installed(a.app_label):
         p = settings.SITE.plugins.get(a.app_label, None)
-        if p is None or not p.is_active():
+        if p is None or p.is_hidden():
             # avoid registering choicelists of non-installed plugins
             # logger.info("20190107 skip register_actor for %s", a)
+            a.abstract = True
             return
     old = actors_dict.define(a.app_label, a.__name__, a)
     if old is not None:
@@ -212,8 +215,8 @@ class ActorMetaClass(type):
 # class Actor(metaclass=ActorMetaClass, type('NewBase', (actions.Parametrizable, Permittable), {}))):
 class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
     """
-    The base class for all actors.  Subclassed by :class:`AbstractTable
-    <lino.core.tables.AbstractTable>`, :class:`Table
+    The base class for all actors (:term:`data view`).  Subclassed by
+    :class:`AbstractTable <lino.core.tables.AbstractTable>`, :class:`Table
     <lino.core.dbtables.Table>`, :class:`ChoiceList
     <lino.core.choicelists.ChoiceList>` and :class:`Frame
     <lino.core.frames.Frame>`.
@@ -247,7 +250,7 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
     .. classmethod:: get_welcome_messages(self, ar)
 
         If a method of this name is defined on an actor, then it must
-        be a class method which takes an :class:`ar
+        be a class method that takes an :class:`ar
         <lino.core.requests.BaseRequest>` as single argument and
         returns or yields a list of :term:`welcome messages <welcome
         message>` (messages to be displayed in the welcome block of
@@ -473,6 +476,10 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
     def is_installed(self):
         return settings.SITE.is_installed(self.app_label)
 
+    @classmethod
+    def is_hidden(self):
+        return settings.SITE.is_hidden_plugin(self.app_label)
+
     @classmethod
     def get_widget_options(cls, name, **options):
         if cls.model is None:
@@ -520,14 +527,19 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
         which case `model` is the *requested* master).
 
         """
+        if not pk:
+            return None
         if issubclass(model, models.Model):
             try:
                 return model.get_user_queryset(ar.get_user()).get(pk=pk)
                 # why not simply return model.objects.get(pk=pk) ?
-            except ValueError:
-                return None
-            except model.DoesNotExist:
-                return None
+            except Exception as e:
+                # raise BadRequest(str(e))
+                return MissingRow("{} (pk={})".format(e, pk))
+            # except ValueError:
+            #     return None
+            # except model.DoesNotExist as e:
+            #     return None
         msg = "{0} must override get_master_instance"
         msg = msg.format(self)
         raise Exception(msg)
@@ -566,71 +578,6 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
             s |= cls._state_to_disabled_actions.get(state.name, set())
         return s
 
-    @classmethod
-    def get_request_handle(self, ar):
-        """
-        Return the dynamic (per-request) handle for this actor for the
-        renderer used by specified action request.
-        """
-        # logger.info("18072017, self.get_handle_name:|%s| #1955"%(self.get_handle_name),)
-        if self.get_handle_name is None:
-            return self._get_handle(ar, _handle_attr_name)
-        return self._get_handle(ar, self.get_handle_name(ar))
-
-    @classmethod
-    def get_navinfo(cls, ar, obj):
-        """
-        Return navigation info for the given obj in the given ar.
-
-        The default implementation assumes that you navigate on the
-        :attr:`data_iterator`.
-
-        :class:`lino_xl.lib.calview.DayNavigator` overrides this.
-
-        """
-        return navinfo(ar.data_iterator, obj, ar.limit)
-
-    @classmethod
-    def is_valid_row(self, row):
-        return False
-
-    @classmethod
-    def make_params_layout_handle(cls):
-        if cls.is_abstract():
-            raise Exception("{} is abstract".format(cls))
-        return actions.make_params_layout_handle(cls)
-
-    @classmethod
-    def is_abstract(cls):
-        return cls.abstract
-
-    @classmethod
-    def has_handle(self, ui):
-        return self.__dict__.get(_handle_attr_name, False)
-
-    @classmethod
-    def clear_handle(self):
-        """
-        When an actor has dynamic columns which depend on database
-        content, then its layout handle may not persist between
-        different Django test cases because a handle from a first
-        test case may refer to elements which no longer exist in a
-        second test case.
-        """
-        setattr(self, _handle_attr_name, None)
-
-    @classmethod
-    def on_analyze(self, site):
-        pass
-
-    @classmethod
-    def summary_row(cls, ar, obj, **kw):
-        return obj.summary_row(ar, **kw)
-
-    @classmethod
-    def do_setup(self):
-        pass
-
     @classmethod
     def get_handle(self):
         """
@@ -675,6 +622,71 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
         # logger.info("18072017, h:|%s|, h.store:|%s|, #1955"%(h, getattr(h,'store',None)))
         return h
 
+    @classmethod
+    def get_request_handle(self, ar):
+        """
+        Return the dynamic (per-request) handle for this actor for the
+        renderer used by specified action request.
+        """
+        # logger.info("18072017, self.get_handle_name:|%s| #1955"%(self.get_handle_name),)
+        if self.get_handle_name is None:
+            return self._get_handle(ar, _handle_attr_name)
+        return self._get_handle(ar, self.get_handle_name(ar))
+
+    @classmethod
+    def has_handle(self, ui):
+        return self.__dict__.get(_handle_attr_name, False)
+
+    @classmethod
+    def clear_handle(self):
+        """
+        When an actor has dynamic columns which depend on database
+        content, then its layout handle may not persist between
+        different Django test cases because a handle from a first
+        test case may refer to elements which no longer exist in a
+        second test case.
+        """
+        setattr(self, _handle_attr_name, None)
+
+    @classmethod
+    def get_navinfo(cls, ar, obj):
+        """
+        Return navigation info for the given obj in the given ar.
+
+        The default implementation assumes that you navigate on the
+        :attr:`data_iterator`.
+
+        :class:`lino_xl.lib.calview.DayNavigator` overrides this.
+
+        """
+        return navinfo(ar.data_iterator, obj, ar.limit)
+
+    @classmethod
+    def is_valid_row(self, row):
+        return False
+
+    @classmethod
+    def make_params_layout_handle(cls):
+        if cls.is_abstract():
+            raise Exception("{} is abstract".format(cls))
+        return actions.make_params_layout_handle(cls)
+
+    @classmethod
+    def is_abstract(cls):
+        return cls.abstract
+
+    @classmethod
+    def on_analyze(self, site):
+        pass
+
+    @classmethod
+    def row_as_summary(cls, ar, obj, **kwargs):
+        return obj.as_summary_row(ar, **kwargs)
+
+    @classmethod
+    def do_setup(self):
+        pass
+
     # @classmethod
     # def update_field(cls, name, **kwargs):
     #     cls._pending_field_updates.append((name, kwargs)) xxx
@@ -820,7 +832,6 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
     @classmethod
     def hide_editing(cls, user_type):
         """
-
         Whether users of the given :term:`user type` can edit in this
         :term:`data window`.
 
@@ -1235,7 +1246,6 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
             # return str(self)
         return E.div(*forcetext([ar.obj2html(obj)]))
 
-
     @classmethod
     def override_column_headers(self, ar, **kwargs):
         """A hook to dynamically override the column headers. This has no
@@ -1529,8 +1539,8 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
 
         An optional first argument is the front end plugin, a
         :class:`Plugin` instance.  If this is None, use
-        :attr:`settings.SITE.kernel.default_ui
-        <lino.core.kernel.Kernel.default_ui>`.
+        :attr:`settings.SITE.kernel.web_front_ends
+        <lino.core.kernel.Kernel.web_front_ends>`.
 
         """
         lh = cls.get_detail_layout()
@@ -1628,16 +1638,17 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
 
           class NewClients(Clients):
               @classmethod
-              def param_defaults(self,ar,**kw):
-                  kw = super(NewClients,self).param_defaults(ar,**kw)
+              def param_defaults(self, ar, **kw):
+                  kw = super().param_defaults(ar, **kw)
                   kw.update(coached_since=amonthago())
                   return kw
 
 
         """
-        for k, pf in self.parameters.items():
-            # if not isinstance(pf, fields.DummyField):
-            kw[k] = pf.get_default()
+        if self.parameters:
+            for k, pf in self.parameters.items():
+                # if not isinstance(pf, fields.DummyField):
+                kw[k] = pf.get_default()
         return kw
 
     @classmethod
@@ -1674,15 +1685,14 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
         """
         Return or yield a list of screenshots to generate for this actor.
         Not yet stable. Don't override this.
-        Don't worry if you don't understand.
         """
         return []
 
     @classmethod
     def slave_as_html(cls, master, ar):
         """
-        Creates and returns the method to be used when :attr:`display_mode`
-        is DISPLAY_MODE_HTML.
+        Execute this slave view on the given master and render it as plain html.
+        Used when :attr:`display_mode` is ``DISPLAY_MODE_HTML``.
         """
         ar = cls.request(
             master, request=ar.request,
@@ -1695,7 +1705,7 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
             el = E.div(el, E.p(*toolbar))
         return el
 
-    summary_sep = E.br
+    summary_sep = "<br/>"
 
     @classmethod
     def get_table_as_list(cls, obj, ar):
@@ -1706,7 +1716,7 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
                 break
             par = sar.row_as_paragraph(obj)  # 20230207
             par = sar.add_detail_link(obj, par)
-            par = "<p>{}</p>".format(par)
+            par = '<p class="clearfix">{}</p>'.format(par)
             # url = sar.obj2url(obj)
             # if url is not None:
             #     url = html.escape(url)
@@ -1741,23 +1751,49 @@ class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
         # sar = ar.spawn_request(actor=cls, master_instance=obj,
         #     is_on_main_actor=False)
         sar = cls.request(parent=ar, master_instance=obj, is_on_main_actor=False)
-        p = E.div(*qs2summary(sar, sar.data_iterator, separator=cls.summary_sep,
-                max_items=cls.preview_limit))
-
+        p = qs2summary(sar, sar.data_iterator, separator=cls.summary_sep,
+                max_items=cls.preview_limit)
+        assert isinstance(p, str)
         toolbar = sar.plain_toolbar_buttons()
         if len(toolbar):
-            p.append(E.br())
+            p += "<br/>"
             for b in toolbar:
-                p.append(b)
+                p += tostring(b)
 
-        # if cls.insert_action is not None:
-        #     ir = cls.insert_action.request_from(sar)
-        #     if ir.get_permission():
-        #         btn = ir.ar2button()
-        #         if len(p):
-        #             p.append(E.br())
-        #         p.append(btn)
-        return p
+        return "<div>{}</div>".format(p)
+
+    @classmethod
+    def columns_to_paragraph(cls, self, ar=None, fmt=None):
+        """
+        Represent the given row as a paragraph with a comma-separated list of
+        the values of the fields in the column_names of this actor.
+        """
+        if ar is None:
+            return str(self)
+        # cols = ar.actor.get_detail_layout().main
+        cols = cls.get_list_layout().main.columns
+        cols = [c for c in cols if not c.value.get('hidden')]
+        if fmt is None:
+            def fmt(obj, col):
+                # return str(type(col))
+                v = col.value_from_object(obj, ar)
+                if v is None:
+                    return None
+                else:
+                    try:
+                        v = col.format_value(ar, v)
+                    except Exception as e:
+                        # v = "{} in {}".format(e, col.name)
+                        return col.name + "?!"
+                # return v
+                return "{}:{}".format(col.get_label(), v)
+
+        values = [fmt(self, c) for c in cols]
+        values = [v for v in values if v is not None]
+        s = ", ".join(values)
+        # s = str(ar.actor)
+        # print("20231218", s)  # self, ar.actor.get_list_layout().main.columns)
+        return s
 
     @classmethod
     def error2str(self, e):
