@@ -39,6 +39,7 @@ class AuthenticationMiddleware(MiddlewareMixin):
                                                 "'django.contrib.auth.middleware.AuthenticationMiddleware'."
                                             ) % ("_CLASSES" if settings.MIDDLEWARE is None else "")
         request.user = SimpleLazyObject(lambda: get_user(request))
+        request.subst_user = None
 
 
 class RemoteUserMiddleware(MiddlewareMixin):
@@ -68,7 +69,7 @@ class RemoteUserMiddleware(MiddlewareMixin):
                 "The Django remote user auth middleware requires the"
                 " authentication middleware to be installed.  Edit your"
                 " MIDDLEWARE setting to insert"
-                " 'django.contrib.auth.middleware.AuthenticationMiddleware'"
+                " 'lino.core.auth.middleware.AuthenticationMiddleware'"
                 " before the RemoteUserMiddleware class.")
         try:
             username = request.META[self.header]
@@ -97,6 +98,7 @@ class RemoteUserMiddleware(MiddlewareMixin):
             # User is valid.  Set request.user and persist user in the session
             # by logging the user in.
             request.user = user
+            # request.subst_user = None
             auth.login(request, user)
 
     def clean_username(self, username, request):
@@ -181,46 +183,49 @@ class WithUserMiddleware(MiddlewareMixin):
         user = request.user
         user_language = user.language  # or settings.SITE.get_default_language()
 
+        request.requesting_panel = None
+        request.subst_user = None
+
         if settings.USE_TZ:
             if user.time_zone:
                 activate(user.time_zone.tzinfo)
             else:
                 activate(settings.SITE.models.about.TimeZones.default.tzinfo)
 
-        if user.is_anonymous:
-            request.subst_user = None
-            request.requesting_panel = None
-            return
-        update = False
-        now = datetime.datetime.now()
-        last = request.session.get('last_activity', None)
-        if last is None:
-            update = True
-        else:
-            last = datetime.datetime.strptime(last, "%Y-%m-%dT%H:%M:%S.%f")
-            if now - last > ACTIVITY_SLOT:
-                # print("20210116 update last activity")
+        if not user.is_anonymous:
+            update = False
+            now = datetime.datetime.now()
+            last = request.session.get('last_activity', None)
+            if last is None:
                 update = True
-        if update:
-            # information shown in users.ActiveSessions
-            request.session['last_activity'] = now.isoformat()
-            request.session['last_ip_addr'] = get_client_ip_address(request)
+            else:
+                last = datetime.datetime.strptime(last, "%Y-%m-%dT%H:%M:%S.%f")
+                if now - last > ACTIVITY_SLOT:
+                    # print("20210116 update last activity")
+                    update = True
+            if update:
+                # information shown in users.ActiveSessions
+                request.session['last_activity'] = now.isoformat()
+                request.session['last_ip_addr'] = get_client_ip_address(request)
 
         rqdata = request2data(request, user_language)
         if rqdata is None:
             return
 
-        su = rqdata.get(constants.URL_PARAM_SUBST_USER, None)
-        if su is not None:
-            if su:
-                try:
-                    su = settings.SITE.user_model.objects.get(id=int(su))
-                    # ~ logger.info("20120714 su is %s",su.username)
-                except settings.SITE.user_model.DoesNotExist:
-                    su = None
-            else:
-                su = None  # e.g. when it was an empty string "su="
-        request.subst_user = su
+        if not user.is_anonymous:
+            su = rqdata.get(constants.URL_PARAM_SUBST_USER, None)
+            if su is not None:
+                if su:
+                    try:
+                        su = settings.SITE.user_model.objects.get(id=int(su))
+                        # ~ logger.info("20120714 su is %s",su.username)
+                    except settings.SITE.user_model.DoesNotExist:
+                        su = None
+                else:
+                    su = None  # e.g. when it was an empty string "su="
+            request.subst_user = su
+        # if request.subst_user:
+        #     raise(Exception("20230331 {}".format(request.subst_user)))
 
 
 
