@@ -76,7 +76,7 @@ class AnonymousUser:
         return str(self)
 
 
-def activate_social_auth_testing(globals_dict, has_google=False):
+def activate_social_auth_testing(globals_dict, google=True, github=True, wikimedia=True, facebook=True):
     """
     Used for testing a development server.
     See for example the :xfile:`settings.py` of :mod:`lino_book.projects.noi1e`.
@@ -84,32 +84,28 @@ def activate_social_auth_testing(globals_dict, has_google=False):
     """
     Site = globals_dict['Site']
 
-    Site.social_auth_backends = [
-        'social_core.backends.github.GithubOAuth2',
+    Site.social_auth_backends = []
+
+    if github:
+        Site.social_auth_backends.append('social_core.backends.github.GithubOAuth2',)
+        globals_dict.update(
+            # https://github.com/organizations/lino-framework/settings/applications/632218
+            SOCIAL_AUTH_GITHUB_KEY = '355f66b1557f0cbf4d1d',
+            SOCIAL_AUTH_GITHUB_SECRET = '4dbeea1701bf03316c1759bdb422d9f88969b782')
+
         # 'social_core.backends.google.GoogleOAuth2',
         # 'social_core.backends.google.GoogleOAuth',
-        'social_core.backends.facebook.FacebookOAuth2',
-        'social_core.backends.mediawiki.MediaWiki'
-    ]
-    if not has_google:
+        # 'social_core.backends.facebook.FacebookOAuth2',
+    if wikimedia:
+        Site.social_auth_backends.append('social_core.backends.mediawiki.MediaWiki')
+        globals_dict.update(
+            SOCIAL_AUTH_MEDIAWIKI_KEY = '7dbd2e1529e45108f798349811c7a2b7',
+            SOCIAL_AUTH_MEDIAWIKI_SECRET = '8041055fcd16333fa242b346e0ae52133fd2ee14',
+            SOCIAL_AUTH_MEDIAWIKI_URL = 'https://meta.wikimedia.org/w/index.php',
+            SOCIAL_AUTH_MEDIAWIKI_CALLBACK = 'oob'
+            )
+    if google:
         Site.social_auth_backends.append('social_core.backends.google.GooglePlusAuth')
-
-    globals_dict.update(
-        # https://github.com/organizations/lino-framework/settings/applications/632218
-        SOCIAL_AUTH_GITHUB_KEY = '355f66b1557f0cbf4d1d',
-        SOCIAL_AUTH_GITHUB_SECRET = '4dbeea1701bf03316c1759bdb422d9f88969b782',
-
-        SOCIAL_AUTH_FACEBOOK_KEY = '1837593149865295',
-        SOCIAL_AUTH_FACEBOOK_SECRET = '1973f9e9d9420c4c6502aa40cb8cb7db',
-        SOCIAL_AUTH_FACEBOOK_SCOPE = ['email', 'public_profile', 'user_friends'],
-
-        SOCIAL_AUTH_MEDIAWIKI_KEY = '7dbd2e1529e45108f798349811c7a2b7',
-        SOCIAL_AUTH_MEDIAWIKI_SECRET = '8041055fcd16333fa242b346e0ae52133fd2ee14',
-        SOCIAL_AUTH_MEDIAWIKI_URL = 'https://meta.wikimedia.org/w/index.php',
-        SOCIAL_AUTH_MEDIAWIKI_CALLBACK = 'oob'
-        )
-
-    if not has_google:
         globals_dict.update(
             SOCIAL_AUTH_GOOGLE_PLUS_KEY = '451271712409-9qtm9bvjndaeep2olk3useu61j6qu2kp.apps.googleusercontent.com',
             SOCIAL_AUTH_GOOGLE_PLUS_SECRET = 'NHyaqV2HY8lV5ULG6k51OMwo',
@@ -120,3 +116,12 @@ def activate_social_auth_testing(globals_dict, has_google=False):
                 'https://www.googleapis.com/auth/contacts ', # To have WRITE/READ permissions
             ]
         )
+
+    if facebook:
+        globals_dict.update(
+            SOCIAL_AUTH_FACEBOOK_KEY = '1837593149865295',
+            SOCIAL_AUTH_FACEBOOK_SECRET = '1973f9e9d9420c4c6502aa40cb8cb7db',
+            SOCIAL_AUTH_FACEBOOK_SCOPE = ['email', 'public_profile', 'user_friends'])
+
+    if not Site.social_auth_backends:
+        Site.social_auth_backends = None
