@@ -6,7 +6,7 @@
 
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 import os
 
 from django.conf import settings
@@ -105,9 +105,6 @@ class BoundAction(object):
     def get_button_label(self, *args):
         return self.action.get_button_label(self.actor, *args)
 
-    #~ def get_panel_btn_handler(self,*args):
-        #~ return self.action.get_panel_btn_handler(self.actor,*args)
-
     def setup_action_request(self, *args):
         return self.action.setup_action_request(self.actor, *args)
 
