@@ -13,13 +13,14 @@ import warnings
 
 from django.utils.translation import gettext_lazy as _
 from django.utils.functional import lazy
-from django.utils.deconstruct import deconstructible
+# from django.utils.deconstruct import deconstructible
 from django.db import models
 from django.conf import settings
 from django.db.models import NOT_PROVIDED
 from django.db.migrations.serializer import BaseSerializer
 from django.db.migrations.writer import MigrationWriter
 
+from lino.utils import MissingRow
 from lino.core.utils import resolve_field
 from lino.core import actions
 from lino.core import actors
@@ -33,7 +34,7 @@ STRICT = True
 VALUE_FIELD = models.CharField(_("value"), max_length=20)
 VALUE_FIELD.attname = 'value'
 
-@deconstructible
+# @deconstructible
 class Choice(fields.TableRow):
     """A constant value whose unicode representation depends on the
     current language at runtime.  Every item of a :class:`ChoiceList`
@@ -221,9 +222,6 @@ Django creates copies of them when inheriting models.
         return (self.value >= other)
 
     __hash__ = object.__hash__
-    #~ 20120620: removed to see where it was used
-    #~ def __getattr__(self,name):
-        #~ return curry(getattr(self.choicelist, name),self)
 
     def __repr__(self):
         # when there several names, we use the first one
@@ -239,8 +237,6 @@ Django creates copies of them when inheriting models.
     #     return str(self.text)
 
     def __str__(self):
-        # return force_str(self.text, errors="replace")
-        # return self.text
         if self.choicelist.show_values:
             return "{0} ({1})".format(self.value, self.text)
         return str(self.text)
@@ -296,34 +292,24 @@ class ChoiceListMeta(actors.ActorMetaClass):
 #~ choicelist_column_fields['text'] = fields.VirtualField(models.CharField())
 #~ choicelist_column_fields['name'] = fields.VirtualField(models.CharField())
 
-class CallableChoice(object):
-    def __repr__(self):
-        return "{}.as_callable('{}')".format(repr(self.ChoiceList), self.name)
-    # def __eq__(self, other):
-    #     return self.ChoiceList == other.ChoiceList and self.name == other.name
-    def __init__(self, ChoiceList, name):
-        self.ChoiceList = ChoiceList
+class CallableChoice:
+
+    def __init__(self, choicelist, name):
+        self.choicelist = choicelist
         self.name = name
-    def __call__(self, *args, **kwargs):
-        return self.ChoiceList.get_by_name(self.name)
-        # return self.callfn(*args, **kwargs)
-
-class MissingRow():
-
-    def __init__(self, pointing_field, pointing_choice):
-        self.pointing_field = pointing_field
-        self.pointing_choice = pointing_choice
-
-    def __str__(self):
-        return _("No {} pointing to {}").format(
-            self.pointing_field.model._meta.verbose_name, self.pointing_choice)
 
     def __repr__(self):
-        return "{}({})".format(self.__class__.__name__, repr(self.pointing_choice))
+        return repr(self.name)
+
+    def __call__(self, *args, **kwargs):
+        return self.choicelist.get_by_name(self.name)
+        # return self.callfn(*args, **kwargs)
 
 
 class PointingChoice(Choice):
     """
+    A choice that points to a database object.
+
     Usage examples: :class:`lino_xl.lib.ledger.CommonAccounts`,
     :class:`lino_xl.lib.properties.PropertyAreas`.
     """
@@ -348,7 +334,10 @@ class PointingChoice(Choice):
             try:
                 self._instance = pf.model.objects.get(**{pf.name: self})
             except pf.model.DoesNotExist:
-                self._instance = MissingRow(pf,self)
+                # self._instance = MissingRow(pf,self)
+                self._instance = MissingRow(
+                    _("No {} pointing to {}").format(
+                        pf.model._meta.verbose_name, repr(self)))
         return self._instance
 
     def has_row(self):
@@ -396,25 +385,22 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
             ...
             client_state=ClientStates.field(blank=True, default=''))
 
-    Note that the default values of parameter fields of a table which
+    Note that the default values of parameter fields of a table that
     is used as the *models default table* will apply for the choices
     of pointers to that model. Concrete use case is the choicelist of
-    `cal.Guest.partner` in :ref:`avanti` which should show only
+    `cal.Guest.partner` in :ref:`avanti`, which should show only
     coached clients.  So instead of above code we actually now do::
 
         class MyClients(My, Clients):
             @classmethod
             def param_defaults(self, ar, **kw):
-                kw = super(MyClients, self).param_defaults(ar, **kw)
+                kw = super().param_defaults(ar, **kw)
                 kw.update(client_state='')
                 return kw
 
-
-
-    The disadvantage
-    is that when somebody *does not* want your default value, then
-    they must explicitly specify `default=''` when defining a field on
-    your choicelist.
+    The disadvantage is that when somebody *does not* want your default value,
+    then they must explicitly specify `default=''` when defining a field on your
+    choicelist.
 
     """
 
@@ -441,15 +427,16 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
 
     preferred_width = None
     """Preferred width (in characters) used by
-    :class:`fields<lino.core.fields.ChoiceListField>` that refer to
+    choicelist fields that refer to
     this list.
 
     If this is `None`, then Lino calculates the value at startup,
     taking the length of the longest choice text.  The hard-coded
-    absolute minimum in that case is 4.  Note that it calculates the
-    value using the :attr:`default site language
-    <lino.site.Site.languages>` and thus might guess wrong if the user
-    language is not the default site language.
+    absolute minimum in that case is 4.
+
+    Note that it calculates the value using the :attr:`default site language
+    <lino.site.Site.languages>` and thus might guess wrong if the user language
+    is not the default site language.
 
     Note that by this we mean the width of the bare text field,
     excluding any UI-specific control like the trigger button of a
@@ -487,11 +474,14 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
 
     @classmethod
     def get_data_elem(self, name):
-        de = super(ChoiceList, self).get_data_elem(name)
+        de = super().get_data_elem(name)
         if de:
             return de
         return getattr(self, name, None)
-        #~ return _choicelist_column_fields.get(name)
+
+    @classmethod
+    def get_widget_options(cls, name, **options):
+        return cls.item_class.get_widget_options(name, **options)
 
     @fields.virtualfield(VALUE_FIELD)
     def value(cls, choice, ar):
@@ -644,7 +634,7 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
 
     @classmethod
     def class_init(cls):
-        super(ChoiceList, cls).class_init()
+        super().class_init()
         if cls.abstract:
             return
         if cls.preferred_width is None:
@@ -717,7 +707,7 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
         #~ We must make it dynamic since e.g. UserTypes can change after
         #~ the fields have been created.
 
-        #~ https://docs.djangoproject.com/en/4.1/ref/models/fields/
+        #~ https://docs.djangoproject.com/en/5.0/ref/models/fields/
         #~ note that choices can be any iterable object -- not necessarily
         #~ a list or tuple. This lets you construct choices dynamically.
         #~ But if you find yourself hacking choices to be dynamic, you're
@@ -734,29 +724,26 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
         instance `bc` to the user.
 
         Override this to customize the display text of choices.
+
         :class:`lino.modlib.users.UserGroups` and
         :class:`lino.modlib.cv.models.CefLevel` used to do this before
         we had the :attr:`ChoiceList.show_values` option.
 
-        This must be lazyly translatable because the result are also
-        used to build the `choices` attribute of ChoiceListFields on
-        this choicelist.
+        This must be lazily translatable because the return value is also used
+        to build the `choices` attribute of ChoiceListFields on this choicelist.
+
+        Note that Django's `lazy` function has a list of "resultclasses" that
+        are used "so that the automatic forcing of the lazy evaluation code is
+        triggered".
 
-        Note that Django's `lazy` function has a list of
-        "resultclasses" which are used "so that the automatic forcing
-        of the lazy evaluation code is triggered".
 
         """
-        if cls.show_values:
-            # if unicodeerror:
-            # assert_pure(str(bc))
-            # str(bc)
-
-            def fn(bc):
-                # return "%s (%s)" % (bc.value, str(bc))
-                return "{0} ({1})".format(bc.value, bc)
-            return lazy(fn, str, str)(bc)
-        return lazy(str, str, str)(bc)
+        # if cls.show_values:
+        #     def fn(bc):
+        #         # return "%s (%s)" % (bc.value, str(bc))
+        #         return "{0} ({1})".format(bc.value, bc)
+        #     return lazy(fn, str)(bc)
+        return lazy(str, str)(bc)
 
     @classmethod
     def get_by_name(self, name, *args):
@@ -782,21 +769,15 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
         return cls.items_dict.get(value, *args)
 
     @classmethod
-    def as_callable(self, name):
+    def as_callable(cls, name):
         """
-        Use this when you want to specify some named default choice of this
-        list as a default value *without* removing the possibility to
-        clear and re-populate the list after the field definition.
-
-        Usage example::
-
-            foo_state = MyStates.as_callable('foo')
-
-        This is used internally when you specify a string as default value of a
-        choicelist field.
-
+        Used internally when a string is given as default value of a choicelist
+        field. Resolving that string immediately into a Choice object would
+        break the possibility of re-populating the list after the field
+        definition.
         """
-        return CallableChoice(self, name)
+        # return lambda : cls.get_by_name(name)
+        return CallableChoice(cls, name)
 
     @classmethod
     def get_default_value(self):
@@ -888,11 +869,15 @@ class ChoiceListField(models.CharField):
 
     empty_strings_allowed = False
 
-    def __init__(self, choicelist=None, verbose_name=None,
+    strict: bool
+    """Whether to fail at runtime if no :class:`Choice` exists for a value (used in from_db_value)."""
+
+    def __init__(self, choicelist=None, verbose_name=None, strict=True,
                  force_selection=True, default=None, **kw):
         if verbose_name is None:
             verbose_name = choicelist.verbose_name
         self.choicelist = choicelist
+        self.strict = strict
         self.force_selection = force_selection
         if default is not None:
             if isinstance(default, str):
@@ -900,9 +885,6 @@ class ChoiceListField(models.CharField):
             kw.update(default=default)
         defaults = dict(
             max_length=choicelist.max_length)
-        # if choicelist.default_value:
-        #     defaults.update(
-        #         default=choicelist.as_callable(choicelist.default_value))
         if choicelist.default_value:
             defaults.update(default=choicelist.get_default_value)
         # if not 'help_text' in kw:
@@ -925,19 +907,14 @@ class ChoiceListField(models.CharField):
     def deconstruct(self):
         """
         Needed for Django 1.7+, see
-        https://docs.djangoproject.com/en/4.1/howto/custom-model-fields/#custom-field-deconstruct-method
+        https://docs.djangoproject.com/en/5.0/howto/custom-model-fields/#custom-field-deconstruct-method
         """
 
-        name, path, args, kwargs = super(ChoiceListField, self).deconstruct()
-        # args = [self.choicelist]
-
+        name, path, args, kwargs = super().deconstruct()
         kwargs['choicelist'] = self.choicelist
-        # kwargs.pop('default', None)
-        # TODO: above line is cheating in order to get makemigrations
-        # to pass. we remove the `default` attribute because it is not
-        # serializable. This means that our migrations are probably
-        # invalid and not usable.
-
+        # The available choices are *not* relevant for the database structure,
+        # and Django might have problems for representing them in a migration.
+        kwargs.pop('choices', None)
         return name, path, args, kwargs
 
     def get_internal_type(self):
@@ -949,11 +926,16 @@ class ChoiceListField(models.CharField):
     def from_db_value(self, value, expression, connection, context=None):
         if value is None:
             return None
-        return self.choicelist.to_python(value)
+        try:
+            return self.choicelist.to_python(value)
+        except UnresolvedChoice as e:
+            if not self.strict:
+                return UnresolvedValue(self.choicelist, value)
+            raise e
 
     def to_python(self, value):
         """See Django's docs about `to_python()
-        <https://docs.djangoproject.com/en/4.1/ref/models/fields/#django.db.models.Field.to_python>`__.
+        <https://docs.djangoproject.com/en/5.0/ref/models/fields/#django.db.models.Field.to_python>`__.
 
         """
         #~ if self.attname == 'query_register':
@@ -980,11 +962,11 @@ class ChoiceListField(models.CharField):
     def get_prep_value(self, value):
         """
         Excerpt from `Django docs
-        <https://docs.djangoproject.com/en/4.1/howto/custom-model-fields/#converting-python-objects-to-query-values>`__:
+        <https://docs.djangoproject.com/en/5.0/howto/custom-model-fields/#converting-python-objects-to-query-values>`__:
         "If you override `to_python()
-        <https://docs.djangoproject.com/en/4.1/ref/models/fields/#django.db.models.Field.to_python>`__
+        <https://docs.djangoproject.com/en/5.0/ref/models/fields/#django.db.models.Field.to_python>`__
         you also have to override `get_prep_value()
-        <https://docs.djangoproject.com/en/4.1/ref/models/fields/#django.db.models.Field.get_prep_value>`__
+        <https://docs.djangoproject.com/en/5.0/ref/models/fields/#django.db.models.Field.get_prep_value>`__
         to convert Python objects back to query values."
         """
         #~ if self.attname == 'query_register':
@@ -1065,15 +1047,14 @@ class MultiChoiceListField(ChoiceListField):
 
 
 
-# from lino.core.choicelists import Choice, ChoiceList, CallableChoice
-
 
 class ChoiceSerializer(BaseSerializer):
     def serialize(self):
-        return ("rt.models.{}.{}.get_by_value('{}')".format(
-            self.value.choicelist.app_label, self.value.choicelist.__name__,
-                self.value.value),
-            {'from lino.api.shell import rt'})
+        return repr(self.value.value), set()
+        # return ("rt.models.{}.{}.get_by_value('{}')".format(
+        #     self.value.choicelist.app_label, self.value.choicelist.__name__,
+        #         self.value.value),
+        #     {'from lino.api.shell import rt'})
 
 MigrationWriter.register_serializer(Choice, ChoiceSerializer)
 
@@ -1087,9 +1068,9 @@ MigrationWriter.register_serializer(ChoiceList, ChoiceListSerializer)
 
 class CallableChoiceSerializer(BaseSerializer):
     def serialize(self):
-        choice = self.value()
-        return ("rt.models.{}.{}.as_callable('{}')".format(
-            choice.choicelist.app_label, choice.choicelist.__name__, choice.name),
-            {'from lino.api.shell import rt'})
+        return repr(self.value().name), set()
+        # return ("rt.models.{}.{}.as_callable('{}')".format(
+        #     choice.choicelist.app_label, choice.choicelist.__name__, choice.name),
+        #     {'from lino.api.shell import rt'})
 
 MigrationWriter.register_serializer(CallableChoice, CallableChoiceSerializer)
