@@ -5,7 +5,7 @@
 This defines the :class:`Table` class.
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 import datetime
 
@@ -55,7 +55,7 @@ def base_attrs(cl):
 def add_gridfilters(qs, gridfilters):
     """Converts a `filter` request in the format used by
     :extux:`Ext.ux.grid.GridFilters` into a `Django field lookup
-    <https://docs.djangoproject.com/en/4.1/ref/models/querysets/#field-lookups>`_
+    <https://docs.djangoproject.com/en/5.0/ref/models/querysets/#field-lookups>`_
     on a :class:`django.db.models.query.QuerySet`.
 
     :param qs: the queryset to be modified.
@@ -235,13 +235,13 @@ class Table(AbstractTable):
         if self.model is not None:
             return self.model.get_chooser_for_field(fieldname)
 
-    @classmethod
-    def request(self, master_instance=None, **kw):  # 20130327
-        kw.update(actor=self)
-        if master_instance is not None:
-            kw.update(master_instance=master_instance)
-        kw.setdefault('action', self.default_action)
-        return TableRequest(**kw)
+    # @classmethod
+    # def request(self, master_instance=None, **kw):  # 20130327
+    #     kw.update(actor=self)
+    #     if master_instance is not None:
+    #         kw.update(master_instance=master_instance)
+    #     kw.setdefault('action', self.default_action)
+    #     return TableRequest(**kw)
 
     @classmethod
     def column_choices(self):
@@ -364,7 +364,10 @@ class Table(AbstractTable):
     def get_actor_label(self):
         if self.model is None:
             # return self._label or self.__name__
-            return super(Table, self).get_actor_label()
+            return super().get_actor_label()
+        if isinstance(self.model, str):
+            print("20231104", settings.SITE.is_hidden_app(self.app_label))
+            raise Exception("20231104 {}.model is {!r}".format(self, self.model))
         return self._label or self.model._meta.verbose_name_plural
 
     @classmethod
@@ -731,6 +734,7 @@ class Table(AbstractTable):
         calling also :meth:`lino.core.model.Model.on_create`.
         """
         # print 20120630, "Actor.create_instance", kw
+        # raise Exception("20230331 {}".format(ar.subst_user))
         instance = self.model(**kw)
         instance.on_create(ar)
         return instance
