@@ -7,8 +7,6 @@ See :doc:`/dev/delete`.
 
 """
 
-# import logging ; logger = logging.getLogger(__name__)
-
 from django.conf import settings
 from django.db import models
 
@@ -57,7 +55,7 @@ class DisableDeleteHandler(object):
         return "<DisableDeleteHandler(%s, %s)>" % (self.model, s)
 
     def disable_delete_on_object(self, obj, ignore_models=set()):
-        """Return a veto message which explains why this object cannot be
+        """Return a veto message that explains why this object cannot be
         deleted.  Return `None` if there is no veto.
 
         If `ignore_model` (a set of model class objects) is specified,
