@@ -7,7 +7,7 @@ Defines extended database field classes and utility functions
 related to fields.
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 import datetime
 from decimal import Decimal
 
@@ -157,7 +157,7 @@ class MonthField(models.DateField):
 class PriceField(models.DecimalField):
     """
     A thin wrapper around Django's `DecimalField
-    <https://docs.djangoproject.com/en/4.1/ref/models/fields/#decimalfield>`_
+    <https://docs.djangoproject.com/en/5.0/ref/models/fields/#decimalfield>`_
     which adds default values for `decimal_places`, `max_length` and
     `max_digits`.
     """
@@ -287,6 +287,7 @@ class FakeField(object):
     blank = True  # 20200425
     delayed_value = False
     max_length = None
+    generated = False
 
     wildcard_data_elem = False
     """Whether to consider this field as wildcard data element.
@@ -468,7 +469,7 @@ class DelayedHtmlBox(HtmlBox):
     """
 
     A simple extension of :class:`HtmlBox` that uses the :class:`DelayedValue
-    <lino.utils.DelayedValue>` for its related store field value.
+    <lino.core.utils.DelayedValue>` for its related store field value.
 
     """
 
@@ -576,11 +577,13 @@ class VirtualField(FakeField):
                     "Invalid return type spec {} for {} : {}".format(f, self, e))
 
         if isinstance(f, FakeField):
-            sortable_by = f.sortable_by
-            self.sortable_by = sortable_by
-            if sortable_by and isinstance(sortable_by, list):
-                sortable_by = sortable_by[0]
-            self.column = sortable_by
+            # sortable_by = f.sortable_by
+            self.sortable_by = f.sortable_by
+            if f.sortable_by is not None:
+                assert isinstance(f.sortable_by, list)
+                self.column = f.sortable_by[0]
+            # if sortable_by and isinstance(sortable_by, list):
+            #     sortable_by = sortable_by[0]
 
         if isinstance(f, models.ForeignKey):
             f.remote_field.model = resolve_model(f.remote_field.model)
@@ -880,16 +883,19 @@ class QuantityField(models.CharField):
     <lino.utils.quantities.Percentage>` and :class:`Duration
     <lino.utils.quantities.Duration>` values.
 
-    Implemented as a CharField (sorting or filter ranges may not work
-    as expected).
+    Implemented as a CharField, which means that
+    sorting or filter ranges may not work as expected,
+    and you cannot use SUM or AVG agregators on quantity fields
+    since the database does not know how to calculate sums from them.
 
-    When you set `blank=True`, then you should also declare `null=True`.
+    When you set `blank=True`, then you should also set `null=True`.
 
     """
     description = _("Quantity (Decimal or Duration)")
+    overflow_value = None
 
     def __init__(self, *args, **kw):
-        kw.setdefault('max_length', 6)
+        kw.setdefault('max_length', settings.SITE.quantity_max_length)
         super().__init__(*args, **kw)
         if self.blank and not self.null:
             raise ChangedAPI(
@@ -901,7 +907,7 @@ class QuantityField(models.CharField):
     def to_python(self, value):
         """
         Excerpt from `Django docs
-        <https://docs.djangoproject.com/en/4.1/howto/custom-model-fields/#converting-values-to-python-objects>`__:
+        <https://docs.djangoproject.com/en/5.0/howto/custom-model-fields/#converting-values-to-python-objects>`__:
 
             As a general rule, :meth:`to_python` should deal gracefully with
             any of the following arguments:
@@ -913,8 +919,6 @@ class QuantityField(models.CharField):
         I'd add "Any value allowed for this field when instantiating a model."
 
         """
-        if isinstance(value, Decimal):
-            return quantities.Quantity(value)
         if value:
             # try:
             if isinstance(value, str):
@@ -923,23 +927,31 @@ class QuantityField(models.CharField):
             # except Exception as e:
             #     raise ValidationError(
             #         "Invalid value {} for {} : {}".format(value, self, e))
+        elif isinstance(value, Decimal):
+            return quantities.Quantity(value)
         return None
 
     def from_db_value(self, value, expression, connection, context=None):
-        return quantities.parse(value) if value else self.get_default()
+        if value is None or value == '':
+            return self.get_default()
+        return quantities.parse(value)
 
     # def get_db_prep_value(self, value, connection, prepared=False):
     #     return str(value) if value else ''
 
     def get_prep_value(self, value):
-        # if value is None:
-        #     return ''
-        return str(value) if value else ''
+        if value is None:
+            return ''
+        return str(value)  # if value is None else ''
 
     def clean(self, raw_value, obj):
         if len(str(raw_value)) > self.max_length:
+            if self.overflow_value:
+                return self.overflow_value
+            raise ValidationError("Cannot accept quantity {} "
+                "because max_length is {}".format(raw_value, self.max_length))
             # print("20230129 Can't store {}={} in {}".format(self.name, raw_value, obj))
-            return -1
+            # return -1
         return super().clean(raw_value, obj)
 
 
@@ -948,13 +960,11 @@ class DurationField(QuantityField):
     A field that stores :class:`Duration
     <lino.utils.quantities.Duration>` values as CHAR.
 
-    Note that you cannot use SUM or AVG agregators on these fields
-    since the database does not know how to calculate sums from them.
-
-
     """
     def from_db_value(self, value, expression, connection, context=None):
-        return Duration(value) if value else self.get_default()
+        if value is None or value == '':
+            return self.get_default()
+        return Duration(value)
 
     def to_python(self, value):
         if isinstance(value, Duration):
@@ -992,7 +1002,7 @@ or "23.07.0000" means "on a 23th of July"."""))
         models.CharField.__init__(self, *args, **kw)
 
     def deconstruct(self):
-        name, path, args, kwargs = super(IncompleteDateField, self).deconstruct()
+        name, path, args, kwargs = super().deconstruct()
         del kwargs["max_length"]
         return name, path, args, kwargs
 
@@ -1118,7 +1128,7 @@ class CustomField(object):
         The widget must be an instance of the given `base_class`.
 
         `self` and `field` are identical unless `self` is a
-        :class`RemoteField` or a :class:`VirtualField`.
+        :class:`RemoteField` or a :class:`VirtualField`.
 
         """
         return None
@@ -1146,6 +1156,8 @@ class TableRow(object):
     _lino_default_table = None
     _widget_options = {}
 
+    pk = None
+
     hidden_columns = frozenset()
     """If specified, this is the default value for
     :attr:`hidden_columns<lino.core.tables.AbstractTable.hidden_columns>`
@@ -1244,9 +1256,10 @@ class TableRow(object):
         """
         a = getattr(self, '_detail_action', None)
         # print("20201230 get_detail_action", ar.actor, ar.actor.model, self.__class__)
+        # if a is not None:
+        #     raise Exception("20230425")
         if a is None:
-            if ar and ar.actor and ar.actor.model \
-               and self.__class__ is ar.actor.model:
+            if ar and ar.actor and ar.actor.model is self.__class__:
                 a = ar.actor.detail_action
             else:
                 # if ar and ar.actor and ar.actor.model:
@@ -1259,6 +1272,7 @@ class TableRow(object):
         if a is None or ar is None:
             return a
         if a.get_view_permission(ar.get_user().user_type):
+            # raise Exception("20230425 {}".format(ar.actor))
             return a
 
     def get_choices_text(self, request, actor, field):
@@ -1290,15 +1304,29 @@ class TableRow(object):
         # return [ar.obj2html(self)]
         return [self.obj2href(ar)]
 
-    def as_page(self, ar):
-        return []
+    def as_story_item(self, ar, **kwargs):
+        # if settings.SITE.is_installed('search') and issubclass(
+        #     ar.actor, settings.SITE.models.search.SiteSearchBase):
+        #     return self.as_search_item(ar)
+        # return self.as_summary_row(ar)
+        # return "<p>{}</p>".format(self.as_paragraph(ar))
+        kwargs.update(display_mode="story")
+        return "".join(self.as_page(ar, **kwargs))
 
-    def as_paragraph(self, ar):
-        """Return a rich text that represents the given row as a list item.
+    def as_page(self, ar, **kwargs):
+        yield "<h1>{}</h1>".format(self)
 
-        See :ref:`dev.as_paragraph`.
-        """
-        return str(self)
+    def as_paragraph(self, ar, **kwargs):
+        # return str(self)
+        return ar.obj2htmls(self)
+
+    def as_summary_row(self, ar, **kwargs):
+        # used by tickets.Tickets table in the bootstrap frontend
+        # also when display_mode = ((None, constants.DISPLAY_MODE_STORY), ) it returns html
+        # text for the object that is calling
+        # return tostring(E.p(*self.summary_row(ar)))
+        # return ar.obj2htmls(self)
+        return self.as_paragraph(ar, **kwargs)
 
     def save_existing_instance(self, ar):
         watcher = ChangeWatcher(self)
@@ -1423,7 +1451,7 @@ def pointer_factory(cls, othermodel, *args, **kw):
       case. This is useful when designing reusable models.
 
     - Explicitly sets the default value for `on_delete
-      <https://docs.djangoproject.com/en/4.1/ref/models/fields/#django.db.models.ForeignKey.on_delete>`__
+      <https://docs.djangoproject.com/en/5.0/ref/models/fields/#django.db.models.ForeignKey.on_delete>`__
       to ``CASCADE`` (as required by Django 2).
 
     """
@@ -1475,8 +1503,9 @@ def make_remote_field(model, name):
             # dummy field
             return fld
 
-        if isinstance(fld, models.ManyToOneRel):
-            gettable = False
+        # Why was this? it caused docs/specs/avanti/courses.rst to fail
+        # if isinstance(fld, models.ManyToOneRel):
+        #     gettable = False
 
         # make sure that the atomizer gets created.
         store.get_atomizer(model, fld, fld.name)
@@ -1486,15 +1515,16 @@ def make_remote_field(model, name):
         leaf_chooser = choosers.check_for_chooser(model, fld)
 
         field_chain.append(fld)
-        if isinstance(fld, (models.OneToOneRel, models.ForeignKey)):
+        if isinstance(fld, (models.OneToOneRel, models.OneToOneField, models.ForeignKey)):
             editable = True
         if getattr(fld, 'remote_field', None):
             model = fld.remote_field.model
         else:
             model = None
 
-    if not gettable:
-        return RemoteField(none_getter, name, fld)
+    # if not gettable:
+    #     # raise Exception("20231112")
+    #     return RemoteField(none_getter, name, fld)
 
     if leaf_chooser is not None:
         d = choosers.get_choosers_dict(cls)
@@ -1534,7 +1564,7 @@ def make_remote_field(model, name):
                 if isinstance(fld, (models.OneToOneRel, models.ForeignKey)):
                     reltarget = getattr(target, fld.name, None)
                     if reltarget is None:
-                        # rkw = { fld.field.name: target }
+                        rkw = { fld.field.name: target }
                         # print(
                         #     "20180712 create {}({})".format(
                         #         fld.related_model, rkw))
