@@ -21,35 +21,32 @@ application.
 
 """
 
-import logging ; logger = logging.getLogger(__name__)
-
 import os
 from os.path import join, dirname, exists
 
 import sys
 import time
-# import copy
 import codecs
 import atexit
 import threading
 from importlib import import_module
-# import dill
 import json
-
+from etgen.html import E
 
 from django.apps import AppConfig
 from django.apps import apps
 from django.conf import settings
-from django.core import exceptions
 from django.utils.encoding import force_str
 from django.utils.text import format_lazy
 from django.utils.translation import gettext_lazy as _
-from django.core.exceptions import PermissionDenied
+from django.core.exceptions import PermissionDenied, ValidationError
 from django.db.utils import DatabaseError
+from django.db import IntegrityError
 
 from django.db import models
 
 import lino  # for is_testing
+from lino import logger
 from lino.utils import codetime
 # from lino.utils import isiterable
 from lino.core import layouts
@@ -62,7 +59,6 @@ from lino.core import choicelists
 from lino.core import workflows
 from lino.core import tables
 from lino.core import constants
-from etgen.html import E
 from lino.core.model import Model
 from lino.core.roles import UserRole
 from lino.core.store import Store
@@ -85,7 +81,7 @@ from .utils import resolve_fields_list
 from .utils import class_dict_items
 
 from .fields import set_default_verbose_name
-from lino.core.requests import ActorRequest
+# from lino.core.requests import ActorRequest
 
 startup_rlock = threading.RLock()  # Lock() or RLock()?
 
@@ -102,8 +98,9 @@ class Kernel(object):
         Obsolete. Was moved to :mod:`lino.modlib.memo`.
 
     """
-    default_ui = None  # TODO: rename this to front_end
-    admin_ui = None
+    # default_ui = None  # TODO: rename this to front_end
+    web_front_ends = None
+    # admin_ui = None
 
     def __init__(self, site):
         # logger.info("20140227 Kernel.__init__() a")
@@ -141,7 +138,8 @@ class Kernel(object):
           methods into Models that don't inherit from it.
 
         """
-        # logger.info("20161219 kernel_startup")
+        # logger.info("20231016 kernel_startup (%s)", site._history_aware_logging)
+        # print("20231019 kernel_startup()", site, site._history_aware_logging)
         if site._history_aware_logging:
             if len(sys.argv) == 0:
                 process_name = 'WSGI'
@@ -403,7 +401,7 @@ class Kernel(object):
         # ManyToManyField.
         for model in models_list:
             p = site.plugins.get(model._meta.app_label)
-            if not p.is_active():
+            if p.is_hidden():
                 # models of inactive plugins need no _lino_default_table
                 continue
             # Not getattr but __dict__.get because of the mixins.Listings
@@ -513,26 +511,51 @@ class Kernel(object):
         # self.html_renderer = HtmlRenderer(self)
         # self.text_renderer = TextRenderer(self)
 
-        for p in self.site.installed_plugins:
-            if p.app_name == self.site.default_ui:
-                if not p.force_url_prefix:
+        if self.site.web_front_ends is None:
+            # backwards compatibility
+            for p in self.site.installed_plugins:
+                if p.app_name == self.site.default_ui:
                     p.url_prefix = None
-                self.default_ui = p
-                self.html_renderer = HtmlRenderer(p)
-                self.text_renderer = TextRenderer(p)
+                    self.web_front_ends = [p]
+                    break
+        else:
+            lst = []
+            for prefix, modname in self.site.web_front_ends:
+                found = False
+                for p in self.site.installed_plugins:
+                    if p.app_name == modname:
+                        p.url_prefix = prefix
+                        lst.append(p)
+                        found = True
+                        break
+                if not found:
+                    raise Exception(
+                        f"Invalid modname {modname} in Site.web_front_ends")
+            self.web_front_ends = lst
+            # print("20230407 web front ends:")
+            # print("\n".join(["- {0.url_prefix} --> {0.app_name} {1}".format(p, hash(p))
+            #     for p in self.web_front_ends]))
+
+        for p in self.web_front_ends:
+            if p.ui_handle_attr_name is not None:
+                editing_wf = p
                 break
 
+        self.editing_front_end = editing_wf
+        self.html_renderer = HtmlRenderer(self.web_front_ends[0])
+        self.text_renderer = TextRenderer(editing_wf)
+
         for p in site.installed_plugins:
             p.on_ui_init(self)
 
-        self.default_renderer = self.default_ui.renderer
+        self.default_renderer = editing_wf.renderer
 
         site.resolve_virtual_fields()
 
-        if self.site.admin_ui is not None:
-            for p in self.site.installed_plugins:
-                if p.app_name == self.site.admin_ui:
-                    self.admin_ui  = p
+        # if self.site.admin_ui is not None:
+        #     for p in self.site.installed_plugins:
+        #         if p.app_name == self.site.admin_ui:
+        #             self.admin_ui  = p
 
         # site.user_roles = set()
         for a in actors.actors_list:
@@ -676,6 +699,7 @@ class Kernel(object):
             # raise Exception("20150330 %s", obj._meta.pk)
             return  # e.g. Country.iso_code is a CharField, cannot
                     # point to a country using GFK
+        assert not obj._meta.abstract
         obj_ct = ContentType.objects.get_for_model(obj.__class__)
         # logger.info("20150330 ok %s", obj_ct)
         for gfk in self.GFK_LIST:
@@ -685,6 +709,7 @@ class Kernel(object):
             kw = dict()
             kw[gfk.fk_field] = obj.pk
             kw[gfk.ct_field] = obj_ct
+            assert not gfk.model._meta.abstract
             ct = ContentType.objects.get_for_model(gfk.model)
             yield gfk, fk_field, ct.get_all_objects_for_this_type(**kw)
 
@@ -765,7 +790,7 @@ class Kernel(object):
                 A(obj2str(ar.master_instance))
                 A(obj2str(ar.selected_rows))
                 # A(format_request(ar.request))
-                logger.info("run_action {0}".format(' '.join(flds)))
+                ar.logger.info("run_action {0}".format(' '.join(flds)))
                 # logger.info("run_action {0}".format(ar))
         try:
             a.run_from_ui(ar)
@@ -773,7 +798,7 @@ class Kernel(object):
                 ar.set_response(master_data=ar.selected_rows[0].get_master_data(ar))
             if a.parameters and not a.no_params_window:
                 ar.set_response(close_window=True)
-        except exceptions.ValidationError as e:
+        except (ValidationError, IntegrityError) as e:
             # logger.info("20150127 run_action %r", e)
             ar.error(ar.ah.actor.error2str(e), alert=True)
         except Warning as e:
@@ -820,7 +845,7 @@ class Kernel(object):
     def must_build_site_cache(self):
         self._must_build = True
 
-    def make_cache_file(self, fn, write, force=False):
+    def make_cache_file(self, fn, write, force=False, verbosity=1):
         """Make the specified cache file.  This is used internally at server
         startup.
 
@@ -835,18 +860,20 @@ class Kernel(object):
         if not force and not self._must_build and exists(fn):
             mtime = os.stat(fn).st_mtime
             if mtime > self.code_mtime:
-                logger.debug("%s (%s) is up to date.", fn, time.ctime(mtime))
+                # logger.debug("%s (%s) is up to date.", fn, time.ctime(mtime))
                 return 0
 
-        # The following message is important to see in a developer
-        # console because the process takes some time and when
-        # developing you are watching at such messages. It should
-        # *not* be shown when running unit tests because its occurence
-        # is not (easily) predictable.  OTOH we would like it to be
-        # logged on a production site as well.
-        if self.site.is_demo_site:
-            logger.debug("Building %s ...", fn)
-        else:
+        # print("20231005 make_cache_file() {}".format(verbosity))
+
+        # The following message is important to see in a developer console
+        # because the process takes some time and when developing you are
+        # watching at such messages. It should *not* be shown when running unit
+        # tests because its occurence is not (easily) predictable.   On a
+        # production site we want it to be seen on the console and logged to the
+        # lino.log.
+        # if self.site.is_demo_site:
+        # if is_devserver():
+        if verbosity > 1:
             logger.info("Building %s ...", fn)
 
         self.site.makedirs_if_missing(dirname(fn))
