@@ -14,21 +14,21 @@ from builtins import object
 
 class Hotkey(object):
     "Represents a combination of keystrokes."
+    key = None
     keycode = None
     shift = False
     ctrl = False
     alt = False
-    inheritable = ('keycode', 'shift', 'ctrl', 'alt')
 
-    def __init__(self, **kw):
+    def __init__(self, key=None, **kw):
+        if key:
+            self.key = key.upper()
+            self.keycode = ord(self.key)
         for k, v in list(kw.items()):
             setattr(self, k, v)
 
-    def __call__(self, **kw):
-        for n in self.inheritable:
-            if not n in kw:
-                kw[n] = getattr(self, n)
-            return Hotkey(**kw)
+        self.__dict__.update(keycode=self.keycode, shift=self.shift,
+            key = self.key, ctrl=self.ctrl, alt=self.alt)
 
 # ExtJS src/core/EventManager-more.js
 RETURN = Hotkey(keycode=13)
@@ -37,5 +37,3 @@ PAGE_UP = Hotkey(keycode=33)
 PAGE_DOWN = Hotkey(keycode=34)
 INSERT = Hotkey(keycode=44)
 DELETE = Hotkey(keycode=46)
-
-
