@@ -5,7 +5,7 @@
 
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 import re
 
 from django.conf import settings
@@ -627,16 +627,20 @@ add_tabpanel() on %s horizontal 'main' panel %r."""
         #~ if kw:
             #~ print 20120525, self, self.detail_layout._element_options
 
-    def get_layout_handle(self):
+    def get_layout_handle(self, front_end=None):
         """
         Return the LayoutHandle for this layout.
         Create a LayoutHandle instance if this is the first call.
 
         20230217: Removed ui argument because we no longer have Lino sites with
-        several front ends
+        several front ends.
+
+        20230407: Restored `ui` argument, now named `front_end` because I
+        changed my mind.
 
         """
-        front_end = settings.SITE.kernel.default_ui
+        if front_end is None:
+            front_end = settings.SITE.kernel.editing_front_end
         hname = front_end.ui_handle_attr_name
         if hname is None:
             raise Exception(
@@ -820,7 +824,7 @@ class ActionParamsLayout(ParamsLayout):
         e.declare_type = jsgen.DECLARE_THIS
 
     def get_choices_url(self, ui, field, **kw):
-        return settings.SITE.kernel.default_ui.build_plain_url(
+        return settings.SITE.kernel.web_front_ends[0].build_plain_url(
             "apchoices",
             self._datasource.defining_actor.app_label,
             self._datasource.defining_actor.__name__,
