@@ -8,7 +8,7 @@ See :doc:`/dev/merge`.
 
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 from django.db import models
 from django.conf import settings
@@ -51,6 +51,8 @@ class MergeAction(actions.Action):
         # logger.info("20160621 MergeAction for %s : _lino_ddh.fklist is %s",
         #             model, model._lino_ddh.fklist)
         for m, fk in traverse_ddh_fklist(model):
+            if settings.SITE.is_hidden_plugin(m._meta.app_label):
+                continue
             if fk.name in m.allow_cascaded_delete:
                 fieldname = full_model_name(m, '_')
                 if fieldname not in keep_volatiles:
