@@ -9,7 +9,7 @@ See :ref:`dev.models`, :doc:`/dev/delete`, :doc:`/dev/disable`,
 
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 import copy
 
 from django.db import models
@@ -43,14 +43,6 @@ except ImportError:
 
 
 class Model(models.Model, fields.TableRow):
-    """
-    Lino's extension of the plain Django Model class.
-
-    .. method:: full_clean
-
-        This is defined by Django.
-
-    """
 
     class Meta(object):
         abstract = True
@@ -89,19 +81,7 @@ class Model(models.Model, fields.TableRow):
     preferred_foreignkey_width = None
 
     workflow_state_field = None
-    """If this is set on a Model, then it will be used as default value
-    for :attr:`workflow_state_field
-    <lino.core.table.Table.workflow_state_field>` of all tables based
-    on this Model.
-
-    """
-
     workflow_owner_field = None
-    """If this is set on a Model, then it will be used as default value
-    for :attr:`lino.core.table.Table.workflow_owner_field` on all
-    tables based on this Model.
-
-    """
 
     change_watcher_spec = None
     """
@@ -112,8 +92,6 @@ class Model(models.Model, fields.TableRow):
     # """Whether to disable any automatic creation by learning choosers.
     # """
 
-    summary_row_template = None
-
     _lino_tables = []
     _bleached_fields = []
 
@@ -577,12 +555,6 @@ class Model(models.Model, fields.TableRow):
             content = ""
         return tostring(E.h4(ar.obj2html(self))) + ar.parse_memo(content)
 
-    def as_story_item(self, ar):
-        if settings.SITE.is_installed('search') and issubclass(
-            ar.actor, settings.SITE.models.search.SiteSearchBase):
-            return self.as_search_item(ar)
-        return self.as_summary_row(ar)
-
     @property
     def edge_ngram_field(self):
         values = [str(getattr(self, field.name)) for field in self.quick_search_fields + self.quick_search_fields_digit]
@@ -602,20 +574,8 @@ class Model(models.Model, fields.TableRow):
         ar = self.__class__.get_default_table().request()
         return self.as_search_item(ar)
 
-    def as_summary_row(self, ar):
-        # used by tickets.Tickets table in the bootstrap frontend
-        # also when display_mode = ((None, constants.DISPLAY_MODE_STORY), ) it returns html
-        # text for the object that is calling
-        if self.summary_row_template:
-            # not tested
-            env = settings.SITE.plugins.jinja.renderer.jinja_env
-            template = env.get_template(self.summary_row_template)
-            context = ar.get_printable_context(obj=self)
-            return template.render(**context)
-        return tostring(E.p(*self.summary_row(ar)))
-
-    def summary_row(self, ar, **kw):
-        yield ar.obj2html(self)
+    # def summary_row(self, ar, **kw):
+    #     yield ar.obj2html(self)
 
     @displayfield(_("Name"), max_length=15)
     def name_column(self, ar):
@@ -665,7 +625,7 @@ class Model(models.Model, fields.TableRow):
         return ar.html_text(E.div(*items, **kwargs))
 
 
-    @displayfield(_("Workflow"), help_text="List of actions that change the workflow state of this object.")
+    @displayfield(_("Workflow"))
     def workflow_buttons(self, ar):
         if ar is None:
             return ''
@@ -974,6 +934,7 @@ LINO_MODEL_ATTRIBS = (
     'get_row_permission',
     # 'get_excerpt_options',
     # 'is_attestable',
+    'as_summary_row',
     'as_paragraph',
     'as_page',
     'get_data_elem',
@@ -987,7 +948,7 @@ LINO_MODEL_ATTRIBS = (
     'workflow_owner_field',
     'disabled_fields',
     'get_choices_text',
-    'summary_row',
+    # 'summary_row',
     'submit_insert',
     'active_fields',
     'hidden_columns',
@@ -1003,8 +964,6 @@ LINO_MODEL_ATTRIBS = (
     'as_search_item',
     'as_story_item',
     'haystack_rendered_field',
-    'as_summary_row',
-    'summary_row_template',
     'get_related_project',
     'obj2href',
     'quick_search_fields',
@@ -1035,7 +994,7 @@ def pre_delete_handler(sender, instance=None, **kw):
 
     It seems that Django deletes *generic related objects* only if
     the object being deleted has a `GenericRelation
-    <https://docs.djangoproject.com/en/4.1/ref/contrib/contenttypes/#django.contrib.contenttypes.fields.GenericRelation>`_
+    <https://docs.djangoproject.com/en/5.0/ref/contrib/contenttypes/#django.contrib.contenttypes.fields.GenericRelation>`_
     field (according to `Why won't my GenericForeignKey cascade
     when deleting?
     <https://stackoverflow.com/questions/6803018/why-wont-my-genericforeignkey-cascade-when-deleting>`_).
