@@ -7,8 +7,7 @@
 # import six
 # from builtins import object
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 from django.conf import settings
 
