@@ -5,16 +5,16 @@
 Defines :class:`HtmlRenderer` and :class:`TextRenderer`.
 """
 
+import os
 from html import escape
 import rstgen
 
 from django.conf import settings
 from django.db import models
 from django.db.models.fields import NOT_PROVIDED
+from django.utils.html import mark_safe
 # from django.utils.encoding import force_str
 from django.utils.text import format_lazy
-
-
 from django.utils.translation import gettext as _
 from django.utils.translation import get_language
 
@@ -23,13 +23,15 @@ from lino.utils import isiterable
 from lino.utils.jsgen import py2js, js_code
 from etgen.html import E, tostring, iselement, forcetext, to_rst
 from lino.core import constants
-from lino.core.site import html2text
+from lino.utils import html2text
 from lino.core.fields import TableRow
 
 from lino.core.menus import Menu, MenuItem
 # from etgen.html import _html2rst as html2rst
 # from etgen.html import html2rst
 
+from lino.modlib.users.utils import get_user_profile
+
 from .dashboard import DashboardItem
 from .views import json_response
 
@@ -130,6 +132,9 @@ class Renderer(object):
             kwargs[constants.URL_PARAM_FIELD_VALUES] = fv
         return kwargs
 
+    def build_js_cache(self, *args, **kwargs):
+        return 0
+
     # def render_action_response(self, ar):
     #     """In a plain HTML UI this will return a full HTML index page, in
     #     ExtJS it will return JSON code.
@@ -242,15 +247,17 @@ class HtmlRenderer(Renderer):
                     show_links=False, header_level=None, display_mode=None,
                     **kwargs):
         """
-        Returns a HTML element representing the given action request as a
+        Returns an HTML element representing the given action request as a
         table. See :meth:`ar.show
         <lino.core.request.BaseRequest.show>`.
 
         Silently ignores the parameters `stripped` and `header_links`
         since for HTML these options have no meaning.
         """
+        # print("20231227")
         if display_mode is None:
             display_mode = ar.actor.get_display_mode()
+        # yield E.p(display_mode)
         if not nosummary:
             if display_mode == constants.DISPLAY_MODE_SUMMARY:
                 yield ar.actor.get_table_summary(ar.master_instance, ar)
@@ -445,7 +452,7 @@ class HtmlRenderer(Renderer):
         return E.p(*buttons)
 
     def get_home_url(self, *args, **kw):
-        return settings.SITE.kernel.default_ui.build_plain_url(*args, **kw)
+        return settings.SITE.kernel.web_front_ends[0].build_plain_url(*args, **kw)
 
     def obj2url(self, ar, obj):
         ba = obj.get_detail_action(ar)
@@ -479,6 +486,8 @@ class HtmlRenderer(Renderer):
         ba = ar.bound_action
         label = label or ba.get_button_label()
         if ar._status is None:
+            # if ar.subst_user:
+            #     raise(Exception("20230331 {}".format(ar.subst_user)))
             ar._status = ar.get_status()
         js_handler = ba.action.js_handler
         if js_handler:
@@ -528,8 +537,8 @@ class HtmlRenderer(Renderer):
 
         kwargs[constants.URL_PARAM_ACTION_NAME] = ba.action.action_name
         arguments = ["api", str(ba.actor.app_label), str(ba.actor.__name__), str(obj.pk)]
-        if ar.hash_router:
-            arguments.insert(0, '#')
+        # if ar.hash_router:
+        #     arguments.insert(0, '#')
         return settings.SITE.buildurl(*arguments, **kwargs)
 
     def row_action_button(
@@ -623,7 +632,7 @@ class HtmlRenderer(Renderer):
         # print("20180907 show_story in {} : {}".format(ar.renderer, elems))
         # return E.div(*elems) if len(elems) else ""
         if len(elems):
-            return "<div>{}</div>".format(''.join(elems))
+            return mark_safe("<div>{}</div>".format(''.join(elems)))
         return ""
 
     def show_menu(self, ar, mnu, level=1):
@@ -941,14 +950,14 @@ class JsRenderer(HtmlRenderer):
 
         url = self.front_end.build_plain_url(
             ar.actor.app_label, ar.actor.__name__)
-        params = ar.get_status().get('base_params', None) # dont use **statuc on ar.get_status to not modify existing code.
-
-        rqData, xcallback = py2js(status.get("rqdata", None)), py2js(status.get("xcallback", None))
-        pp = "function() {return %s;}" % py2js(params)
+        rqData = py2js(status.get("rqdata", None))
+        xcallback = py2js(status.get("xcallback", None))
+        base_params = ar.get_status().get('base_params', None)  # dont use **status on ar.get_status() to not modify existing code.
+        pp = "function() {return %s;}" % py2js(base_params)
 
         return "Lino.list_action_handler(%s,%s,%s,%s,%s,%s)()" % (
             py2js(url), py2js(ba.action.action_name),
-            py2js(ba.action.http_method),pp, rqData, xcallback)
+            py2js(ba.action.http_method), pp, rqData, xcallback)
 
     def obj2url(self, ar, obj):
         ba = obj.get_detail_action(ar)
@@ -959,17 +968,18 @@ class JsRenderer(HtmlRenderer):
             return None
         if ar.permalink_uris:
             return self.get_detail_url(ar, ba.actor, obj.pk)
-        return self.js2url(self.instance_handler(ar, obj, None))
+        return self.js2url(self.instance_handler(ar, obj, ba))
 
 
     def add_help_text(self, kw, help_text, title, datasource, fieldname):
         if settings.SITE.use_quicktips:
+            title = title or ""
             if settings.SITE.show_internal_field_names:
-                ttt = "(%s.%s) " % (datasource, fieldname)
+                ttt = format_lazy("{} ({}.{})", title, datasource, fieldname)
             else:
-                ttt = ''
+                ttt = title
             if help_text:
-                ttt = format_lazy(u"{}{}", ttt, help_text)
+                ttt = format_lazy("{} : {}", ttt, help_text)
             if ttt:
                 # kw.update(qtip=self.field.help_text)
                 # kw.update(toolTipText=self.field.help_text)
@@ -979,3 +989,172 @@ class JsRenderer(HtmlRenderer):
                         py2js(title),
                         py2js(ttt)))
                 ))
+
+
+class JsCacheRenderer(JsRenderer):
+    """
+    Mixin for:
+    :class:`lino_react.react.renderer.Renderer`,
+    :class:`lino.modlib.extjs.ext_renderer.ExtRenderer` and
+    :class:`lino_extjs6.extjs.ext_renderer.ExtRenderer`.
+
+    Includes linoweb.js cacheing functionality.
+
+    """
+    lino_web_template = "extjs/linoweb.js"
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.prepare_layouts()
+
+    def write_lino_js(self, f):
+        """
+
+        :param f: File object
+        :return: 1
+        """
+        raise NotImplementedError("Need to implement a lino_web.js writing script")
+
+        user_type = get_user_profile()
+
+        context = dict(
+            ext_renderer=self,
+            site=settings.SITE,
+            settings=settings,
+            lino=lino,
+            language=get_language(),
+            # ext_requests=constants,
+            constants=constants,
+            extjs=self.plugin,  # 20171227
+        )
+
+        context.update(_=_)
+
+        tpl = self.linolib_template()
+
+        f.write(tpl.render(**context) + '\n')
+
+        return 1
+
+    def prepare_layouts(self):
+        from lino.core import kernel
+        self.actors_list = [
+            rpt for rpt in kernel.master_tables
+                           + kernel.slave_tables
+                           + list(kernel.generic_slaves.values())
+                           + kernel.virtual_tables
+                           + kernel.frames_list
+                           + list(kernel.CHOICELISTS.values())]
+
+        # self.actors_list.extend(
+        #     [a for a in kernel.CHOICELISTS.values()
+        #      if settings.SITE.is_installed(a.app_label)])
+
+        # don't generate JS for abstract actors
+        self.actors_list = [a for a in self.actors_list
+                            if not a.is_abstract()]
+
+        # Lino knows three types of form layouts:
+
+        self.form_panels = set()
+        self.param_panels = set()
+        self.action_param_panels = set()
+        self.other_panels = set()
+
+        def add(res, collector, fl, formpanel_name, choice_name=None):
+            # res: an actor class or action instance
+            # collector: one of form_panels, param_panels or
+            # action_param_panels
+            # fl : a FormLayout
+            # if str(fl).endswith("Given"):
+            #     print("20210223 add", fl)
+            # if str(res).endswith("MyCoursesGiven"):
+            #     print("20210223 gonna add {} for {}".format(fl, res))
+            if fl is None:
+                return
+            if fl._datasource is None:
+                # raise Exception("20210223 {}".format(res))
+                return  # 20130804
+
+            if fl._datasource != res:
+                fl.add_datasource(res)
+                # if str(res).endswith("MyCoursesGiven"):
+                #     print("20210223 added", fl._other_datasources)
+                # if str(res).startswith('newcomers.AvailableCoaches'):
+                #     logger.info("20150716 %s also needed by %s", fl, res)
+                # if str(res) == 'courses.Pupils':
+                #     print("20160329 ext_renderer.py {2}: {0} != {1}".format(
+                #         fl._datasource, res, fl))
+
+            if False:
+                try:
+                    lh = fl.get_layout_handle()
+                except Exception as e:
+                    # logger.exception(e)
+                    raise Exception("Could not define %s for %r: %s" % (
+                        formpanel_name, res, e))
+
+                # lh.main.loosen_requirements(res)
+                for e in lh.main.walk():
+                    e.loosen_requirements(res)
+
+            if fl not in collector:
+                fl._formpanel_name = formpanel_name
+                fl._url = res.actor_url()
+                if choice_name:
+                    fl.choice_name = choice_name
+                collector.add(fl)
+                # if str(res) == 'courses.Pupils':
+                #     print("20160329 ext_renderer.py collected {}".format(fl))
+
+        for res in self.actors_list:
+            add(res, self.form_panels, res.detail_layout,
+                "%s.DetailFormPanel" % res)
+            for name, fl in res.extra_layouts.items():
+                add(res, self.form_panels, fl,
+                    "{}._{}_DetailFormPanel".format(res, name), name)
+            add(res, self.form_panels, res.insert_layout,
+                "%s.InsertFormPanel" % res)
+            # if res.parameters is not None:
+            add(res, self.param_panels, res.params_layout,
+                "%s.ParamsPanel" % res)
+            add(res, self.other_panels, res.card_layout,
+                "%s.CardsPanel" % res)
+            add(res, self.other_panels, res.list_layout,
+                "%s.ItemsPanel" % res)
+
+            for ba in res.get_actions():
+                if ba.action.parameters:
+                    add(res, self.action_param_panels,
+                        ba.action.params_layout,
+                        "%s.%s_ActionFormPanel" % (res, ba.action.action_name))
+
+    def lino_js_parts(self):
+        user_type = get_user_profile()
+        filename = 'lino_'
+        file_type = self.lino_web_template.rsplit(".")[-1]
+        if user_type is not None:
+            filename += user_type.value + '_'
+        filename += get_language() + '.' + file_type
+        return ('cache', file_type, filename)
+
+    def linolib_template(self):
+        # env = jinja2.Environment(loader=jinja2.FileSystemLoader(
+        #     os.path.dirname(__file__)))
+        # return env.get_template('linoweb.js')
+        env = settings.SITE.plugins.jinja.renderer.jinja_env
+        return env.get_template(self.lino_web_template)
+
+
+    def build_js_cache(self, force, verbosity=1):
+        """Build the :term:`site cache` files for the current user type and the
+        current language.  If the file exists and is up to date, don't
+        generate it unless `force` is `True`.
+
+        """
+        fn = os.path.join(*self.lino_js_parts())
+
+        def write(f):
+            self.write_lino_js(f)
+
+        return settings.SITE.kernel.make_cache_file(fn, write, force, verbosity)
