@@ -1,13 +1,15 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2022 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 See introduction in :doc:`/dev/ar`.
 """
 
-import logging; logger = logging.getLogger(__name__)
 import html
-
+import logging
+from io import StringIO
+from lino import logger
+from contextlib import contextmanager
 from types import GeneratorType
 from copy import copy, deepcopy
 from xml.sax.saxutils import escape
@@ -18,10 +20,13 @@ from django.utils.translation import gettext
 from django.utils.translation import get_language, activate
 from django.utils import translation
 from django.utils import timezone
+from django.core.mail import send_mail
 from django.core import exceptions
 from django.db import models
 from lino.core import constants
 from lino.utils import AttrDict
+from lino.utils import MissingRow
+from lino.utils import html2text
 from etgen.html import E, tostring, iselement
 
 from lino.core import callbacks
@@ -33,15 +38,61 @@ from lino.core.diff import ChangeWatcher
 from lino.core.utils import getrqdata
 from lino.core.utils import obj2unicode
 from lino.core.utils import obj2str
+from lino.core.utils import UnresolvedModel
 from lino.core.exceptions import ChangedAPI
 
+try:
+    from django.contrib.contenttypes.models import ContentType
+except RuntimeError:
+    pass
+
+
+
 CATCHED_AJAX_EXCEPTIONS = (Warning, exceptions.ValidationError)
 
+PRINT_EMAIL = """send email
+Sender: {sender}
+To: {recipients}
+Subject: {subject}
+
+{body}
+"""
+
 
 def noop(ar):
     return ar.success(gettext("Aborted"))
 
 
+class StringLogger(logging.Logger):
+    # Instantiated by BaseRequest.capture_logger()
+
+    # format = '%(levelname)s: %(message)s'
+    # format = '%(levelname)s:%(name)s: %(message)s'
+    format = '%(message)s'
+
+    def __init__(self, parent, level):
+        super().__init__(parent.name+"~", level)
+        self.parent = parent
+        self.streamer = StringIO()
+        h = logging.StreamHandler(stream=self.streamer)
+        h.setFormatter(logging.Formatter(self.format))
+        self.addHandler(h)
+        # print("20231012", logging.getLevelName(self.level), self.__class__)
+
+    # def handle(self, record):
+    #     # print("20231012 handle", record)
+    #     assert self.parent is None
+    #     super().handle(record)
+    #     if True:  # logger.isEnabledFor(self.level):
+    #         logger.handle(record)
+
+    def getvalue(self):
+        return self.streamer.getvalue()
+
+    # def __str__(self):
+    #     return self.streamer.getvalue()
+
+
 class ValidActionResponses(object):
     """
     These are the allowed keyword arguments for :meth:`ar.set_response
@@ -113,6 +164,10 @@ class ValidActionResponses(object):
 
     refresh = None
     refresh_delayed_value = None
+    """
+    A string referencing an actor_id corresponding to a DelayedValue equivalent element
+    or boolean `True` meaning all the DelayedValue(s) should be refreshed.
+    """
     refresh_all = None
     close_window = None
     record_deleted = None
@@ -160,6 +215,8 @@ class ValidActionResponses(object):
 
     version_mismatch = False
 
+    editing_mode = False
+
 
 class VirtualRow(object):
 
@@ -189,7 +246,7 @@ class PhantomRow(VirtualRow):
 
 
 inheritable_attrs = frozenset(
-    'user subst_user renderer requesting_panel master_instance'.split())
+    'user subst_user renderer requesting_panel master_instance logger'.split())
 
 
 def bool2text(x):
@@ -200,7 +257,9 @@ def bool2text(x):
 
 class BaseRequest(object):
     """
-    Base class of all action requests.
+    Base class of all :term:`action requests <action request>`.
+
+    An action request represents the context in which an action is running.
     """
     user = None
     subst_user = None
@@ -235,13 +294,13 @@ class BaseRequest(object):
     See :ref:`permalink_uris` for details and test coverage.
     """
 
-    hash_router = False
-    """
-
-    Used in permalink URIs creation. Set this to `True` if the front_end root
-    has an hash router. Ex: `lino_react`.
-
-    """
+    # hash_router = False
+    # """
+    #
+    # Used in permalink URIs creation. Set this to `True` if the front_end root
+    # has an hash router. Ex: `lino_react`.
+    #
+    # """
 
     master_instance = None
     """
@@ -251,8 +310,7 @@ class BaseRequest(object):
 
     request = None
     """
-    The incoming Django HttpRequest object which caused this action
-    request.
+    The incoming Django HttpRequest object that caused this action request.
     """
 
     selected_rows = []
@@ -262,6 +320,7 @@ class BaseRequest(object):
     xcallback_answers = {}
 
     row_meta = None
+    logger = logger
 
     _status = None  # cache when get_status() is called multiple times
 
@@ -276,8 +335,8 @@ class BaseRequest(object):
             kw = self.parse_req(request, self.rqdata, **kw)
             if permalink_uris is None:
                 permalink_uris = False  # todo: which default value?
-            if hash_router is None:
-                hash_router = False
+            # if hash_router is None:
+            #     hash_router = False
         elif parent is not None:
             # if parent.actor is None:
             # 20190926 we want to have javascript extjs links in dasboard
@@ -305,13 +364,24 @@ class BaseRequest(object):
             # is_on_main_actor = False
             if permalink_uris is None:
                 permalink_uris = parent.permalink_uris
-            if hash_router is None:
-                hash_router = parent.hash_router
+            # if hash_router is None:
+            #     hash_router = parent.hash_router
 
         self.is_on_main_actor = is_on_main_actor
         self.permalink_uris = permalink_uris
-        self.hash_router = hash_router
+        # self.hash_router = hash_router
         self.setup(**kw)
+        if self.master is not None and settings.SITE.strict_master_check:
+            if self.master_instance is None:
+                raise exceptions.BadRequest(
+                    "Request on slave table {} has no master instance ({})".format(
+                        self.actor, locals()))
+            # if isinstance(self.master_instance, UnresolvedModel):
+            if isinstance(self.master_instance, MissingRow):
+                raise exceptions.BadRequest(self.master_instance)
+                # raise Exception(
+                #     "Invalid master type {} for slave request on {}".format(
+                #         self.master_instance, self.actor))
 
     def setup(self,
               user=None,
@@ -321,12 +391,15 @@ class BaseRequest(object):
               selected_rows=None,
               master=None,
               master_instance=None,
-              master_mk=None,
-              master_mt=None,
+              master_key=None,
+              master_type=None,
               limit=None,
+              logger=None,
               requesting_panel=None,
               renderer=None,
               xcallback_answers=None):
+        if logger is not None:
+            self.logger = logger
         self.requesting_panel = requesting_panel
         if user is None:
             self.user = settings.SITE.get_anonymous_user()
@@ -344,7 +417,16 @@ class BaseRequest(object):
             self.xcallback_answers = xcallback_answers
 
         self.master = master if master is not None else self.actor.master if self.actor is not None else None
-        self.master_instance = master_instance if master_instance is not None else self.get_master_instance(self.master, master_mk, master_mt)
+
+        # if str(self.actor) == 'outbox.MyOutbox':
+        #     if self.master_instance is None:
+        #         raise Exception("20230426 a {}".format(self.master))
+
+        if self.master is not None and self.master_instance is None:
+            # master_instance might have been inherited from parent
+            if master_instance is None:
+                master_instance = self.get_master_instance(self.master, master_key, master_type)
+            self.master_instance = master_instance
 
         # set_selected_pks() is called when the master_instance has been set.
         # e.g. SuggestedMovements.set_selected_pks() needs to know the voucher
@@ -355,6 +437,21 @@ class BaseRequest(object):
 
         self.row_meta = dict(meta=True)
 
+    @contextmanager
+    def capture_logger(self, level=logging.INFO):
+        old_logger = self.logger
+
+        try:
+            # We instantiate a temporary Logger object, which is not known by the
+            # root logger.
+            self.logger = StringLogger(old_logger, level)
+            # self.logger.parent =
+            yield self.logger
+
+        finally:
+            self.logger.streamer.flush()
+            self.logger = old_logger
+
     def get_row_classes(self, row):
         if self.actor is None or self.actor.get_row_classes is None:
             return
@@ -404,12 +501,10 @@ class BaseRequest(object):
             # logger.info("20150130 b %s", tab)
             self.set_response(active_tab=tab)
 
-        if not 'selected_pks' in kw:
+        if not 'selected_pks' in kw and not 'selected_rows' in kw:
             selected = rqdata.getlist(constants.URL_PARAM_SELECTED)
             kw.update(selected_pks=selected)
 
-
-
         kw.update(xcallback_answers={id: rqdata[id] for id in [
             callbackID for callbackID in rqdata.keys() if callbackID.startswith("xcallback__")]})
 
@@ -501,16 +596,9 @@ class BaseRequest(object):
         for n in ('Count', 'Sum', 'Max', 'Min', 'Avg', 'F'):
             kw[n] = getattr(models, n)
 
-        if False:  # 20150803 why was this?  It disturbed e.g. for the bs3
-            # language selector.
-            sar = copy(self)
-            sar.renderer = settings.SITE.kernel.html_renderer
-            kw['ar'] = sar
-        else:
-            kw['ar'] = self
-
         kw['_'] = gettext
         kw.update(
+            ar=self,
             E=E, tostring=tostring,
             dd=dd,
             rt=rt,
@@ -523,7 +611,7 @@ class BaseRequest(object):
             iif=iif,
             bool2text=bool2text,
             bool2js=lambda b: "true" if b else "false",
-            unicode=str,  # backwards-compatibility. In new template
+            unicode=str,  # backwards-compatibility. In new templates
             # you should prefer `str`.
             pgettext=pgettext,
             now=timezone.now(),
@@ -533,12 +621,11 @@ class BaseRequest(object):
             requested_language=get_language())
 
         def parse(s):
-            # Jinja doesn't like a name 'self' in the context which
+            # Jinja doesn't like a name 'self' in the context, which
             # might exist there in a backwards-compatible appypod
             # template:
             kw.pop('self', None)
-            return dd.plugins.jinja.renderer.jinja_env.from_string(
-                s).render(**kw)
+            return dd.plugins.jinja.renderer.jinja_env.from_string(s).render(**kw)
 
         kw.update(parse=parse)
         return kw
@@ -565,6 +652,9 @@ class BaseRequest(object):
         # note: ticket #523 was because the GET contained an empty pk ("&sr=")
 
     def get_master_instance(self, master, mk, mt):
+        # if str(self.actor) == 'comments.CommentsByRFC':
+        #     print("20230426 ", mt)
+
         master_instance = None
         if master is not None:
             if not isinstance(master, type):
@@ -572,25 +662,28 @@ class BaseRequest(object):
 
             # Convert MT to class
             if settings.SITE.is_installed('contenttypes'):
-                from django.contrib.contenttypes.models import ContentType
                 if (issubclass(master, models.Model)
-                        and (master is ContentType or master._meta.abstract)
-                        and mt is not None):
+                        and (master is ContentType or master._meta.abstract)):
                     try:
-                        master = ContentType.objects.get(
-                            pk=mt).model_class()
+                        master = ContentType.objects.get(pk=mt).model_class()
                     except ContentType.DoesNotExist:
-                        pass
+                        # master = UnresolvedModel  # (master, mt)
+                        raise exceptions.BadRequest(
+                            "Invalid master type {}".format(mt))
+                        # pass
                         # master is None
             pk = mk
-            if pk == '':
-                pk = None
-            if pk is not None:
+            # if pk == '':
+            #     pk = None
+            # if pk is not None:
+            if True:
                 master_instance = self.actor.get_master_instance(self, master, pk)
-                if master_instance is None:
-                    raise exceptions.ObjectDoesNotExist(
-                        "Invalid master key {0} for {1}".format(
-                            pk, self.actor))
+                # if master_instance is None:
+                #     master_instance = UnresolvedModel(master, pk)
+                    # raise exceptions.ObjectDoesNotExist(
+                    # raise exceptions.BadRequest(
+                    #     "No master {0}, {1} for {2}".format(
+                    #         master, pk, self.actor))
         return master_instance
 
     def get_permission(self):
@@ -687,31 +780,86 @@ class BaseRequest(object):
                 kw.update(message=message)
         self.set_response(**kw)
 
-    def append_message(self, level, msg, *args, **kw):
-        if args:
-            msg = msg % args
-        if kw:
-            msg = msg % kw
-        # print("20221124", msg)
-        k = level + '_message'
-        old = self.response.get(k, None)
-        if old is None:
-            self.response[k] = msg
-        else:
-            self.response[k] = old + '\n' + msg
-        # return self.success(*args,**kw)
+    # def append_message(self, level, msg, *args, **kw):
+    #     if args:
+    #         msg = msg % args
+    #     if kw:
+    #         msg = msg % kw
+    #     # print("20221124", msg)
+    #     k = level + '_message'
+    #     old = self.response.get(k, None)
+    #     if old is None:
+    #         self.response[k] = msg
+    #     else:
+    #         self.response[k] = old + '\n' + msg
+    #     # return self.success(*args,**kw)
+    #
+    # def debug(self, msg, *args, **kw):
+    #     if settings.SITE.verbose_client_info_message:
+    #         self.append_message('info', msg, *args, **kw)
+    #
+    # def info(self, msg, *args, **kw):
+    #     # deprecated?
+    #     self.append_message('info', msg, *args, **kw)
+    #
+    # def warning(self, msg, *args, **kw):
+    #     # deprecated?
+    #     self.append_message('warning', msg, *args, **kw)
 
-    def debug(self, msg, *args, **kw):
-        if settings.SITE.verbose_client_info_message:
-            self.append_message('info', msg, *args, **kw)
+    def debug(self, *args, **kwargs): self.logger.debug(*args, **kwargs)
+    def info(self, *args, **kwargs): self.logger.info(*args, **kwargs)
+    def warning(self, *args, **kwargs): self.logger.warning(*args, **kwargs)
 
-    def info(self, msg, *args, **kw):
-        # deprecated?
-        self.append_message('info', msg, *args, **kw)
+    def send_email(self, subject, sender, body, recipients):
+        """Send an email message with the specified arguments (the same
+signature as `django.core.mail.EmailMessage`.
 
-    def warning(self, msg, *args, **kw):
-        # deprecated?
-        self.append_message('warning', msg, *args, **kw)
+        `recipients` is an iterator over a list of strings with email
+        addresses. Any address containing '@example.com' will be
+        removed. Does nothing if the resulting list of recipients is
+        empty.
+
+        If `body` starts with "<", then it is considered to be HTML.
+
+        """
+        if '@example.com' in sender:
+            # used by book/lino_book/projects/noi1e/tests/test_notify.py
+            self.logger.debug(
+                "Ignoring email because sender is %s", sender)
+            self.logger.debug(PRINT_EMAIL.format(
+                subject=subject, sender=sender, body=body,
+                recipients=', '.join(recipients)))
+            return
+
+        recipients = [a for a in recipients if '@example.com' not in a]
+        if not len(recipients):
+            self.logger.info(
+                "Ignoring email '%s' because there is no recipient", subject)
+            # self.logger.info("Email body would have been %s", body)
+            return
+
+        self.logger.info(
+            "Send email '%s' from %s to %s", subject, sender, recipients)
+
+        kw = {}
+        if body.startswith('<'):
+            kw['html_message'] = body
+            body = html2text(body)
+        # self.logger.info("20161008b %r %r %r %r", subject, sender, recipients, body)
+        try:
+            send_mail(subject, body, sender, recipients, **kw)
+        except Exception as e:
+            self.logger.warning("send_mail() failed : %s", e)
+        # msg = EmailMessage(subject=subject,
+        #                    from_email=sender, body=body, to=recipients)
+
+        # from django.core.mail import EmailMessage
+
+        # msg = EmailMessage(subject=subject,
+        #                    from_email=sender, body=body, to=recipients)
+        # self.logger.info(
+        #     "Send email '%s' from %s to %s", subject, sender, recipients)
+        # msg.send()
 
     _confirm_answer = True
 
@@ -785,7 +933,7 @@ class BaseRequest(object):
         return self.renderer.ar2js(self, *args, **kwargs)
 
     def goto_pk(self, pk, text, **kwargs):
-        """Navigate to the record with the specified primary key.
+        """Return a HTML link that navigates to the record with the specified primary key.
 
         When `pk`  is `None`, returns just the text.
         The `text` argument is mandatory.
@@ -916,10 +1064,9 @@ class BaseRequest(object):
                        have the same result in a printed document or in a
                        tested spec).
 
-        :header_level: show also the table header (using specified
-                       level)
+        :header_level: show also the table header (using specified level)
 
-        :header_links: make headers clickable so that user can
+        :header_links: make column headers clickable so that user can
                        interactively change the sorting order.
 
         :language: overrides the default language used for headers and
@@ -1015,18 +1162,21 @@ class BaseRequest(object):
         switching language to default language.
 
         """
-        if translation.get_language() != settings.SITE.DEFAULT_LANGUAGE:
-            kw[constants.URL_PARAM_USER_LANGUAGE] = translation.get_language()
-        return self.renderer.get_home_url(*args, **kw)
+        # if translation.get_language() != settings.SITE.DEFAULT_LANGUAGE:
+        #     kw[constants.URL_PARAM_USER_LANGUAGE] = translation.get_language()
+        return self.renderer.get_home_url(self, *args, **kw)
 
     def get_request_url(self, *args, **kw):
-        """When called on a BaseRequest, this just redirects to home.
+        return self.renderer.get_request_url(self, *args, **kw)
 
-        """
-        return self.renderer.get_home_url(*args, **kw)
+    # def get_request_url(self, *args, **kw):
+    #     """When called on a BaseRequest, this just redirects to home.
+    #
+    #     """
+    #     return self.renderer.get_home_url(*args, **kw)
 
-    def summary_row(self, obj, **kwargs):
-        return obj.summary_row(self, **kwargs)
+    def row_as_summary(self, obj, **kwargs):
+        return obj.as_summary_row(self, **kwargs)
 
     def is_obvious_field(self, name):
         """
@@ -1036,7 +1186,7 @@ class BaseRequest(object):
         then the city field is "obvious" and doesn't need to be displayed for
         each partner.
 
-        This is used e.g. in customized :meth:`lino.core.model.Model.summary_row`
+        This is used e.g. in customized
         :meth:`lino.core.model.Model.as_summary_row` methods.
 
         General rule: in a request on a slave table, the master instance is
@@ -1161,6 +1311,7 @@ class BaseRequest(object):
                 if not ba.action.select_rows:
                     if ba.action.show_in_plain:
                         ir = ba.request_from(self)
+                        # assert ir.user is self.user
                         if ir.get_permission():
                             # try:
                             #     btn = ir.ar2button(**btnattrs)
@@ -1180,6 +1331,7 @@ class BaseRequest(object):
          permissions.
 
         """
+        # raise Exception("20230331 {}".format(self.subst_user))
         return self.renderer.ar2button(self, *args, **kwargs)
 
     def instance_action_button(self, ia, *args, **kwargs):
@@ -1344,12 +1496,52 @@ class BaseRequest(object):
         return E.a(text, href=url, **kw)
 
 
-class ActorRequest(BaseRequest):
-    """Base for :class:`ActionRequest`, but also used directly by
-    :meth:`lino.core.kernel.Kernel.run_callback`.
+class ActionRequest(BaseRequest):
+    """
+    Holds information about an individual web request and provides
+    methods like
+
+    - :meth:`get_user <lino.core.actions.BaseRequest.get_user>`
+    - :meth:`confirm <lino.core.actions.BaseRequest.confirm>`
+    - :meth:`spawn <lino.core.actions.BaseRequest.spawn>`
+
+    An `ActionRequest` is also a :class:`BaseRequest` and inherits its
+    methods.
+
+    An ActionRequest is instantiated from different shortcut methods:
+
+    - :meth:`lino.core.actors.Actor.request`
+    - :meth:`lino.core.actions.Action.request`
+
 
     """
     no_data_text = _("No data to display")
+    create_kw = None
+    renderer = None
+
+    offset = None
+    limit = None
+    order_by = None
+
+    def __init__(self, actor=None,
+                 unused_request=None, action=None, unused_renderer=None,
+                 rqdata=None,
+                 **kw):
+        # print("20170116 ActionRequest.__init__()", actor, kw)
+        assert unused_renderer is None
+        assert unused_request is None
+        self.actor = actor
+        self.rqdata = rqdata
+        self.bound_action = action or actor.default_action
+        BaseRequest.__init__(self, **kw)
+        if not actor.is_abstract():
+            self.ah = actor.get_request_handle(self)
+
+    def __str__(self):
+        return "{0} {1}".format(self.__class__.__name__, self.bound_action)
+
+    def __repr__(self):
+        return "{0} {1}".format(self.__class__.__name__, self.bound_action)
 
     def create_phantom_rows(self, **kw):
         # phantom row disturbs when there is an insert button in
@@ -1425,6 +1617,7 @@ class ActorRequest(BaseRequest):
             bp[constants.URL_PARAM_PROJECT] = self.current_project
 
         if self.subst_user is not None:
+            # raise Exception("20230331")
             bp[constants.URL_PARAM_SUBST_USER] = self.subst_user.id
         self._status = kw
         return kw
@@ -1451,8 +1644,8 @@ class ActorRequest(BaseRequest):
     #         actor = self.actor
     #     return super(ActorRequest, self).spawn(actor, **kw)
 
-    def summary_row(self, obj, **kwargs):
-        return self.actor.summary_row(self, obj, **kwargs)
+    def row_as_summary(self, obj, **kwargs):
+        return self.actor.row_as_summary(self, obj, **kwargs)
 
     def get_sum_text(self, sums):
         return self.actor.get_sum_text(self, sums)
@@ -1469,9 +1662,6 @@ class ActorRequest(BaseRequest):
     def render_to_dict(self):
         return self.bound_action.action.render_to_dict(self)
 
-    def get_request_url(self, *args, **kw):
-        return self.renderer.get_request_url(self, *args, **kw)
-
     def absolute_uri(self, *args, **kw):
         ar = self.spawn(*args, **kw)
         location = ar.get_request_url()
@@ -1499,52 +1689,6 @@ class ActorRequest(BaseRequest):
         return self.bound_action.action.run_from_code(self, *args, **kw)
 
 
-class ActionRequest(ActorRequest):
-    """
-    Holds information about an individual web request and provides
-    methods like
-
-    - :meth:`get_user <lino.core.actions.BaseRequest.get_user>`
-    - :meth:`confirm <lino.core.actions.BaseRequest.confirm>`
-    - :meth:`spawn <lino.core.actions.BaseRequest.spawn>`
-
-    An `ActionRequest` is also a :class:`BaseRequest` and inherits its
-    methods.
-
-    An ActionRequest is instantiated from different shortcut methods:
-
-    - :meth:`lino.core.actors.Actor.request`
-    - :meth:`lino.core.actions.Action.request`
-
-
-    """
-    create_kw = None
-    renderer = None
-
-    offset = None
-    limit = None
-    order_by = None
-
-    def __init__(self, actor=None,
-                 unused_request=None, action=None, unused_renderer=None,
-                 rqdata=None,
-                 **kw):
-        # print("20170116 ActionRequest.__init__()", actor, kw)
-        assert unused_renderer is None
-        assert unused_request is None
-        self.actor = actor
-        self.rqdata = rqdata
-        self.bound_action = action or actor.default_action
-        BaseRequest.__init__(self, **kw)
-        if not actor.is_abstract():
-            self.ah = actor.get_request_handle(self)
-
-    def __str__(self):
-        return "{0} {1}".format(self.__class__.__name__, self.bound_action)
-
-    def __repr__(self):
-        return "{0} {1}".format(self.__class__.__name__, self.bound_action)
-
     def setup(self,
               known_values=None,
               param_values=None,
@@ -1683,6 +1827,8 @@ class InstanceAction(object):
     def __init__(self, action, actor, instance, owner):
         # ~ print "Bar"
         # ~ self.action = action
+        if actor is None:
+            actor = instance.get_default_table()
         self.bound_action = actor.get_action_by_name(action.action_name)
         if self.bound_action is None:
             raise Exception("%s has not action %r" % (actor, action))
@@ -1706,7 +1852,7 @@ class InstanceAction(object):
         ar.selected_rows = [self.instance]
         return self.bound_action.action.run_from_code(ar, *args, **kw)
 
-    def run_from_ui(self, ar, **kw):
+    def run_from_ui(self, ar, *args, **kwargs):
         """
         Run this action on this instance in the given session, updating
         the response of the session.  Returns nothing.
@@ -1714,7 +1860,7 @@ class InstanceAction(object):
         # raise Exception("20170129 is this still used?")
         # kw.update(selected_rows=[self.instance])
         ar.selected_rows = [self.instance]
-        self.bound_action.action.run_from_ui(ar)
+        self.bound_action.action.run_from_ui(ar, *args, **kwargs)
 
     def request_from(self, ses, **kwargs):
         """
