@@ -48,12 +48,16 @@ class Anonymous(UserRole):
 class SiteUser(UserRole):
     """Every authenticated user has this role."""
 
-class Expert(SiteUser):
+class DataExporter(UserRole):
+    """A user who can export to xls and pdf."""
+
+class Expert(DataExporter):
     """
     A user with some expertise and more options than a beginner.
     """
 
-class SiteStaff(Expert):
+
+class SiteStaff(SiteUser, Expert):
     """
     A user who can configure site-wide functionality.
 
