@@ -24,7 +24,7 @@ Other usages:
 
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 import datetime
 
@@ -40,9 +40,7 @@ from lino.utils.jsgen import py2js
 from lino.utils.quantities import parse_decimal
 from lino.core.utils import getrqdata
 from lino.core.gfks import GenericForeignKey
-
 from lino.core import constants
-
 from lino.core import fields
 from lino.core import actors
 from lino.core import actions
@@ -53,7 +51,7 @@ from lino.utils import iif
 from lino.utils.format_date import fds
 from lino.core.requests import PhantomRow
 from lino.utils import IncompleteDate
-from lino.utils import DelayedValue
+from lino.core.utils import DelayedValue
 
 
 class StoreField(object):
@@ -676,7 +674,7 @@ class DisableEditingStoreField(SpecialStoreField):
 
 class BooleanStoreField(StoreField):
     """A :class:`StoreField` for
-    `BooleanField <https://docs.djangoproject.com/en/4.1/ref/models/fields/#booleanfield>`__.
+    `BooleanField <https://docs.djangoproject.com/en/5.0/ref/models/fields/#booleanfield>`__.
 
     """
 
@@ -786,7 +784,7 @@ class IntegerStoreField(StoreField):
 class AutoStoreField(StoreField):
 
     """A :class:`StoreField` for
-    `AutoField <https://docs.djangoproject.com/en/4.1/ref/models/fields/#autofield>`__
+    `AutoField <https://docs.djangoproject.com/en/5.0/ref/models/fields/#autofield>`__
 
     """
 
@@ -811,10 +809,10 @@ class DateStoreField(StoreField):
 
     def parse_form_value(self, v, obj, ar=None):
         if v:
-            v = datetime.date(*settings.SITE.parse_date(v))
-        else:
-            v = None
-        return v
+            try:
+                return datetime.date(*settings.SITE.parse_date(v))
+            except Exception as e:
+                raise Warning("Invalid date '{}'' : {}".format(v, e))
 
     def format_value(self, ar, v):
         """Return a plain textual representation of this value as a unicode
