@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Defines the `TableRequest` class.
@@ -16,6 +16,10 @@ from django.db import models
 from django.conf import settings
 from django.db.models.query import QuerySet
 from django.core.exceptions import ObjectDoesNotExist, SuspiciousOperation
+if settings.SITE.is_installed('contenttypes'):
+    from django.contrib.contenttypes.models import ContentType
+else:
+    ContentType = None
 
 from lino.core.utils import obj2str
 from lino.core.utils import format_request
@@ -24,9 +28,10 @@ from lino.core import constants
 from etgen import html as xghtml
 from etgen.html import E
 from lino.utils import jsgen
+from lino.utils import MissingRow
 from lino.core.utils import getrqdata
-from .fields import RemoteField, FakeField, TableRow
 
+from .fields import RemoteField, FakeField, TableRow
 from .requests import ActionRequest
 
 class SearchQuerySet:
@@ -246,41 +251,42 @@ class TableRequest(ActionRequest):
         - `master` is some abstract model
 
         - `master` is not a subclass of Model, e.g.
-          :class:`lino_xl.lib.polls.models.AnswersByResponse`, a
-          virtual table which defines :meth:`get_row_by_pk
+          :class:`lino_xl.lib.polls.AnswersByResponse`, a
+          virtual table that defines :meth:`get_row_by_pk
           <lino.core.actors.Actor.get_row_by_pk>`.
 
         """
         # logger.info("20120723 %s.parse_req() %s", self.actor, rqdata)
         # ~ rh = self.ah
-        if "master_instance" not in kw:
-            kw.update(master_mt=rqdata.get(constants.URL_PARAM_MASTER_TYPE, None),
-                      master_mk=rqdata.get(constants.URL_PARAM_MASTER_PK, None))
 
-        if settings.SITE.use_filterRow:
-            exclude = dict()
-            for f in self.ah.store.fields:
-                if f.field:
-                    filterOption = rqdata.get(
-                        'filter[%s_filterOption]' % f.field.name)
-                    if filterOption == 'empty':
-                        kw[f.field.name + "__isnull"] = True
-                    elif filterOption == 'notempty':
-                        kw[f.field.name + "__isnull"] = False
-                    else:
-                        filterValue = rqdata.get('filter[%s]' % f.field.name)
-                        if filterValue:
-                            if not filterOption:
-                                filterOption = 'contains'
-                            if filterOption == 'contains':
-                                kw[f.field.name + "__icontains"] = filterValue
-                            elif filterOption == 'doesnotcontain':
-                                exclude[f.field.name +
-                                        "__icontains"] = filterValue
-                            else:
-                                print("unknown filterOption %r" % filterOption)
-            if len(exclude):
-                kw.update(exclude=exclude)
+        if "master_instance" not in kw:
+            kw.update(master_type=rqdata.get(constants.URL_PARAM_MASTER_TYPE, None),
+                      master_key=rqdata.get(constants.URL_PARAM_MASTER_PK, None))
+
+        # if settings.SITE.use_filterRow:
+        #     exclude = dict()
+        #     for f in self.ah.store.fields:
+        #         if f.field:
+        #             filterOption = rqdata.get(
+        #                 'filter[%s_filterOption]' % f.field.name)
+        #             if filterOption == 'empty':
+        #                 kw[f.field.name + "__isnull"] = True
+        #             elif filterOption == 'notempty':
+        #                 kw[f.field.name + "__isnull"] = False
+        #             else:
+        #                 filterValue = rqdata.get('filter[%s]' % f.field.name)
+        #                 if filterValue:
+        #                     if not filterOption:
+        #                         filterOption = 'contains'
+        #                     if filterOption == 'contains':
+        #                         kw[f.field.name + "__icontains"] = filterValue
+        #                     elif filterOption == 'doesnotcontain':
+        #                         exclude[f.field.name +
+        #                                 "__icontains"] = filterValue
+        #                     else:
+        #                         print("unknown filterOption %r" % filterOption)
+        #     if len(exclude):
+        #         kw.update(exclude=exclude)
 
         if settings.SITE.use_gridfilters:
             filter = rqdata.get(constants.URL_PARAM_GRIDFILTER, None)
@@ -290,6 +296,9 @@ class TableRequest(ActionRequest):
 
         kw = ActionRequest.parse_req(self, request, rqdata, **kw)
 
+        # if str(self.actor) == 'comments.CommentsByRFC':
+        #     print("20230426", kw)
+
         # ~ kw.update(self.report.known_values)
         # ~ for fieldname, default in self.report.known_values.items():
         # ~ v = request.REQUEST.get(fieldname,None)
@@ -309,6 +318,7 @@ class TableRequest(ActionRequest):
                 # field without sortable_by.
             else:
                 sort = [sort]
+            # print("20231006 sort", sortfld, sort)
             if sort is not None:
                 def si(k):
                     if k[0] == '-':
@@ -361,33 +371,36 @@ class TableRequest(ActionRequest):
 
         if title is not None:
             self.title = title
+        if offset is not None:
+            self.offset = offset
+        if limit is not None:
+            self.limit = limit
 
-        ActionRequest.setup(self, **kw)
-
+        super().setup(**kw)
         self.actor.setup_request(self)
 
+        # if str(self.actor) == 'outbox.MyOutbox':
+        #     if self.master_instance is None:
+        #         raise Exception("20230426 b {}".format(self.master))
+
         if isinstance(self.actor.master_field, RemoteField):
             # cannot insert rows in a slave table with a remote master
             # field
             self.create_kw = None
+        elif isinstance(self.master_instance, MissingRow):
+            self.create_kw = None  # 20230426
         else:
             self.create_kw = self.actor.get_filter_kw(self)
 
-        if offset is not None:
-            self.offset = offset
 
-        if limit is not None:
-            self.limit = limit
-
-    def get_master_instance(self, master, mk, mt):
+    def get_master_instance_unused(self, master, mk, mt):
         master_instance = None
         if master is not None:
             if not isinstance(master, type):
                 raise Exception("20150216 not a type: %r" % master)
 
             # Convert MT to class
-            if settings.SITE.is_installed('contenttypes'):
-                from django.contrib.contenttypes.models import ContentType
+            if ContentType is not None:
                 if (issubclass(master, models.Model)
                         and (master is ContentType or master._meta.abstract)
                         and mt is not None):
@@ -397,18 +410,19 @@ class TableRequest(ActionRequest):
                         pass
                         # master is None
             pk = mk
-            if pk == '':
-                pk = None
-            if pk is not None:
+            # if pk == '':
+            #     pk = None
+            # if pk is not None:
+            if True:
                 master_instance = self.actor.get_master_instance(self, master, pk)
-                if master_instance is None:
-                    raise ObjectDoesNotExist(
-                        "Invalid master key {0} for {1}".format(
-                            pk, self.actor))
+                # if master_instance is None:
+                #     raise ObjectDoesNotExist(
+                #         "Invalid master key {0} for {1}".format(
+                #             pk, self.actor))
         return master_instance
 
-    def summary_row(self, obj, **kwargs):
-        return self.actor.summary_row(self, obj, **kwargs)
+    def row_as_summary(self, obj, **kwargs):
+        return self.actor.row_as_summary(self, obj, **kwargs)
 
     def row_as_page(self, row, **kwargs):
         return self.actor.row_as_page(self, row, **kwargs)
@@ -708,7 +722,8 @@ class TableRequest(ActionRequest):
         """
         if self._status is not None and not kw:
             return self._status
-        self._status = kw = ActionRequest.get_status(self, **kw)
+        # print("20230331 712 get_status() {}".format(self.subst_user))
+        self._status = kw = super().get_status(**kw)
         bp = kw['base_params']
         if self.quick_search:
             bp[constants.URL_PARAM_FILTER] = self.quick_search
@@ -727,9 +742,9 @@ class TableRequest(ActionRequest):
         if self.master_instance is not None:
             if isinstance(self.master_instance, (models.Model, TableRow)):
                 bp[constants.URL_PARAM_MASTER_PK] = self.master_instance.pk
-                if (isinstance(self.master_instance, models.Model) and
-                        settings.SITE.is_installed('contenttypes')):
-                    from django.contrib.contenttypes.models import ContentType
+                if ContentType is not None and isinstance(
+                        self.master_instance, models.Model):
+                    assert not self.master_instance._meta.abstract
                     mt = ContentType.objects.get_for_model(
                         self.master_instance.__class__).pk
                     bp[constants.URL_PARAM_MASTER_TYPE] = mt
@@ -738,8 +753,10 @@ class TableRequest(ActionRequest):
                 #                    self.master_instance,
                 #                    ContentType)
             else:  # if self.master is None:
+                # e.g. in ledger.MovementsByMatch the master is a `str`
                 bp[constants.URL_PARAM_MASTER_PK] = self.master_instance
-
+                # raise Exception("No master key for {} {!r}".format(
+                #     self.master_instance.__class__, self.master_instance))
         return kw
 
     def __repr__(self):
