@@ -1,18 +1,19 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2022 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Defines the classes :class:`AbstractTable` and
 :class:`VirtualTable`.
 
 """
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 from future.utils import with_metaclass
 
 import os
 import yaml
 
 from django.db import models
+from django.db.utils import OperationalError, ProgrammingError
 from django.conf import settings
 from django.utils.translation import gettext_lazy as _
 
@@ -24,8 +25,8 @@ from lino.core.utils import resolve_fields_list
 from lino.core.tablerequest import TableRequest
 
 
-class InvalidRequest(Exception):
-    pass
+# class InvalidRequest(Exception):
+#     pass
 
 
 if False:  # 20130710
@@ -101,7 +102,7 @@ class TableHandle(object):
     """
     For every table we create one "handle" per renderer.
 
-    See also :meth:`lino.core.actors.Actor.setup_handle` which is called during
+    See also :meth:`lino.core.actors.Actor.setup_handle`, which is called during
     startup and sets more attributes.
 
     """
@@ -389,7 +390,7 @@ class AbstractTable(actors.Actor):
     order_by = None
     """If specified, this must be a tuple or list of field names that
 will be passed to Django's `order_by
-<https://docs.djangoproject.com/en/4.1/ref/models/querysets/#order-by>`__
+<https://docs.djangoproject.com/en/5.0/ref/models/querysets/#order-by>`__
 method in order to sort the rows of the queryset.
 
     """
@@ -398,7 +399,7 @@ method in order to sort the rows of the queryset.
     """If specified, this must be a `models.Q` object (not a dict of
     (fieldname -> value) pairs) which will be passed to Django's
     `filter
-    <https://docs.djangoproject.com/en/4.1/ref/models/querysets/#filter>`__
+    <https://docs.djangoproject.com/en/5.0/ref/models/querysets/#filter>`__
     method.
 
     Note that if you allow a user to insert rows into a filtered
@@ -414,14 +415,14 @@ method in order to sort the rows of the queryset.
     One advantage of :attr:`filter` over
     :attr:`known_values  <lino.core.actors.Actor.known_values>`
     is that this can use the full range of Django's `field lookup methods
-    <https://docs.djangoproject.com/en/4.1/topics/db/queries/#field-lookups>`_
+    <https://docs.djangoproject.com/en/5.0/topics/db/queries/#field-lookups>`_
 
     """
 
     exclude = None
     """If specified, this must be dict which will be passed to Django's
     `exclude
-    <https://docs.djangoproject.com/en/4.1/ref/models/querysets/#exclude>`__
+    <https://docs.djangoproject.com/en/5.0/ref/models/querysets/#exclude>`__
     method on the queryset.
 
     """
@@ -514,18 +515,19 @@ method in order to sort the rows of the queryset.
 
     @classmethod
     def row_as_paragraph(cls, ar, row):
-        """Return a HTML string that represents the given row as a list item.
+        """Return an HTML string that represents the given row as a single
+        paragraph.
 
         See :ref:`dev.as_paragraph`.
         """
         return row.as_paragraph(ar)
 
     @classmethod
-    def row_as_page(cls, ar, row):
-        """Yield a series HTML strings that represent the given row as a plain page.
-
+    def row_as_page(cls, ar, row, **kwargs):
         """
-        return row.as_page(ar)
+        Return an HTML string that represent the given row as a plain page.
+        """
+        return row.as_page(ar, **kwargs)
 
     @classmethod
     def get_actor_editable(self):
@@ -644,6 +646,7 @@ method in order to sort the rows of the queryset.
         kw.update(actor=self)
         if master_instance is not None:
             kw.update(master_instance=master_instance)
+        kw.setdefault('action', self.default_action)
         return TableRequest(**kw)
 
     @classmethod
@@ -702,14 +705,14 @@ class VirtualTable(AbstractTable):
 class VentilatedColumns(VirtualTable):
     """
     A mixin for tables that have a series of automatically generated
-    columns
+    columns.  TODO: rename this to DynamicColumns.
     """
     ventilated_column_suffix = ':5'
 
     column_names_template = ''
     """
     The template to use for :attr:`column_names`.   It should contain a string
-    ``{vcolumns}`` which will be replaced by a space-separated list of the column
+    ``{vcolumns}``, which will be replaced by a space-separated list of the column
     names given by :meth:`get_ventilated_columns`.
     """
 
@@ -721,10 +724,13 @@ class VentilatedColumns(VirtualTable):
         #     return
         # self.column_names = 'description '
         names = ''
-        for i, vf in enumerate(self.get_ventilated_columns()):
-            self.add_virtual_field('vc' + str(i), vf)
-            names += ' ' + vf.name + self.ventilated_column_suffix
-
+        try:
+            for i, vf in enumerate(self.get_ventilated_columns()):
+                self.add_virtual_field('vc' + str(i), vf)
+                names += ' ' + vf.name + self.ventilated_column_suffix
+        except (OperationalError, ProgrammingError) as e:
+            # Error can differ depending on the database engine.
+            logger.debug("Failed to load ventilated columns : %s", e)
         self.column_names = self.column_names_template.format(vcolumns=names)
 
         #~ logger.info("20131114 setup_columns() --> %s",self.column_names)
