@@ -20,24 +20,17 @@ from lino.core.site import has_socialauth
 # we must explicitly call django.setup() because when running under
 # mod_wsgi this is not done automatically as with runserver (or at
 # least it seems so)
-import lino
-lino.startup()
-
+if False:  # deactivated 20230423 to see whether it is still needed
+    import lino
+    lino.startup()
 
 site = settings.SITE
+
 urlpatterns = []
 
 prefix = ''
-publisher = None
-if site.is_installed('publisher'):
-    p = site.plugins.publisher
-    if p.home_view is not None:
-        prefix = p.admin_location[1:]
-        publisher = p.app_label
-
-if publisher is None:
-    if site.site_prefix:
-        prefix = site.site_prefix[1:]
+if site.site_prefix:
+    prefix = site.site_prefix[1:]
 rx = '^' + prefix
 
 for p in site.installed_plugins:
@@ -46,17 +39,12 @@ for p in site.installed_plugins:
     if not pat:
         continue
 
+    # print("20230407 add patterns from {} ({} {})".format(p.app_name, p.url_prefix, hash(p)))
+
     prx = rx
     if p.url_prefix:
         prx += p.url_prefix + "/"
 
-    if p.app_label == publisher:
-        if p.home_view is not None:
-            if p.url_prefix:
-                prx = '^' + p.url_prefix + '/'
-            else:
-                prx = '^'
-
     if prx == '^':
         urlpatterns += pat
     else:
@@ -66,8 +54,6 @@ if has_socialauth and site.social_auth_backends:
     urlpatterns.append(
         url('^oauth/', include('social_django.urls', namespace='social')))
 
-
-
 if site.django_admin_prefix:  # not tested
     from django.contrib import admin
     admin.autodiscover()
