@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2010-2021 Rumma & Ko Ltd
+# Copyright 2010-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 A collection of utilities which require Django settings to be
@@ -11,6 +11,7 @@ import sys
 import datetime
 # import yaml
 
+from django.utils.html import mark_safe
 from django.db import models
 from django.db.models import Q
 from django.core.exceptions import FieldDoesNotExist
@@ -37,38 +38,37 @@ validate_url = URLValidator()
 def djangoname(o):
     return o.__module__.split('.')[-2] + '.' + o.__name__
 
-def comma():
-    return ', '
+# def comma():
+#     return ', '
 
 
-def qs2summary(ar, objects, separator=comma, max_items=5, **kw):
+def qs2summary(ar, objects, separator=", ", max_items=5, **kw):
     """Render a collection of objects as a single paragraph.
 
-    :param separator: separator to use between objects. This must be a callable.
+    :param separator: separator to use between objects.
     :param max_items: don't include more than the specified number of items.
 
-    The separator must be a callable because with etree you may not reuse a same
-    element instance several times.
-
     """
-    elems = []
+    elems = ""
     n = 0
     for i in objects:
         if n:
-            elems.append(separator())
+            elems += separator
         n += 1
-        elems.extend(ar.summary_row(i, **kw))
+        elems += ar.row_as_summary(i, **kw)
         if n >= max_items:
-            elems += [separator(), '...']
+            elems += separator + '...'
             break
-    return elems
+    # return mark_safe("<p>{}</p>".format(elems))
+    return mark_safe(elems)
+
 
 
 def getrqdata(request):
     """Return the request data.
 
     Unlike the now defunct `REQUEST
-    <https://docs.djangoproject.com/en/4.1/ref/request-response/#django.http.HttpRequest.REQUEST>`_
+    <https://docs.djangoproject.com/en/5.0/ref/request-response/#django.http.HttpRequest.REQUEST>`_
     attribute, this inspects the request's `method` in order to decide
     what to return.
 
@@ -119,17 +119,32 @@ def is_devserver():
     - Added the `len(sys.argv) > 1` test because in a wsgi application
       the process is called without arguments.
     - Not only for `runserver` but also for `testserver` and `test`.
+    - pytest removes the first item from sys.argv when running doctests
 
     """
     #~ print 20130315, sys.argv[1]
+    if sys.argv[0].startswith("-"):
+        return True  # doctest under pytest
     if len(sys.argv) <= 1:
         return False
     # if sys.argv[0] == 'daphne':
     #    return True
-    if sys.argv[0].endswith("doctest.py") or sys.argv[0].endswith("doctest_utf8.py"):
+    # if sys.argv[0].endswith("doctest.py") or sys.argv[0].endswith("doctest_utf8.py"):
+    if sys.argv[0].endswith("doctest.py") or sys.argv[0].endswith("pytest"):
         return True
     if sys.argv[1] in ('runserver', 'testserver', 'test', "makescreenshots", 'shell'):
         return True
+    # print(sys.argv[1])
+    return False
+
+
+def is_logserver():
+    if sys.argv[0].startswith("-"):
+        return False  # doctest under pytest
+    if len(sys.argv) <= 1:
+        return False
+    if sys.argv[1] in ('lino_runworker', 'linod'):
+        return True
     return False
 
 
@@ -854,6 +869,8 @@ def traverse_ddh_fklist(model, ignore_mti_parents=True):
     is only one).
 
     """
+    # if settings.SITE.is_hidden_plugin(model._meta.app_label):
+    #     return
     found = set()
     for base in model.mro():
         ddh = getattr(base, '_lino_ddh', None)
@@ -871,3 +888,34 @@ def traverse_ddh_fklist(model, ignore_mti_parents=True):
                     #             fk, fk.__class__)
                     found.add(k)
                     yield k
+
+
+def DelayedValue(ar, fieldname, obj):
+    # return dict(delayed_value_url=settings.SITE.buildurl("values",
+    #     str(ar.actor).replace(".","/"), str(obj.pk), fieldname, mk=ar.master_instance.pk))
+    return dict(delayed_value_url="values/{}/{}/{}".format(
+            str(ar.actor).replace(".","/"), obj.pk, fieldname))
+
+# class DelayedValue:
+#     """
+#
+#     Creates an url for the related value and passes it to the frontend for the
+#     value to be fetched later by the frontend.
+#
+#     """
+#
+#     def __init__(self, actor, fieldname, obj):
+#         if fieldname is None:
+#             raise Exception("20210617 {}".format(field))
+#         # a = ar.actor
+#         self.url = "values/{}/{}/{}".format(
+#             str(actor).replace(".","/"), obj.pk, fieldname)
+#         # print(self, self.url)
+#         # self.field = field
+#         # self.obj = obj
+#
+#     def get_url(self):
+#         return self.url
+#
+#     def __repr__(self):
+#         return "DelayedValue({})".format(self.url)
