@@ -226,7 +226,7 @@ class ChangeStateAction(actions.Action):
     called `mark_XXX`
     """
 
-    show_in_bbar = False
+    show_in_toolbar = False
     show_in_workflow = True
     readonly = False
     # sort_index = 200
