@@ -3,11 +3,10 @@
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from io import open
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 from decimal import Decimal
-import argparse
 
 from clint.textui import progress
 
@@ -15,7 +14,9 @@ from django.db import models
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
 from django.db.utils import DatabaseError
-from django.utils.timezone import make_naive, is_aware, utc
+from django.utils.module_loading import import_string
+from django.utils.timezone import make_naive, is_aware
+from datetime import timezone; utc = timezone.utc
 
 from lino.utils import puts
 from lino.core.utils import sorted_models_list, full_model_name
@@ -141,14 +142,22 @@ class Command(BaseCommand):
 ''' % (settings.SETTINGS_MODULE, settings.TIME_ZONE))
 
         self.stream.write('''
-from __future__ import unicode_literals
+from lino import logger
 
-import logging
-logger = logging.getLogger('%s')
-
-''' % __name__)
+''')
 
         self.stream.write('SOURCE_VERSION = %r\n' % str(current_version))
+
+        appnames = {p.app_name.split('.')[0] for p in settings.SITE.installed_plugins if (
+            _ := lambda x: [1 for p in settings.SITE.migratable_plugin_prefixes + ['lino']
+                            if x.app_name.startswith(p)]
+        )(p)}
+        os_dict = {appname: import_string(f"{appname}.__version__") for appname in appnames}
+        # double-dump test would fail if OTHER_SOURCES is in default repr() with
+        # arbitrary ordering of keys.
+        os_dict = repr(dict(sorted(os_dict.items())))
+        self.stream.write(f"OTHER_SOURCES = {os_dict}\n")
+
         self.stream.write('''
 import os
 import six
@@ -156,7 +165,8 @@ from decimal import Decimal
 from datetime import datetime
 from datetime import time, date
 from django.conf import settings
-from django.utils.timezone import make_aware, utc
+from django.utils.timezone import make_aware
+from datetime import timezone; utc = timezone.utc
 from django.core.management import call_command
 # from django.contrib.contenttypes.models import ContentType
 from lino.utils.dpy import create_mti_child
