@@ -1,7 +1,8 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2019-2021 Rumma & Ko Ltd
+# Copyright 2019-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
+import sys
 import subprocess
 from rstgen.utils import confirm
 from django.core.management.base import BaseCommand
@@ -23,7 +24,7 @@ def runcmd(cmd, **kw):  # same code as in getlino.py
 class Command(BaseCommand):
     help = "Run 'pip install --upgrade' for all Python packages required by this site."
 
-    requires_system_checks = False
+    requires_system_checks = []
 
     def add_arguments(self, parser):
         parser.add_argument('--noinput', action='store_false',
