@@ -7,10 +7,8 @@ Writes screenshots to <project_dir>/media/cache/screenshots
 """
 # from future import standard_library
 # standard_library.install_aliases()
-from builtins import str
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 import subprocess
 import os
