@@ -1,13 +1,11 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2011 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 Generate the local files for running :mod:`lino.ui.qx`.
 """
-from __future__ import print_function
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 import sys
 import os
@@ -22,8 +20,8 @@ from shutil import copytree, rmtree
 
 from django.db import models
 from django.conf import settings
-from django.utils.translation import ugettext as _
-from django.utils.encoding import force_text
+from django.utils.translation import gettext as _
+from django.utils.encoding import force_str
 from django.core.management import call_command
 from django.core.management.base import BaseCommand, CommandError
 from django.db.models import loading
@@ -37,7 +35,7 @@ from lino.utils import confirm
 import rstgen
 from lino.core.menus import Menu, MenuItem
 from lino.utils import jsgen
-from lino.management.commands.makedocs import GeneratingCommand
+from lino.management.commands.makehelp import GeneratingCommand
 
 
 def a2class(a):
