@@ -1,12 +1,11 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2012-2021 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 # from future import standard_library
 # standard_library.install_aliases()
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 import errno
@@ -18,8 +17,8 @@ from os.path import join
 from django.db import models
 from django.conf import settings
 from django.utils import timezone
-from django.utils.translation import ugettext as _
-from django.utils.encoding import force_text
+from django.utils.translation import gettext as _
+from django.utils.encoding import force_str
 from django.core.management import call_command
 from django.core.management.base import BaseCommand, CommandError
 
