@@ -1,9 +1,9 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2020 by Rumma & Ko Ltd.
+# Copyright 2020-2021 by Rumma & Ko Ltd.
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
-This defines the :manage:`passwd` management command.
+This defines the :manage:`passwd` command.
 
 See :doc:`/dev/users`.
 
