@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2012-2013 Luc Saffre
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 Not yet implemented.
@@ -16,8 +16,7 @@ as DIR1 and `userdocs/scrennshots`
 
 """
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 import errno
@@ -30,7 +29,7 @@ from os.path import join
 from multiprocessing import Process
 
 from django.db import models
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.utils import translation
 from django.core.management.base import BaseCommand, CommandError
 
