@@ -174,12 +174,12 @@ class ProjectRelated(model.Model):
     #     if ar.actor.master_key and ar.actor.master_key == "project":
     #         self.project = ar.master_instance
 
-    def summary_row(self, ar, **kwargs):
-        s = list(super(ProjectRelated, self).summary_row(ar, **kwargs))
+    def as_summary_row(self, ar, **kwargs):
+        s = super().as_summary_row(ar, **kwargs)
         # s = [ar.obj2html(self)]
         if settings.SITE.project_model:
             if self.project and not ar.is_obvious_field("project"):
-                s += [" (", ar.obj2html(self.project), ")"]
+                s += " ({)}".format(ar.obj2htmls(self.project))
         return s
 
     def update_owned_instance(self, controllable):
@@ -282,4 +282,4 @@ from lino.mixins.polymorphic import Polymorphic
 from lino.utils.mldbc.fields import BabelCharField, BabelTextField
 from lino.utils.mldbc.mixins import BabelNamed, BabelDesignated
 
-from lino.mixins.human import Human, Born
+from lino.mixins.human import Human
