@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright 2008-2020 Rumma & Ko Ltd
+# Copyright 2008-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 
 See test cases and examples in :doc:`/specs/human`.
 
 """
-
 import datetime
 from dateutil.relativedelta import relativedelta
 
@@ -18,7 +17,6 @@ from django.conf import settings
 
 from lino.utils import join_words
 from lino.api.dd import Genders
-
 from lino.core import fields
 from lino.core import model
 
@@ -303,34 +301,10 @@ class Human(model.Model):
 
     @classmethod
     def get_simple_parameters(cls):
-        for p in super(Human, cls).get_simple_parameters():
+        for p in super().get_simple_parameters():
             yield p
         yield 'gender'
 
-    # no longer needed after 20170826
-    # @classmethod
-    # def setup_parameters(cls, **fields):
-    #     fields.update(
-    #         gender=Genders.field(
-    #             blank=True, help_text=_(
-    #                 "Show only persons with the given gender.")))
-    #     return super(Human, cls).setup_parameters(**fields)
-
-    # @classmethod
-    # def get_request_queryset(cls, ar):
-    #     # print("20160329 Human.get_request_queryset")
-    #     qs = super(Human, cls).get_request_queryset(ar)
-    #     if ar.param_values.gender:
-    #         qs = qs.filter(gender__exact=ar.param_values.gender)
-    #     return qs
-
-    # @classmethod
-    # def get_title_tags(cls, ar):
-    #     for t in super(Human, cls).get_title_tags(ar):
-    #         yield t
-    #     if ar.param_values.gender:
-    #         yield str(ar.param_values.gender)
-
 
 class Born(model.Model):
     """
@@ -347,6 +321,7 @@ class Born(model.Model):
     """
 
     class Meta(object):
+        # app_label = 'cal'
         abstract = True
 
     birth_date = fields.IncompleteDateField(
@@ -355,7 +330,7 @@ class Born(model.Model):
     def get_age(self, today=None):
         """
         Return the age (in years) of this human.  See
-        :meth:`lino.utils.IncompleteDateField.get_age`.
+        :meth:`lino.utils.IncompleteDate.get_age`.
         """
         if self.birth_date:
             return self.birth_date.get_age(today or settings.SITE.today())
@@ -397,7 +372,7 @@ class Born(model.Model):
                 s += " " + _("{} months").format(months)
         if self.birth_date and self.birth_date.is_complete():
             return s
-        return u"±" + s
+        return "±" + s
 
     @classmethod
     def setup_parameters(cls, fields):
@@ -410,11 +385,11 @@ class Born(model.Model):
                 _("Aged to"), blank=True, null=True,
                 help_text=_("Select only persons aged at most "
                             "the given number of years.")))
-        super(Born, cls).setup_parameters(fields)
+        super().setup_parameters(fields)
 
     @classmethod
     def get_request_queryset(cls, ar, **filter):
-        qs = super(Born, cls).get_request_queryset(ar, **filter)
+        qs = super().get_request_queryset(ar, **filter)
         pv = ar.param_values
 
         today = settings.SITE.today()
@@ -433,7 +408,7 @@ class Born(model.Model):
 
     @classmethod
     def get_title_tags(self, ar):
-        for t in super(Born, self).get_title_tags(ar):
+        for t in super().get_title_tags(ar):
             yield t
         pv = ar.param_values
         if pv.aged_from or pv.aged_to:
