@@ -1,12 +1,12 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2010-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 This defines the :class:`Registable` model mixin.
 """
 
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from lino.core import model
 from lino.core.actions import Action
