@@ -18,6 +18,7 @@ from django.core.exceptions import ValidationError
 
 from lino.core import actions
 from lino.core import fields
+from lino.core.inject import update_field
 from lino.core.utils import navinfo
 from etgen.html import E
 from lino.utils import AttrDict
@@ -389,7 +390,11 @@ class Hierarchical(Duplicable):
             p = p.parent
 
     def get_ancestor(self):
-        return self.get_parental_line()[0]
+        p = self
+        while p.parent is not None:
+            p = p.parent
+        return p
+        # return self.get_parental_line()[0]
 
     def get_parents(self):
         rv = []
@@ -438,12 +443,13 @@ class Hierarchical(Duplicable):
 
     def whole_tree(self):
         """
-        Returns a tuple of tuples.
-        The first item is the top most ancestor and the second item is a tuple
+        Returns a tuple with two items `(obj, children)` representing the whole tree.
+
+        The first item is the top-most ancestor and the second item is a tuple
         of all the children of the ancestor.
-        A children is wrappend inside another tuple where the first item is the
-        children and second item is None when the children has no grandchildren
-        otherwise the second item will be another tuple of grandchildren
+        A child is wrappend inside another tuple where the first item is the
+        child and second item is None when the child itself has no children
+        otherwise the second item will be another tuple of children
         and so on.
         """
         items = []
@@ -469,10 +475,13 @@ class Hierarchical(Duplicable):
             return None
         openned = self.get_parental_line()
         ancestor = openned[0]
-        tab = "»"
+        # tab = "» "
+        tab = " ⸱ "  # U+2e31
 
-        folder_closed = "🗀 " # U+1F5C0
-        folder_open = "🗁 " # U+1F5C1
+        # folder_closed = "🗀 " # U+1F5C0
+        folder_closed = "⌾ " # U+233e
+        # folder_open = "🗁 " # U+1F5C1
+        folder_open = "⌾ " # U+233e
         folder_with_child_closed = "📁 " # U+1F4C1 "🗂 "
         folder_with_child_open = "📂 " # U+1F4C2
 
