@@ -23,6 +23,7 @@ System plugins
     printing
     summaries
     help
+    linod
 
 Front ends
 ==========
@@ -56,7 +57,7 @@ Communication
     comments
     notify
     changes
-    chat
+    linod
 
 Enterprise Resources
 ====================
