@@ -1,4 +1,4 @@
-# Copyright 2008-2017 Rumma & Ko Ltd
+# Copyright 2008-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -14,7 +14,3 @@ class Plugin(ad.Plugin):
 
     def setup_site_menu(self, site, user_type, m):
         m.add_action(site.models.about.About)
-        # m.add_action(site.models.about.SiteSearch)
-
-    def get_quicklinks(site):
-        yield 'about.SiteSearch'
