@@ -7,15 +7,6 @@ Adds usage of the `AwesomeUploader
 Rymarczyk, hosted at
 <https://code.google.com/p/awesomeuploader/source/checkout>.
 
-Example configuration in a :xfile:`settings.py` file or
-a :xfile:`lino_local.py` file::
-
-    ad.configure_plugin(
-        'awesomeuploader',
-        maxFileSizeBytes=3145728
-    )
-
-
 .. setting:: awesomeuploader.maxFileSizeBytes
 
 Maximum file size in bytes
