@@ -7,10 +7,7 @@
 
 """
 
-from __future__ import unicode_literals
-
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 from django.conf import settings
 from django.utils.translation import gettext_lazy as _
