@@ -41,12 +41,15 @@ class Renderer(HtmlRenderer):
     #         return self.front_end.build_plain_url(
     #             model._meta.app_label, model.__name__, str(pk), **kw)
 
-    def get_home_url(self, *args, **kw):
+    def get_home_url(self, ar, *args, **kw):
+        add_user_language(kw, ar)
         return self.front_end.build_plain_url(*args, **kw)
 
     def get_request_url(self, ar, *args, **kw):
-        if ar.actor.__name__ == "Main":
+        if ar.actor is None:
             return self.front_end.build_plain_url(*args, **kw)
+        # if ar.actor.__name__ == "Main":
+        #     return self.front_end.build_plain_url(*args, **kw)
 
         st = ar.get_status()
         kw.update(st['base_params'])
