@@ -14,7 +14,7 @@ from django.core import exceptions
 from django.utils.translation import gettext as _
 from django.utils.translation import get_language
 from django.utils.decorators import method_decorator
-from django.views.decorators.csrf import ensure_csrf_cookie, csrf_protect
+from django.views.decorators.csrf import ensure_csrf_cookie
 
 # from django.contrib import auth
 from lino.core import auth
