@@ -8,8 +8,7 @@ menu entry to the `Explorer` menu.
 
 """
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 import datetime
 
@@ -29,6 +28,7 @@ from lino.core.signals import pre_add_child, pre_remove_child
 from lino.core.signals import receiver
 
 from lino.modlib.gfks.fields import GenericForeignKey, GenericForeignKeyIdField
+from lino.modlib.users.mixins import UserAuthored
 
 
 class ChangeTypes(dd.ChoiceList):
@@ -51,7 +51,7 @@ add('M', _("Merge"), 'merge')
 
 
 
-class Change(dd.Model):
+class Change(UserAuthored):
     """A registered change in the database.
 
     Each database change of a watched object will generate one Change
@@ -78,10 +78,10 @@ class Change(dd.Model):
 
     time = models.DateTimeField()
     type = ChangeTypes.field()
-    if settings.SITE.user_model:
-        user = dd.ForeignKey(settings.SITE.user_model)
-    else:
-        user = dd.DummyField()
+    # if settings.SITE.user_model:
+    #     user = dd.ForeignKey(settings.SITE.user_model)
+    # else:
+    #     user = dd.DummyField()
 
     object_type = dd.ForeignKey(
         'contenttypes.ContentType', blank=True, null=True,
@@ -121,10 +121,11 @@ class Changes(dd.Table):
         'object_type': param_object_type,
         'object_id': models.PositiveIntegerField("Object ID", blank=True),
     }
-    if settings.SITE.user_model:
-        parameters['user'] = dd.ForeignKey(
-            settings.SITE.user_model,
-            blank=True)
+    # no longer needed because user is a simple parameter
+    # if settings.SITE.user_model:
+    #     parameters['user'] = dd.ForeignKey(
+    #         settings.SITE.user_model,
+    #         blank=True)
 
     required_roles = dd.login_required(SiteStaff)
 
@@ -143,7 +144,8 @@ class Changes(dd.Table):
 
     @classmethod
     def get_request_queryset(cls, ar, **filter):
-        qs = super(Changes, cls).get_request_queryset(ar, **filter)
+        # print("20230620", ar.master_instance)
+        qs = super().get_request_queryset(ar, **filter)
         if not isinstance(qs, list):
             if ar.param_values.change_type:
                 qs = qs.filter(type=ar.param_values.change_type)
@@ -151,12 +153,13 @@ class Changes(dd.Table):
                 qs = qs.filter(time__range=(
                     ar.param_values.date,
                     ar.param_values.date+datetime.timedelta(1)))
-            if settings.SITE.user_model and ar.param_values.user:
-                qs = qs.filter(user=ar.param_values.user)
+            # if settings.SITE.user_model and ar.param_values.user:
+            #     qs = qs.filter(user=ar.param_values.user)
             if ar.param_values.object_type:
                 qs = qs.filter(object_type=ar.param_values.object_type)
             if ar.param_values.object_id:
                 qs = qs.filter(object_id=ar.param_values.object_id)
+            # print("20230620", qs.query)
         return qs
 
 
@@ -195,12 +198,13 @@ def log_change(type, request, master, obj, msg='', changed_fields=''):
 remove_after = dd.plugins.changes.remove_after
 if remove_after:
 
-    @dd.schedule_daily
-    def delete_older_changes():
+    @dd.schedule_daily()
+    def delete_older_changes(ar):
         days = datetime.timedelta(days=remove_after)
-        qs = Change.objects.filter(time_lt=timezone.now() - days)
+        # django.core.exceptions.FieldError: Cannot resolve keyword 'time_lt' into field. Choices are: changed_fields, diff, id, list_item, master, master_id, master_type, master_type_id, name_column, navigation_panel, object, object_id, object_type, object_type_id, overview, time, type, user, user_id, workflow_buttons
+        qs = Change.objects.filter(time__lt=timezone.now() - days)
         if qs.count() > 0:
-            dd.logger.info(
+            ar.logger.info(
                 "Removing %d changes older than %d days.",
                 qs.count(), remove_after)
             qs.delete()
