@@ -33,7 +33,6 @@ class Checker(dd.Choice):
     severity = None
     self = None
     model = None
-
     help_text = None
 
     def __init__(self):
@@ -47,7 +46,7 @@ class Checker(dd.Choice):
             text = value
         else:
             text = self.verbose_name
-        super(Checker, self).__init__(value, text, None)
+        super().__init__(value, text, None)
 
     @classmethod
     def activate(cls):
@@ -57,12 +56,11 @@ class Checker(dd.Choice):
         Checkers.add_item_instance(cls.self)
 
     @classmethod
-    def update_unbound_problems(cls, **kwargs):
+    def update_unbound_problems(cls, ar, **kwargs):
         assert cls.self.model is None
-        cls.self.update_problems(**kwargs)
-        todo, done = cls.self.update_problems(**kwargs)
+        todo, done = cls.self.update_problems(ar, **kwargs)
         msg = "Found {0} and fixed {1} checkdata messages for {2}."
-        dd.logger.info(msg.format(len(todo), len(done), cls.self))
+        ar.logger.info(msg.format(len(todo), len(done), cls.self))
 
     @classmethod
     def check_instance(cls, *args, **kwargs):
@@ -77,7 +75,7 @@ class Checker(dd.Choice):
         if isinstance(self.model, str):
             self.model = dd.resolve_model(self.model, strict=True)
 
-    def update_problems(self, obj=None, delete=True, fix=False):
+    def update_problems(self, ar, obj=None, delete=True, fix=False):
         Message = rt.models.checkdata.Message
         if delete:
             # if obj is None:
@@ -102,6 +100,11 @@ class Checker(dd.Choice):
                 done.append(msg)
             else:
                 todo.append(msg)
+            if obj is None:
+                ar.logger.info("- {} : {}".format(self.value, msg))
+            else:
+                ar.logger.info("- {} : {}".format(obj, msg))
+
         if len(todo):
             # dd.logger.info("%s : %s", obj, todo)
             user = self.get_responsible_user(obj)
@@ -137,7 +140,7 @@ class Checkers(dd.ChoiceList):
     max_length = 250
     # e.g. "lino_welfare.modlib.pcsw.models.ClientCoachingsChecker"
     column_names = "value text"
-    show_values = False
+    show_values = True
 
     detail_layout = """
     value text
