@@ -1,21 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2015-2020 Rumma & Ko Ltd
+# Copyright 2015-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-"""Defines the :manage:`checkdata` management command:
-
-.. management_command:: checkdata
-
-.. py2rst::
-
-  from lino.modlib.checkdata.management.commands.checkdata \
-      import Command
-  print(Command.help)
-
-In other words, this command does the same as if a user would click on
-the button with the bell ("Check data") on each database
-object for which there are data checkers.
-
-"""
 
 from django.core.management.base import BaseCommand, CommandError
 
@@ -57,8 +42,9 @@ class Command(BaseCommand):
         app = options.get('checkers', args)
         if app:
             args += tuple(app)
+        ar = rt.login()
         if options['list']:
-            rt.show(Checkers, column_names="value text")
+            ar.show(Checkers, column_names="value text")
         else:
             rt.startup()
-            check_data(args=args, fix=options['fix'], prune=options['prune'])
+            check_data(ar, args=args, fix=options['fix'], prune=options['prune'])
