@@ -2,6 +2,8 @@
 # Copyright 2013-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
+# from html import escape
+from django.contrib.humanize.templatetags.humanize import naturaltime
 from django.db import models
 from django.db.models import Q
 from django.core import validators
@@ -115,7 +117,7 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
         }
     )]
 
-    publisher_location = "c"
+    # publisher_location = "c"
     memo_command = "comment"
 
     reply_to = dd.ForeignKey(
@@ -124,7 +126,7 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
     # more_text = dd.RichTextField(_("More text"), blank=True)
 
     private = models.BooleanField(
-        _("Private"), default=dd.plugins.comments.private_default)
+        _("Confidential"), default=dd.plugins.comments.private_default)
 
     comment_type = dd.ForeignKey('comments.CommentType', blank=True, null=True)
     # reply_vote = models.BooleanField(_("Upvote"), null=True, blank=True)
@@ -134,7 +136,10 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
 
     my_emotion = MyEmotionField()
 
-    reply = CommentField()
+    reply = CommentField("comments.RepliesByComment")
+
+    def is_public(self):
+        return not self.private
 
     def disabled_fields(self, ar):
         s = super().disabled_fields(ar)
@@ -152,27 +157,28 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
         if mr:
             return mr.emotion
 
-    def as_story_item(self, ar):
-        header = [ar.obj2html(self, self.created_natural)]
-        header.append(str(_(" by ")))
-        header.append(ar.obj2html(self.user))
-        header.append(E.span(":"))
-        elems = [E.h3(*header)]
-        try:
-            full_preview_elem = fromstring(self.body_full_preview)
-        except:
-            full_preview_elem = fromstring("<p>" + self.body_full_preview + "</p>")
+    def as_story_item(self, ar, indent=0):
+        header = ar.obj2htmls(self, self.created_natural)
+        header += str(_(" by "))
+        header += ar.obj2htmls(self.user)
+        # header += ":"
+        s = "<h3>{}</h3>".format(header)
+
+        s += self.body_full_preview
+
+        # try:
+        #     full_preview_elem = fromstring(self.body_full_preview)
+        # except:
+        #     full_preview_elem = fromstring("<p>" + self.body_full_preview + "</p>")
 
-        childs = []
         if self.replies_to_this.count():
-            childs.append(E.h4("Replies:"))
+            # s += "<p>{}</p>".format("Replies:")
             for child in self.replies_to_this.all():
-                childs.append(fromstring(child.as_story_item(ar)))
+                s += child.as_story_item(ar, indent=indent+1)
+        s += "<br/>"
+        style = "margin-left: {}em;".format(indent*2)
+        return '<div style="{}">{}</div>'.format(style, s)
 
-        elems.append(E.div(full_preview_elem, *childs, style="margin-left: 40px;"))
-
-        elems.append(E.br())
-        return tostring(E.div(*elems))
 
     def __str__(self):
         return '{} #{}'.format(self._meta.verbose_name, self.pk)
@@ -200,6 +206,7 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
         for m in rt.models_by_base(Commentable):
             flt = m.get_comments_filter(user)
             if flt is not None:
+                assert not m._meta.abstract
                 ct = rt.models.contenttypes.ContentType.objects.get_for_model(m)
                 filters.append(flt | ~Q(owner_type=ct))
         if len(filters):
@@ -221,9 +228,12 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
         if self.owner_id:
             self.owner.on_commented(self, ar, cw)
 
-    # def full_clean(self):
-    #     super(Comment, self).full_clean()
-    #     self.owner.setup_comment(self)
+    def full_clean(self):
+        super().full_clean()
+        if self.reply_to_id and not self.owner_id:
+            # added only 2023-11-19
+            self.owner = self.reply_to.owner
+        # self.owner.setup_comment(self)
 
     def get_change_owner(self):
         return self.owner or self
@@ -257,6 +267,7 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
         # s = s.format(user=user, obj=self.owner.obj2memo())
         # return ar.obj2htmls(self.owner)
         s = s.format(user=user, obj=ar.obj2htmls(self.owner))
+        # s += " (20240101 ar is {})".format(escape(str(ar)))
         if dd.is_installed("inbox"):
             # raise Exception("20230216")
             #mailto:ADDR@HOST.com?subject=SUBJECT&body=Filling%20in%20the%20Body!%0D%0Afoo%0D%0Abar
@@ -331,5 +342,23 @@ class Reaction(CreatedModified, UserAuthored, DateRangeObservable):
 #
 #     mp.register_django_model('comment', Comment)
 
+from lino.modlib.checkdata.choicelists import Checker
+
+class CommentChecker(Checker):
+    # temporary checker to fix #4084 (Comment.owner is empty when replying to a comment)
+    verbose_name = _("Check for missing owner in reply to comment")
+    model = Comment
+    msg_missing = _("Missing owner in reply to comment.")
+
+    def get_checkdata_problems(self, obj, fix=False):
+        if obj.reply_to_id and not obj.owner_id and obj.reply_to.owner_id:
+            yield (True, self.msg_missing)
+            if fix:
+                obj.full_clean()
+                obj.save()
+
+CommentChecker.activate()
+
+
 
 from .ui import *
