@@ -107,14 +107,15 @@ class Comments(dd.Table):
         yield "reply_to"
 
     @classmethod
-    def get_card_title(self, ar, obj):
+    def get_card_title(cls, ar, obj):
         """Overrides the default behaviour
         """
-        title = _("Created {created} by {user}").format(
-            created=naturaltime(obj.created), user=str(obj.user))
-        if self.get_view_permission(ar.get_user().user_type):
-            title = tostring(ar.obj2html(obj, title))
-        return title
+        return cls.get_comment_header(obj, ar)
+        # title = _("Created {created} by {user}").format(
+        #     created=naturaltime(obj.created), user=str(obj.user))
+        # if cls.get_view_permission(ar.get_user().user_type):
+        #     title = tostring(ar.obj2html(obj, title))
+        # return title
 
     # @classmethod
     # def get_table_summary(cls, obj, ar):
@@ -131,36 +132,35 @@ class Comments(dd.Table):
 
     @classmethod
     def get_comment_header(cls, comment, ar):
-        ch = []
         if (comment.modified - comment.created).total_seconds() < 1:
             t = _("Created " + comment.created.strftime('%Y-%m-%d %H:%M'))
         else:
             t = _("Modified " + comment.modified.strftime('%Y-%m-%d %H:%M'))
-        ch.append(ar.obj2html(
-            comment, naturaltime(comment.created), title=t))
+        ch = ar.obj2htmls(comment, naturaltime(comment.created), title=t)
+        ch += " " + _("by") + " "
         if comment.user is None:
-            ch += [" ", _("by system")]
+            ch += _("system")
         else:
-            ch += [" ", _("by"), " ",
-                   ar.obj2html(comment.user, str(comment.user))]
+            ch += ar.obj2htmls(comment.user)
 
-        sar = cls.insert_action.request_from(ar)
-        # print(20170217, sar)
-        sar.known_values = dict(
-            reply_to=comment, **gfk2lookup(
-                comment.__class__.owner, comment.owner))
-        # if ar.get_user().is_authenticated:
-        if sar.get_permission():
-            btn = sar.ar2button(None, _(" Reply "), icon_name=None)
-            # btn.set("style", "padding-left:10px")
-            ch += [" [", btn, "]"]
+        if cls.insert_action is not None:
+            sar = cls.insert_action.request_from(ar)
+            # print(20170217, sar)
+            sar.known_values = dict(
+                reply_to=comment, **gfk2lookup(
+                    comment.__class__.owner, comment.owner))
+            # if ar.get_user().is_authenticated:
+            if sar.get_permission():
+                btn = sar.ar2button(None, _(" Reply "), icon_name=None)
+                # btn.set("style", "padding-left:10px")
+                ch += " [" + tostring(btn) + "]"
 
         # ch.append(' ')
         # ch.append(
         #     E.a(u"⁜", onclick="toggle_visibility('comment-{}');".format(
         #         comment.id), title=str(_("Hide")), href="#")
         # )
-        return tostring(ch)
+        return ch
 
     # @classmethod
     # def as_li(cls, self, ar):
@@ -212,7 +212,8 @@ class CommentsByX(Comments):
     required_roles = dd.login_required(CommentsReader)
     order_by = ["-created"]
     # order_by = ["-modified"]
-    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
+    # display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
+    display_mode = ((None, constants.DISPLAY_MODE_LIST), )
     # card_layout = dd.DetailLayout("""
     # card_summary
     # RepliesByComment
@@ -220,7 +221,7 @@ class CommentsByX(Comments):
 
     @classmethod
     def get_request_queryset(cls, ar, **filter):
-        qs = super(CommentsByX, cls).get_request_queryset(ar, **filter)
+        qs = super().get_request_queryset(ar, **filter)
         qs = qs.annotate(num_replies=models.Count('replies_to_this'))
         qs = qs.annotate(num_reactions=models.Count('reactions_to_this'))
         # qs = qs.annotate(my_emotion='reaction__emotion')
@@ -228,10 +229,10 @@ class CommentsByX(Comments):
 
 
     @classmethod
-    def get_table_summary(cls, obj, ar):
+    def unused_get_table_summary(cls, obj, ar):
         # sar = cls.request_from(ar, master_instance=obj, is_on_main_actor=False)
         sar = cls.request(parent=ar, master_instance=obj, is_on_main_actor=False)
-        elems = []
+        elems = ""
 
         if cls.insert_action is not None:
             if not cls.editable:
@@ -251,7 +252,7 @@ class CommentsByX(Comments):
                         title=_("Reply to {} about {}").format(
                             obj, obj.owner))
                     # btn.set("style", "padding-left:10px")
-                    elems.append(E.p(btn))
+                    elems += "<p>{}</p>".format(tostring(btn))
                     # elems += [" [", btn, "]"]
                 elif isinstance(obj, Commentable):
                     # we are showing the comment about a Commentable
@@ -261,7 +262,7 @@ class CommentsByX(Comments):
                     # btn = ir.ar2button(
                     #         None, _("Write new comment:"), # icon_name=None,
                     #         title=_("Start a new comment about {}").format(obj))
-                    elems.append(E.p(btn))
+                    elems += "<p>{}</p>".format(tostring(btn))
                     # elems += [" [", btn, "]"]
                 else:
                     # this should never happen...
@@ -271,24 +272,27 @@ class CommentsByX(Comments):
         for com in sar.data_iterator:
             n += 1
             if n > cls.preview_limit:
-                elems.append(E.p("..."))
+                elems += "<p>{}</p>".format("...")
                 break
-            elems.append(E.p(*cls.summary_row(sar, com)))
+            # elems += "<p>{}</p>".format(cls.as_summary_row(sar, com))
+            elems += "<p>{}</p>".format(sar.row_as_paragraph(com))
 
-        return ar.html_text(E.div(*elems))
+        return "<div>{}</div>".format(elems)
 
     @classmethod
-    def summary_row(cls, ar, o, **kw):
+    def row_as_paragraph(cls, ar, o, **kw):
 
         # Here we do another db request on each comment just to get the user's
-        # emotion. That's  suboptimal and should rather be a annotation:
+        # emotion. That's suboptimal and should rather be a annotation:
+
+        s = ""
 
         if o.num_reactions:
             # my_emotion = MyEmotionField.value_from_object(o, ar)
 
             e = o.get_my_emotion(ar)
             if e is not None:
-                yield " {} ".format(e.button_text or e.text)
+                s += " {} ".format(e.button_text or e.text)
             # else:
             #     yield " foo "
 
@@ -309,13 +313,14 @@ class CommentsByX(Comments):
         #     yield o.emotion.button_text
         #     yield " "
 
-        yield ar.obj2html(o, naturaltime(o.created), title=t)
-        yield " {} ".format(_("by"))
+        s += ar.obj2htmls(o, naturaltime(o.created), title=t)
+        s += " {} ".format(_("by"))
         if o.user is None:
             by = gettext("system")
         else:
             by = o.user.username
-        yield E.b(by)
+        # yield E.b(by)
+        s += "<b>{}</b>".format(by)
 
 
         # Show `reply_to` and `owner` unless they are obvious.
@@ -323,38 +328,41 @@ class CommentsByX(Comments):
         # though that might not be said explicitly.
         if not ar.is_obvious_field('reply_to'):
             if o.reply_to:
-                yield " {} ".format(_("in reply to"))
+                s += " {} ".format(_("in reply to"))
                 if o.reply_to.user is None:
-                    yield gettext("system")
+                    s += gettext("system")
                 else:
-                    yield E.b(o.reply_to.user.username)
+                    # yield E.b(o.reply_to.user.username)
+                    s += "<b>{}</b>".format(o.reply_to.user.username)
             if not ar.is_obvious_field('owner'):
                 if o.owner:
-                    yield " {} ".format(_("about"))
-                    yield o.owner.obj2href(ar)
+                    s += " {} ".format(_("about"))
+                    s +=  ar.obj2htmls(o.owner)
                     group = o.owner.get_comment_group()
                     if group and group.ref:
-                         yield "@" + group.ref
+                         s += "@" + group.ref
 
         if False and o.num_reactions:
             txt = ngettext("{} reaction", "{} reactions", o.num_reactions).format(o.num_reactions)
-            yield " ({})".format(txt)
+            s += " ({})".format(txt)
 
         # replies  = o.__class__.objects.filter(reply_to=o)
         if o.num_replies > 0:
             txt = ngettext("{} reply", "{} replies", o.num_replies).format(o.num_replies)
-            yield " ({})".format(txt)
+            s += " ({})".format(txt)
 
         if o.body_short_preview:
-            yield " : "
-            try:
-                # el = etree.fromstring(o.body_short_preview, parser=html_parser)
-                for e in lxml.html.fragments_fromstring(o.body_short_preview): #, parser=cls.html_parser)
-                    yield e
-                # el = etree.fromstring("<div>{}</div>".format(o.body_full_preview), parser=cls.html_parser)
-                # print(20190926, tostring(el))
-            except Exception as e:
-                yield "{} [{}]".format(o.body_short_preview, e)
+            s += " : " + o.body_short_preview
+            # try:
+            #     # el = etree.fromstring(o.body_short_preview, parser=html_parser)
+            #     for e in lxml.html.fragments_fromstring(o.body_short_preview): #, parser=cls.html_parser)
+            #         yield e
+            #     # el = etree.fromstring("<div>{}</div>".format(o.body_full_preview), parser=cls.html_parser)
+            #     # print(20190926, tostring(el))
+            # except Exception as e:
+            #     yield "{} [{}]".format(o.body_short_preview, e)
+        return s
+
 
 
 # class MyPendingComments(MyComments):
@@ -368,8 +376,9 @@ class CommentsByX(Comments):
 #         return kw
 
 class RecentComments(CommentsByX):
-    required_roles = dd.login_required(CommentsReader)
+    # required_roles = dd.login_required(CommentsReader)
     # required_roles = set([CommentsReader])
+    allow_create = False
     column_names = "body_short_preview modified user owner *"
     stay_in_grid = True
     # order_by = ["-modified"]
@@ -387,10 +396,10 @@ class CommentsByRFC(CommentsByX):
     master_key = 'owner'
     column_names = "body created user *"
     stay_in_grid = True
-    display_mode = (
-        (70, constants.DISPLAY_MODE_SUMMARY),
-        (None, constants.DISPLAY_MODE_STORY),
-    )
+    # display_mode = (
+    #     (70, constants.DISPLAY_MODE_SUMMARY),
+    #     (None, constants.DISPLAY_MODE_STORY),
+    # )
     simple_slavegrid_header = True
     insert_layout = dd.InsertLayout("""
     reply_to
@@ -401,7 +410,7 @@ class CommentsByRFC(CommentsByX):
 
     @classmethod
     def param_defaults(cls, ar, **kw):
-        kw = super(CommentsByRFC, cls).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw['reply_to'] = constants.CHOICES_BLANK_FILTER_VALUE
         return kw
 
@@ -461,6 +470,7 @@ class CommentsByMentioned(CommentsByX):
         if mi is None:
             return None
         Mention = rt.models.memo.Mention
+        assert not cls.model._meta.abstract
         ct = ContentType.objects.get_for_model(cls.model)
         mkw = gfk2lookup(Mention.source, mi, owner_type=ct)
         mentions = Mention.objects.filter(**mkw).values_list('owner_id', flat=True)
@@ -492,3 +502,7 @@ class Reactions(dd.Table):
     editable = False
     model = "comments.Reaction"
     column_names = "comment user emotion created *"
+
+
+from lino_xl.lib.pages.choicelists import PageFillers
+PageFillers.add_item(RecentComments)
