@@ -50,7 +50,7 @@ class Widget(UserAuthored, Sequenced):
     """
 
     move_action_names = ('move_up', 'move_down')
-    
+
     class Meta(object):
         app_label = 'dashboard'
         verbose_name = _("Widget")
@@ -59,7 +59,6 @@ class Widget(UserAuthored, Sequenced):
     item_name = models.CharField(_("Resource"), max_length=200)
     visible = models.BooleanField(_("Visible"), default=True)
 
-    
     @dd.chooser(simple_values=True)
     def item_name_choices(cls, user):
         return [i.name for i in
@@ -71,7 +70,7 @@ class Widget(UserAuthored, Sequenced):
     def get_siblings(self):
         qs = super(Widget, self).get_siblings()
         return qs.filter(user=self.user)
-    
+
     @dd.displayfield(_("Label"))
     def title(self, ar):
         a = settings.SITE.models.resolve(self.item_name)
@@ -81,7 +80,11 @@ class Widget(UserAuthored, Sequenced):
             return _("Invalid item_name {} in {}").format(
                 self.item_name, self._meta.verbose_name)
         return a.label
-    
+
+    def after_ui_save(self, ar, cw):
+        super().after_ui_save(ar, cw)
+        ar.get_user().get_preferences().invalidate()
+
 
 class Widgets(dd.Table):
     model = 'dashboard.Widget'
@@ -91,21 +94,21 @@ class AllWidgets(Widgets):
     required_roles = dd.login_required(SiteAdmin)
     column_names = 'id user seqno move_buttons title visible *'
     order_by = ['id']
-        
+
 class WidgetsByUser(Widgets):
     label = _("Dashboard")
     master_key = 'user'
     column_names = 'seqno move_buttons title visible *'
     order_by = ['seqno']
 
-    
+
 def update_widgets_for(ar, user):
-    
+
     available = set([i.name for i in get_available_items(user)])
-    
+
     Widget = rt.models.dashboard.Widget
     qs = Widget.objects.filter(user=user).order_by('seqno')
-    
+
     seqno = 0
     for w in qs:
         if w.item_name in available:
@@ -123,4 +126,3 @@ def update_widgets_for(ar, user):
 
     up.invalidate()
     ar.set_response(refresh=True)
-
