@@ -15,7 +15,7 @@ from etgen.html import iselement, to_rst
 from lino.core import actions
 from lino.core.choicelists import Choice
 from lino.core.tables import AbstractTable
-from lino.core.roles import Expert
+from lino.core.roles import DataExporter
 from lino.utils import IncompleteDate
 from lino.utils.media import TmpMediaFile
 from lino.utils.quantities import Duration
@@ -122,7 +122,7 @@ class ExportExcelAction(actions.Action):
     default_format = 'ajax'
     preprocessor = "Lino.get_current_grid_config"
     callable_from = 't'
-    required_roles = dd.login_required(Expert)
+    required_roles = dd.login_required(DataExporter)
 
     # def is_callable_from(self, caller):
     #     return isinstance(caller, actions.ShowTable)
