@@ -135,7 +135,7 @@ class Plugin(Plugin):
             if not chooser:
                 return
             for f in chooser.context_fields:
-                if master_field and master_field.name == f.name:
+                if master_field:
                     yield "var bp = this.get_base_params();"
                     yield "%s.setContextValue('%s',bp['%s']);" % (
                         e.as_ext(), constants.URL_PARAM_MASTER_PK,
@@ -143,7 +143,7 @@ class Plugin(Plugin):
                     yield "%s.setContextValue('%s',bp['%s']);" % (
                         e.as_ext(), constants.URL_PARAM_MASTER_TYPE,
                         constants.URL_PARAM_MASTER_TYPE)
-                else:
+                if not master_field or master_field.name != f.name:
                     yield (
                         "%s.setContextValue('%s', record ? record."
                         "data['%s'] : undefined);" % (
