@@ -29,7 +29,7 @@ self.addEventListener('fetch', (e) => {
     if (e.request.url.includes('/media/cache/js/')) {
         e.waitUntil(self.registration.pushManager.getSubscription().then((sub) => {
             if (sub !== null) {
-                fetch(`pushsubscription?sub=${JSON.stringify(sub)}`);
+                // fetch(`pushsubscription?sub=${JSON.stringify(sub)}`);
             }
         }));
     }
