@@ -6,7 +6,7 @@
 Defines the :class:`ExtRenderer` class.
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 from html import escape
 import time
@@ -20,8 +20,8 @@ from etgen.html import E, iselement
 
 import lino
 from lino.core import constants
-from lino.core.renderer import JsRenderer
-from lino.core.renderer_mixins import JsCacheRenderer
+# from lino.core.renderer import JsRenderer
+from lino.core.renderer import JsCacheRenderer
 from lino.core.gfks import ContentType
 
 from lino.core.actions import (ShowEmptyTable, ShowDetail,
@@ -75,7 +75,7 @@ def prepare_label(mi):
 
 
 
-class ExtRenderer(JsRenderer, JsCacheRenderer):
+class ExtRenderer(JsCacheRenderer):
     """An HTML renderer that uses the ExtJS Javascript toolkit.
 
     """
@@ -85,8 +85,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
     extjs_version = 3
 
     def __init__(self, plugin):
-        super(ExtRenderer, self).__init__(plugin)
-        JsCacheRenderer.__init__(self)
+        super().__init__(plugin)
         jsgen.register_converter(self.py2js_converter)
 
         for s in 'green blue red yellow'.split():
@@ -131,6 +130,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
                 if v.params:
                     ar = v.bound_action.request(**v.params)
                     js = self.request_handler(ar)
+                    # print("20230513", js)
                 else:
                     js = self.action_call(None, v.bound_action, {})
                 js = "function() {%s}" % js
@@ -273,6 +273,8 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
                 status[constants.URL_PARAM_SUBST_USER] = ar.subst_user
             if isinstance(a, ShowEmptyTable):
                 status.update(record_id=-99998)
+            if ar is not None and hasattr(ar, 'get_status'):
+                status = ar.get_status(**(status or {}))
             if ar is None:
                 rp = None
             else:
@@ -289,9 +291,10 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
 
         # used e.g. the invoicing.StartInvoicing action (visible in
         # roger or lydia).
-        return "%s()" % self.get_panel_btn_handler(bound_action)
+        return "{}()".format(
+            self.get_panel_btn_handler(bound_action, status))
 
-    def get_panel_btn_handler(self, ba):
+    def get_panel_btn_handler(self, ba, status={}):
         if isinstance(ba.action, WrappedAction):
             original_ba = ba.action.bound_action
             if original_ba.action.parameters and not original_ba.action.no_params_window:
@@ -306,16 +309,19 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             else:
                 h = ba.action.js_handler % ba.action.__dict__
         else:
+            bp = status.get('base_params', None)
+            if bp is None:
+                pp = ba.action.preprocessor
+            else:
+                pp = "function() {return %s;}" % py2js(bp)
+
             if ba.action.select_rows:
                 h = 'Lino.row_action_handler('
             else:
-                h = 'Lino.list_action_handler('
-                h += "'/%s/%s'," % (ba.actor.app_label, ba.actor.__name__)
+                h = "Lino.list_action_handler('{}',".format(ba.actor.actor_url())
             h += "'%s'" % ba.action.action_name
             h += ",'%s'" % ba.action.http_method
-            if ba.action.preprocessor:
-                h += "," + ba.action.preprocessor
-            h += ")"
+            h += "," + pp + ")"
         return h
 
     def row_action_handler(self, ba, obj, ar=None):
@@ -1034,6 +1040,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         if dh.layout.window_size and dh.layout.window_size[1] == 'auto':
             yield "  autoHeight: true,"
         if settings.SITE.is_installed('contenttypes') and issubclass(tbl, dbtables.Table):
+            assert not tbl.model._meta.abstract
             yield "  content_type: %s," % py2js(ContentType.objects.get_for_model(tbl.model).pk)
         if tbl.hide_editing(get_user_profile()):
             yield "  disable_editing: true,"
@@ -1206,7 +1213,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             kw.update(
                 disabled_fields_index=rh.store.column_index('disabled_fields'))
 
-        for k, v in list(kw.items()):
+        for k, v in kw.items():
             yield "  %s : %s," % (k, py2js(v))
 
         yield "  initComponent : function() {"
@@ -1248,23 +1255,23 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         yield ""
 
     def js_render_wrapped_action(self, rh, ba):
-        original_ba = ba.action.bound_action
         yield "Lino.%s = function(panel, btn, step) {" % ba.action.action_name
-        if isinstance(original_ba.action, ShowDetail):
+        ba = ba.action.bound_action
+        if isinstance(ba.action, ShowDetail):
             yield "\tvar pk = panel.get_current_record().id;"
             yield "\tif (pk === -99998) pk = 0;"
-            yield "\tLino.%s.run(null, {record_id: pk});" % original_ba.full_name()
-        elif isinstance(original_ba.action, (ShowTable, ShowEmptyTable, ShowInsert)):
-            yield "\tLino.%s.run(null);" % original_ba.full_name()
+            yield "\tLino.%s.run(null, {record_id: pk});" % ba.full_name()
+        elif isinstance(ba.action, (ShowTable, ShowEmptyTable, ShowInsert)):
+            yield "\tLino.%s.run(null);" % ba.full_name()
         else:
-            if original_ba.action.select_rows:
+            if ba.action.select_rows:
                 h = "\tLino.row_action_handler(%s, %s, %s)(panel, btn, step);"
             else:
-                h = "\tLino.list_action_handler(%s," % py2js(
-                    original_ba.actor.actor_url()) + " %s, %s, %s)(panel, btn, step);"
-            yield h % (py2js(original_ba.action.action_name),
-                py2js(original_ba.action.http_method),
-                original_ba.action.preprocessor)
+                h = "\tLino.list_action_handler('{}'".format(
+                    ba.actor.actor_url()) + ", %s, %s, %s)(panel, btn, step);"
+            yield h % (py2js(ba.action.action_name),
+                py2js(ba.action.http_method),
+                ba.action.preprocessor)
         yield "};"
 
     def js_render_custom_action(self, rh, ba):
@@ -1413,7 +1420,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         either `data_record` or a `record_id`.
 
         Usually `data_record`, except if it is a `file upload
-        <https://docs.djangoproject.com/en/4.1/topics/http/file-uploads/>`_
+        <https://docs.djangoproject.com/en/5.0/topics/http/file-uploads/>`_
         where some mysterious decoding problems (:blogref:`20120209`)
         force us to return a `record_id` which has the same visible
         result but using an additional GET.
