@@ -34,7 +34,7 @@ from django import http
 from django.db import models
 from django.conf import settings
 from django.core.cache import cache
-from django.core.exceptions import PermissionDenied
+from django.core.exceptions import PermissionDenied, ObjectDoesNotExist
 from django.views.generic import View
 from django.views.generic.base import TemplateView
 from django.views.decorators.cache import never_cache
@@ -137,6 +137,9 @@ class AdminIndex(View):
         #     a = settings.SITE.get_main_action(user)
         #     if a is not None and a.get_view_permission(user.user_type):
         #         kw.update(on_ready=renderer.action_call(request, a, {}))
+        # raise Exception("20230331 {}".format(request.user))
+        # if request.subst_user:
+        #     raise(Exception("20230331 {}".format(request.subst_user)))
         return http.HttpResponse(renderer.html_page(request, **kw))
 
 def test_version_mismatch(request):
@@ -147,16 +150,8 @@ def test_version_mismatch(request):
         return {}
     # print("20201217", lv, settings.SITE.kernel.code_mtime)
     cache.clear()
-    if settings.SITE.kernel.default_ui.app_label == 'react':
-        vm_data = dict(version_mismatch=True)
-        try:
-            if float(request.GET.get(
-                    constants.URL_PARAM_MAIN_JS_TIMESTAMP)
-            ) != os.stat(Path(settings.STATIC_ROOT) / 'react' / 'main.js'):
-                vm_data.update(js_version_mismatch=True)
-        except Exception:
-            pass
-        return vm_data
+    if settings.SITE.kernel.editing_front_end.app_label == 'react':
+        return {"version_mismatch": True}
     return dict(alert=_("Version mismatch"),
                 message=_("Your browser is using a previous version of the site, press OK to reload the site"),
                 alert_eval_js="window.location.reload(true);")
@@ -249,6 +244,8 @@ class Choices(View):
                 # logger.info("views.Choices: %r is blank",field)
                 emptyValue = '<br/>'
             ar = rpt.request(request=request)
+            # if str(rpt) == 'comments.CommentsByRFC':
+            #     print("20230426", ar.master_instance)
             qs, row2dict = choices_for_field(ar, rpt, field)
 
         return choices_response(rpt, request, qs, row2dict, emptyValue)
@@ -327,7 +324,7 @@ class ApiElement(View):
     @method_decorator(ensure_csrf_cookie)
     def get(self, request, app_label=None, actor=None, pk=None):
         vm = test_version_mismatch(request)
-        if vm and settings.SITE.kernel.default_ui.app_label == 'react':
+        if vm and settings.SITE.kernel.editing_front_end.app_label == 'react':
             return json_response(vm)
         # this is also used by the react front end
         rpt = requested_actor(app_label, actor)
@@ -351,7 +348,10 @@ class ApiElement(View):
             sr = request.GET.getlist(constants.URL_PARAM_SELECTED)
             if len(sr) == 0:
                 sr = [pk]
-            ar = ba.request(request=request, selected_pks=sr)
+            try:
+                ar = ba.request(request=request, selected_pks=sr)
+            except ObjectDoesNotExist as e:
+                raise http.Http404(f"Objects {sr} does not exists on {rpt}")
             # print(
             #     "20170116 views.ApiElement.get", ba,
             #     ar.action_param_values)
@@ -460,7 +460,7 @@ class ApiList(View):
     @method_decorator(ensure_csrf_cookie)
     def get(self, request, app_label=None, actor=None):
         vm = test_version_mismatch(request)
-        if vm and settings.SITE.kernel.default_ui.app_label == 'react':
+        if vm and settings.SITE.kernel.editing_front_end.app_label == 'react':
             return json_response(vm)
         ar = action_request(app_label, actor, request, request.GET, True)
         ar.renderer = settings.SITE.kernel.extjs_renderer
