@@ -24,10 +24,10 @@ class Plugin(ad.Plugin):
     #     m = m.add_menu(hook.app_label, hook.verbose_name)
     #     m.add_action(site.modules.gfks.BrokenGFKs)
 
-    def setup_config_menu(config, site, user_type, m):
-        hook = site.plugins.system
-        m = m.add_menu(hook.app_label, hook.verbose_name)
-        m.add_action(site.modules.gfks.HelpTexts)
+    # def setup_config_menu(config, site, user_type, m):
+    #     hook = site.plugins.system
+    #     m = m.add_menu(hook.app_label, hook.verbose_name)
+    #     m.add_action(site.modules.gfks.HelpTexts)
 
     def setup_explorer_menu(config, site, user_type, m):
         hook = site.plugins.system
