@@ -1,16 +1,13 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2022 Rumma & Ko Ltd
+# Copyright 2011-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 import sys
 import tempfile
 import subprocess
-from optparse import make_option
-from os.path import join, exists
 from io import open
 from pathlib import Path
 
@@ -48,7 +45,25 @@ from lino.api import doctest
 
 use_dirhtml = False
 
-include_useless = False
+include_useless = settings.SITE.get_plugin_setting('help', 'include_useless')
+
+LAYOUT_HTML = """
+{% extends "!layout.html" %}
+
+{% block fonts %}
+    <style>
+        body {
+            font-family: 'Liberation Sans', -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Open Sans', 'Helvetica Neue', sans-serif;
+        }
+        .header-style {
+            font-family: 'Liberation Sans', Cambria, Cochin, Georgia, Times, 'Times New Roman', serif;
+        }
+    </style>
+{% endblock %}
+
+{% block relbar1 %}{% endblock %}
+{% block relbar2 %}{% endblock %}
+"""
 
 def runcmd(cmd, **kw):
     """Run the specified command in a subprocess.
@@ -146,10 +161,9 @@ class GeneratingCommand(BaseCommand):
     def run_on_temp_dir(self, temp_dir):
         verbosity = self.options.get('verbosity', 0)
         self.temp_dir = temp_dir
-        logger.info("Generate temporary rst files to %s", self.temp_dir)
-
+        logger.info("Generating temporary Sphinx files to %s", self.temp_dir)
         self.generate_files()
-        logger.info("Generated %s files to %s", self.generated_count, self.temp_dir)
+        logger.info("Generated %s temporary Sphinx files to %s", self.generated_count, self.temp_dir)
         logger.info("Building site help html to %s", self.output_dir)
 
         def doit(lng):
@@ -231,19 +245,32 @@ class Command(GeneratingCommand):
             actor_overview=self.actor_overview,
             model_referenced_from=model_referenced_from,
             model_ref=model_ref,
-            makedocs=self,
+            makehelp=self,
         )
         self.context['_'] = _
 
+        # from synodal import REPOS_DICT, REPOS_LIST
+        # myrepo = None
+        # for r in REPOS_LIST:
+        #     if r.settings_module == settings.SETTINGS_MODULE:
+        #         raise Exception("20230314 "+settings.SETTINGS_MODULE)
+
         def doit(lng):
             self.language = lng
-            os.makedirs(self.docspath(), exist_ok=True)
-            self.generate('makedocs/conf.tpl.py', 'conf.py')
-            self.generate('makedocs/index.tpl.rst', 'index.rst')
-            self.generate('makedocs/actors.tpl.rst', 'actors.rst')
+
+            tplpath = Path(self.docspath(), '.templates')
+            tplpath.mkdir(parents=True, exist_ok=True)
+            tplpath /= 'layout.html'
+            tplpath.write_text(LAYOUT_HTML)
+            self.generated_count += 1
+
+            self.generate('makehelp/conf.tpl.py', 'conf.py')
+            self.generate('makehelp/index.tpl.rst', 'index.rst')
+            self.generate('makehelp/copyright.tpl.rst', 'copyright.rst')
+            self.generate('makehelp/actors.tpl.rst', 'actors.rst')
             if include_useless:
-                self.generate('makedocs/models.tpl.rst', 'models.rst')
-                self.generate('makedocs/plugins.tpl.rst', 'plugins.rst')
+                self.generate('makehelp/models.tpl.rst', 'models.rst')
+                self.generate('makehelp/plugins.tpl.rst', 'plugins.rst')
 
         self.with_languages(doit)
 
@@ -332,7 +359,7 @@ class Command(GeneratingCommand):
         for a in actors.actors_list:
             if a.abstract: continue
             ref, text = self.htl.get_help_text_for_class(a)
-            label = ":doc:`{} <{}>`".format(a.label, a)
+            label = ":doc:`{} <{}>`".format((a.label or "???").strip(), a)
             name = ":class:`{} <{}>`".format(a, ref)
             title = "{} ({})".format(label, name)
             rows.append([title, text])
