@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2020 Rumma & Ko Ltd
+# Copyright 2016-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
@@ -21,7 +21,8 @@ class JinjaBuildMethod(DjangoBuildMethod):
             return
         tpl = self.get_template(action, elem)
         lang = str(elem.get_print_language()
-                   or settings.SITE.DEFAULT_LANGUAGE.django_code)
+                   or translation.get_language())
+                   # or settings.SITE.DEFAULT_LANGUAGE.django_code)
         ar = copy(ar)
         ar.renderer = settings.SITE.plugins.jinja.renderer
         # ar.tableattrs = dict()
