@@ -113,7 +113,7 @@ class JinjaRenderer(HtmlRenderer):
                 #     # par += ' <a href="{}">(Detail)</a>'.format(url)
                 #     par = '<a href="{}">{}</a>'.format(url, par)
 
-                items.append("<li>{}</li>".format(par))
+                items.append('<li class="clearfix">{}</li>'.format(par))
                 # items.append("<li>{}</li>".format(obj.as_paragraph(ar)))
             return "<ul>{}</ul>".format("".join(items))
 
@@ -140,6 +140,7 @@ class JinjaRenderer(HtmlRenderer):
             fdl=format_date.fdl,
             fdf=format_date.fdf,
             fdmy=format_date.fdmy,
+            strftime=settings.SITE.strftime,
             babelattr=settings.SITE.babelattr,
             babelitem=settings.SITE.babelitem,  # obsolete
             tr=settings.SITE.babelitem,
