@@ -4,4 +4,4 @@
 
 from django.conf import settings
 
-LINOD = "linod_" + settings.SITE.site_dir.name
+CHANNEL_NAME = "linod_" + settings.SITE.site_dir.name
