@@ -17,7 +17,7 @@ from importlib import import_module
 from rstgen.utils import py2url_txt
 from lino.api import ad
 from .parser import Parser, split_name_rest
-
+from etgen.html import tostring
 
 class Plugin(ad.Plugin):
 
@@ -49,7 +49,7 @@ class Plugin(ad.Plugin):
     """The front end to use when writing previews.
 
     If this is `None`, Lino will use the default front end
-    (:attr:`lino.core.site.Site.default_ui`).
+    (:attr:`lino.core.site.Site.web_front_ends`).
 
     Used on sites that are available via more than one web front ends.  The
     site maintainer must then decide which front end is the primary one.
@@ -68,33 +68,54 @@ class Plugin(ad.Plugin):
 
     """
 
+    short_preview_length = 300
+    short_preview_image_height = "8em"
 
     def on_plugins_loaded(self, site):
 
         self.parser = Parser()
 
-        def url2html(ar, s, cmdname, mentions):
+        def url2html(ar, s, cmdname, mentions, context):
             url, text = split_name_rest(s)
             if text is None:
                 text = url
             return '<a href="%s" target="_blank">%s</a>' % (url, text)
-
         self.parser.register_command('url', url2html)
 
-        def py2html(parser, s, cmdname, mentions):
+        def py2html(parser, s, cmdname, mentions, context):
             url, txt = py2url_txt(s)
             if url:
                 # lines = inspect.getsourcelines(s)
                 return '<a href="{0}" target="_blank">{1}</a>'.format(url, txt)
             return "<pre>{}</pre>".format(s)
-
         self.parser.register_command('py', py2html)
 
+        def show2html(ar, s, cmdname, mentions, context):
+            # kwargs = dict(header_level=3)  #, nosummary=True)
+            kwargs = dict()  #, nosummary=True)
+            dv = self.site.models.resolve(s)
+            sar = dv.request(parent=ar, limit=dv.preview_limit)
+            rv = ''
+            # rv += "20230325 [show {}]".format(dv)
+            for e in sar.renderer.table2story(sar, **kwargs):
+                rv += tostring(e)
+            return rv
+        self.parser.register_command('show', show2html)
+
+        if False:
+            # letting website users execute arbitrary code is a security risk
+            def eval2html(ar, s, cmdname, mentions, context):
+                from django.conf import settings  # context of exec command
+                sar = ar.spawn_request(renderer=settings.SITE.kernel.html_renderer)
+                return eval(compile(s, cmdname, 'eval'))
+            self.parser.register_command('eval', eval2html)
+
 
     def post_site_startup(self, site):
 
         if self.front_end is None:
-            self.front_end = site.kernel.default_ui
+            self.front_end = site.kernel.editing_front_end
+            # web_front_ends[0]
         else:
             self.front_end = site.plugins.resolve(self.front_end)
 
