@@ -14,7 +14,7 @@ TODO:
   which would be empty for # and @ but "]" for memo commands.
 
 """
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 import re
 import inspect
@@ -28,8 +28,11 @@ from django.conf import settings
 from django.db.models import Model
 from etgen import etree
 
-COMMAND_REGEX = re.compile(r"\[(\w+)\s*((?:[^[\]]|\[.*?\])*?)\]")
-#                                       ===...... .......=
+
+# COMMAND_REGEX = re.compile(r"\[(\w+)\s*((?:[^[\]]|\[.*?\])*?)\]")
+#                                         ===...... .......=
+COMMAND_REGEX = re.compile(r"(\\?\[)(\w+)\s*((?:[^[\]]|\[.*?\])*?)\]")
+#                                            ===...... .......=
 
 EVAL_REGEX = re.compile(r"\[=((?:[^[\]]|\[.*?\])*?)\]")
 
@@ -150,7 +153,7 @@ class Parser:
         #     def rnd(obj):
         #         return "[{} {}] ({})".format(name, obj.id, title(obj))
         if cmd is None:
-            def cmd(ar, s, cmdname, mentions):
+            def cmd(ar, s, cmdname, mentions, context):
                 # args = s.split(None, 1)
                 pk, text = split_name_rest(s)
 
@@ -246,22 +249,24 @@ All remaining arguments are used as the text of the link.
                 return matchobj.group(0)
         return func
 
-    def cmd_match_func(self, ar, mentions):
+    def cmd_match_func(self, ar, mentions, context):
 
         def func(matchobj):
-            cmd = matchobj.group(1)
+            if matchobj.group(1).startswith("\\"):
+                return matchobj.group(0)[1:]
+            cmd = matchobj.group(2)
             cmdh = self.commands.get(cmd, None)
             if cmdh is None:
                 return matchobj.group(0)
 
-            params = matchobj.group(2)
+            params = matchobj.group(3)
             params = params.replace('\\\n', ' ')
             params = params.replace('\xa0', ' ')
             params = params.replace('\u200b', ' ')
             params = params.replace('&nbsp;', ' ')
             params = str(params.strip())
             try:
-                return self.format_value(cmdh(ar, params, cmd, mentions))
+                return self.format_value(cmdh(ar, params, cmd, mentions, context))
             except Exception as e:
                 # raise
                 # logger.warning(e)
@@ -319,21 +324,22 @@ All remaining arguments are used as the text of the link.
         if ar is None:
             ar = settings.SITE.plugins.memo.ar
 
+        ctx = dict()
+        ctx.update(self.context)
+        if context is not None:
+            ctx.update(context)
+
         if self.suggesters:
             src = self.simplify_suggestions(src)
             regex = self.compile_suggester_regex()
             mf = self.suggester_match_func(ar)
             src = regex.sub(mf, src)
 
-        src = COMMAND_REGEX.sub(self.cmd_match_func(ar, mentions), src)
+        src = COMMAND_REGEX.sub(self.cmd_match_func(ar, mentions, ctx), src)
 
         if not self.safe_mode:
             # run-time context overrides the global parser context
-            ctx = dict()
-            ctx.update(self.context)
-            if context is not None:
-                ctx.update(context)
-            ctx.update(ar=ar)
+            ctx.update(ar=ar, settings=settings)
             src = EVAL_REGEX.sub(self.eval_match_func(ctx), src)
         return src
 
