@@ -16,7 +16,7 @@ from lino.core.utils import is_devserver
 class Plugin(ad.Plugin):
 
     verbose_name = _("Messages")
-    needs_plugins = ['lino.modlib.users', 'lino.modlib.memo']
+    needs_plugins = ['lino.modlib.users', 'lino.modlib.memo', 'lino.modlib.linod']
     media_name = 'js'
 
     use_push_api = False
@@ -32,18 +32,18 @@ class Plugin(ad.Plugin):
     mark_seen_when_sent = False
 
     def get_requirements(self, site):
-        if self.use_push_api and site.use_linod:
+        if self.use_push_api:
             yield 'pywebpush'
 
     def get_patterns(self):
-        if self.use_push_api and self.site.use_linod:
+        if self.use_push_api:
             from django.urls import re_path as url
             from . import views
             yield url(r'pushsubscription', views.PushSubscription.as_view())
             # yield url(r'testpush', views.TestPush.as_view())
 
     def get_js_includes(self, settings, language):
-        if self.site.use_linod:
+        if self.use_push_api:
             if settings.DEBUG:
                 yield self.build_lib_url(('push.js/push.min.js'))
             else:
@@ -60,7 +60,7 @@ class Plugin(ad.Plugin):
         m.add_action('notify.AllMessages')
 
     def get_head_lines(self, site, request):
-        if self.use_push_api and site.use_linod:
+        if self.use_push_api:
             yield """<script type="text/javascript">
                 window.addEventListener('click', () => {
                     Notification.requestPermission((status) => {
@@ -89,12 +89,12 @@ class Plugin(ad.Plugin):
                 });
             </script>"""
 
-        if not self.site.use_linod:
-            return
-        from lino.utils.jsgen import py2js
-        user_name = "anony"
-        if request.user.is_authenticated:
-            user_name = request.user.username
+        # if not self.site.use_linod:
+        #     return
+        # from lino.utils.jsgen import py2js
+        # user_name = "anony"
+        # if request.user.is_authenticated:
+        #     user_name = request.user.username
         site_title = site.title or 'Lino-framework'
         if self.site.default_ui == 'lino_react.react':
             js_to_add = """
