@@ -2,7 +2,6 @@
 # Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-import logging ; logger = logging.getLogger(__name__)
 import json
 from io import StringIO
 from lxml import etree
@@ -18,9 +17,10 @@ from lino.api import dd, rt, _
 
 from lino.core import constants
 # from lino.core.roles import SiteStaff
+from lino import logger
 from lino.core.gfks import gfk2lookup
 # from lino.core.requests import BaseRequest
-from lino.core.site import html2text
+from lino.utils import html2text
 
 from lino.mixins import Created, ObservedDateRange
 from lino.modlib.gfks.mixins import Controllable
@@ -102,7 +102,7 @@ class ClearSeen(dd.Action):
             obj.save()
         ar.success(refresh_all=True)
 
-if dd.plugins.notify.use_push_api and settings.SITE.use_linod:
+if dd.plugins.notify.use_push_api: # and settings.SITE.use_linod:
 
     class Subscription(UserAuthored):
         allow_cascaded_delete = ['user']
@@ -127,7 +127,7 @@ class Message(UserAuthored, Controllable, Created):
     seen = models.DateTimeField(_("seen"), null=True, editable=False)
     sent = models.DateTimeField(_("sent"), null=True, editable=False)
     body = dd.RichTextField(_("Body"), editable=False, format='html', default='')
-    mail_mode = MailModes.field(default=MailModes.as_callable('often'))
+    mail_mode = MailModes.field(default='often')
     subject = models.CharField(
         _("Subject"), max_length=250, editable=False)
 
@@ -225,27 +225,39 @@ class Message(UserAuthored, Controllable, Created):
     clear_seen = ClearSeen()
 
     @classmethod
-    def send_summary_emails(cls, mm):
+    def send_summary_emails(cls, ar, mm):
+        # print("20231021 send_summary_emails", mm, ar.logger)
+        # ar.logger.debug("20231021 (propagate is %s)", ar.logger.propagate)
+        # raise Warning("20231230")
         qs = cls.objects.filter(sent__isnull=True)
         qs = qs.exclude(user__email='')
         qs = qs.filter(mail_mode=mm).order_by('user')
         if qs.count() == 0:
+            ar.logger.debug(
+                "No email notifications to send for %s.", mm)
             return
+        mail_users = settings.SITE.user_model.get_active_users().exclude(email='')
         # from lino.core.renderer import MailRenderer
         # ar = rt.login(renderer=MailRenderer())
-        ar = rt.login(renderer=dd.plugins.memo.front_end.renderer, permalink_uris=True)
+        # ar = rt.login(renderer=dd.plugins.memo.front_end.renderer, permalink_uris=True)
+        ar.renderer = dd.plugins.memo.front_end.renderer
+        ar.permalink_uris = True
         # ar = rt.login()
         # ar = rt.login(renderer=settings.SITE.kernel.default_ui.renderer)
         context = ar.get_printable_context()
         sender = settings.SERVER_EMAIL
         template = rt.get_template('notify/summary.eml')
         users = dict()
+        def collect(user, obj):
+            lst = users.setdefault(user, [])
+            lst.append(obj)
         for obj in qs:
-            if obj.user is not None:
-                lst = users.setdefault(obj.user, [])
-                lst.append(obj)
-        dd.logger.debug(
-            "Send out %s summaries for %d users.", mm, len(users))
+            if obj.user is None:
+                for u in mail_users: collect(u, obj)
+            else:
+                collect(obj.user, obj)
+        ar.logger.debug(
+            "Send out '%s' summaries for %d users.", mm, len(users))
         for user, messages in users.items():
             with translation.override(user.language):
                 if len(messages) == 1:
@@ -256,7 +268,7 @@ class Message(UserAuthored, Controllable, Created):
                 context.update(user=user, messages=messages)
                 body = template.render(**context)
                 # dd.logger.debug("20170112 %s", body)
-                rt.send_email(subject, sender, body, [user.email])
+                ar.send_email(subject, sender, body, [user.email])
                 for msg in messages:
                     msg.sent = timezone.now()
                     if dd.plugins.notify.mark_seen_when_sent:
@@ -291,8 +303,7 @@ dd.inject_field(
     models.BooleanField(_('Notify myself'), default=False))
 
 dd.inject_field(
-    'users.User', 'mail_mode',
-    MailModes.field(default=MailModes.as_callable('often')))
+    'users.User', 'mail_mode', MailModes.field(default='often'))
 
 
 class Messages(dd.Table):
@@ -425,17 +436,18 @@ class MyMessages(My, Messages):
 #         h)
 
 @dd.schedule_often(every=10)
-def send_pending_emails_often():
-    rt.models.notify.Message.send_summary_emails(MailModes.often)
+def send_pending_emails_often(ar):
+    # print("20231021 send_pending_emails_often()", ar.logger)
+    rt.models.notify.Message.send_summary_emails(ar, MailModes.often)
 
 
 @dd.schedule_daily()
-def send_pending_emails_daily():
-    rt.models.notify.Message.send_summary_emails(MailModes.daily)
+def send_pending_emails_daily(ar):
+    rt.models.notify.Message.send_summary_emails(ar, MailModes.daily)
 
 
 # @dd.schedule_often(every=10)
-# def send_pending_emails_often():
+# def send_pending_emails_often(ar):
 #     Message = rt.models.notify.Message
 #     qs = Message.objects.filter(sent__isnull=True)
 #     qs = qs.filter(user__mail_mode=MailModes.immediately)
@@ -453,22 +465,24 @@ remove_after = dd.plugins.notify.remove_after
 if remove_after:
 
     @dd.schedule_daily()
-    def clear_seen_messages():
-
+    def clear_seen_messages(ar):
         Message = rt.models.notify.Message
         qs = Message.objects.filter(
             created__lt=timezone.now() - timedelta(days=remove_after))
+        what = "notification messages older than {} days".format(remove_after)
         if dd.plugins.notify.keep_unseen:
             qs = qs.filter(seen__isnull=False)
-        if qs.count() > 0:
-            dd.logger.info(
-                "Removing %d messages older than %d hours.",
-                qs.count(), remove_after)
+            what = "(seen) " + what
+        if count := qs.count() > 0:
+            ar.logger.info("Remove %d %s", count, what)
             qs.delete()
+        else:
+            ar.logger.debug("No %s to remove", what)
 
-import warnings
 
-warnings.filterwarnings(
-    "ignore",
-    "You do not have a working installation of the service_identity module: .* Many valid certificate/hostname mappings may be rejected.",
-    UserWarning)
+# import warnings
+#
+# warnings.filterwarnings(
+#     "ignore",
+#     "You do not have a working installation of the service_identity module: .* Many valid certificate/hostname mappings may be rejected.",
+#     UserWarning)
