@@ -1,9 +1,9 @@
-# Copyright 2015-2019 Rumma & Ko Ltd
+# Copyright 2015-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Provides a menu hook for several other plugins.
 
-See :doc:`/specs/office`.
+See :doc:`/plugins/office`.
 
 """
 
@@ -11,5 +11,4 @@ from lino.api import ad, _
 
 
 class Plugin(ad.Plugin):
-    "See :doc:`/dev/plugins`."
     verbose_name = _("Office")
