@@ -1,17 +1,17 @@
-# Copyright 2015-2019 Rumma & Ko Ltd
+# Copyright 2015-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino.core.roles import UserRole
+from lino.modlib.uploads.roles import UploadsReader
 
 
-class OfficeUser(UserRole):
+class OfficeUser(UploadsReader):
     pass
 
 
-class OfficeOperator(UserRole):
+class OfficeOperator(UploadsReader):
     pass
 
 
 class OfficeStaff(OfficeUser, OfficeOperator):
     pass
-
