@@ -2,7 +2,7 @@
 # Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 import shutil
@@ -185,9 +185,9 @@ class CachedPrintAction(BasePrintAction):
             leaf = mf.parts[-1]
             if obj.build_time is None:
                 obj.build_target(ar)
-                ar.info("%s has been built.", leaf)
+                ar.debug("%s has been built.", leaf)
             else:
-                ar.info("Reused %s from cache.", leaf)
+                ar.debug("Reused %s from cache.", leaf)
 
             url = mf.get_url(ar.request)
             self.notify_done(ar, bm, leaf, url, **kw)
@@ -235,7 +235,7 @@ class EditTemplate(BasePrintAction):
 
         lcd = settings.SITE.confdirs.LOCAL_CONFIG_DIR
         if lcd is None:
-            # ar.info("No local config directory in %s " %
+            # ar.debug("No local config directory in %s " %
             #         settings.SITE.confdirs)
             raise Warning("No local config directory. "
                           "Contact your system administrator.")
@@ -261,12 +261,12 @@ class EditTemplate(BasePrintAction):
 
         if not (settings.SITE.webdav_protocol or has_davlink):
             msg = "cp %s %s" % (filename, local_file)
-            ar.info(msg)
+            ar.debug(msg)
             raise Warning("WebDAV is not enabled. "
                           "Contact your system administrator.")
 
         def doit(ar):
-            ar.info("Going to open url: %s " % url)
+            ar.debug("Going to open url: %s " % url)
             if settings.SITE.webdav_protocol:
                 ar.success(open_url=url)
             else:
@@ -277,13 +277,15 @@ class EditTemplate(BasePrintAction):
             doit(ar)
         else:
             # raise Exception("20191019 {} is not {}".format(filename, local_file))
-            ar.info("Gonna copy %s to %s", filename, local_file)
+            ar.debug("Gonna copy %s to %s", filename, local_file)
 
             def ok(ar2):
                 logger.info(
                     "%s made local template copy %s", ar.user, local_file)
                 rt.makedirs_if_missing(os.path.dirname(local_file))
-                shutil.copy(filename, local_file)
+                shutil.copyfile(filename, local_file)
+                # shutil.copy() can cause PermissionError if dst exists and is
+                # owned by another user
                 doit(ar2)
 
             msg = _(
