@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2017 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -7,7 +7,7 @@ Choicelists for `lino.modlib.printing`.
 
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 import io
@@ -174,8 +174,7 @@ class SimpleBuildMethod(TemplatedBuildMethod):
                 (tpl_leaf, elem.__class__.__name__, str(elem),
                  self.template_ext))
 
-        lang = elem.get_print_language() \
-            or settings.SITE.DEFAULT_LANGUAGE.django_code
+        lang = elem.get_print_language() or translation.get_language()
         if lang != settings.SITE.DEFAULT_LANGUAGE.django_code:
             name = tpl_leaf[:-len(self.template_ext)] + \
                 "_" + lang + self.template_ext
@@ -243,8 +242,8 @@ class XmlBuildMethod(DjangoBuildMethod):
             return
         tpl = self.get_template(action, elem)
 
-        lang = str(elem.get_print_language()
-                   or settings.SITE.DEFAULT_LANGUAGE.django_code)
+        lang = str(elem.get_print_language() or translation.get_language())
+                   # or settings.SITE.DEFAULT_LANGUAGE.django_code)
 
         with translation.override(lang):
             cmd_options = elem.get_build_options(self)
