@@ -1,24 +1,18 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2018 Rumma & Ko Ltd
+# Copyright 2016-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-from __future__ import unicode_literals
-from builtins import range
-from builtins import object
-
 from django.db import models
 
 from lino.api import dd, _
 
-
-# SUMMARY_PERIODS = ['yearly', 'monthly', 'timeless']
-SUMMARY_PERIODS = ['yearly', 'monthly']
+SUMMARY_PERIODS = ['yearly', 'monthly', 'weekly', 'timeless']
 
 class ComputeResults(dd.Action):
     label = _("Update summary data")
     # icon_name = 'lightning'
-    # button_text = u"∑"  # u"\u2211"  # N-ARY SUMMATION
-    button_text = u"Σ"  # u"\u03A3"  # GREEK CAPITAL LETTER SIGMA
+    # button_text = "∑"  # "\u2211"  # N-ARY SUMMATION
+    button_text = "Σ"  # "\u03A3"  # GREEK CAPITAL LETTER SIGMA
 
     readonly = False
 
@@ -33,7 +27,7 @@ class UpdateSummariesByMaster(ComputeResults):
     def __init__(self, master_model, summary_models):
         self.master_model = master_model
         self.summary_models = summary_models
-        super(UpdateSummariesByMaster, self).__init__()
+        super().__init__()
 
     def run_from_ui(self, ar, fix=None):
         for master in ar.selected_rows:
@@ -100,7 +94,7 @@ class SlaveSummarized(Summarized):
 
     class Meta(object):
         abstract = True
-        
+
     allow_cascaded_delete = 'master'
 
     @classmethod
@@ -129,7 +123,7 @@ class SlaveSummarized(Summarized):
     #     obj.compute_summary_values()
 
 
-class MonthlySummarized(Summarized):
+class DateSummarized(Summarized):
 
     class Meta(object):
         abstract = True
@@ -146,7 +140,9 @@ class MonthlySummarized(Summarized):
             raise Exception(
                 "Invalid summary_period {!r} for {}".format(
                     cls.summary_period, cls))
-        super(MonthlySummarized, cls).on_analyze(site)
+        if cls.summary_period == "weekly":
+            cls._meta.get_field('month').verbose_name = _("Week")
+        super().on_analyze(site)
 
 
     @classmethod
@@ -161,12 +157,18 @@ class MonthlySummarized(Summarized):
             elif cls.summary_period == 'monthly':
                 for month in range(1, 13):
                     yield year, month
+            elif cls.summary_period == 'weekly':
+                for week in range(1, 53):
+                    yield year, week
 
     def add_date_filter(self, qs, fldname, **kwargs):
         if self.year is not None:
             kwargs[fldname + '__year'] = self.year
         if self.month is not None:
-            kwargs[fldname + '__month'] = self.month
+            if cls.summary_period == 'monthly':
+                kwargs[fldname + '__month'] = self.month
+            elif cls.summary_period == 'weekly':
+                kwargs[fldname + '__week'] = self.month
         return qs.filter(**kwargs)
 
     # @classmethod
@@ -177,18 +179,15 @@ class MonthlySummarized(Summarized):
 
     @classmethod
     def update_for_filter(cls, **flt):
-        for year, month in cls.get_summary_periods():
-            flt.update(year=year, month=month)
+        for year, period in cls.get_summary_periods():
+            if period is not None:
+                flt.update(month=period)
+            if year is not None:
+                flt.update(year=year)
             # obj = cls.get_for_period(**flt)
             for obj in cls.get_for_filter(**flt):
                 obj.compute_summary_values()
 
 
-MonthlySummarized.set_widget_options('year', hide_sum=True)
-MonthlySummarized.set_widget_options('month', hide_sum=True)
-
-class MonthlySlaveSummary(MonthlySummarized, SlaveSummarized):
-
-    class Meta(object):
-        abstract = True
-
+DateSummarized.set_widget_options('year', hide_sum=True)
+DateSummarized.set_widget_options('month', hide_sum=True)
