@@ -1,12 +1,10 @@
-# Copyright 2016-2018 Rumma & Ko Ltd
+# Copyright 2016-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-
-from __future__ import unicode_literals, print_function
-
 from django.conf import settings
 # from django.db import models
 from lino.api import dd, rt, _
+from lino.core.requests import BaseRequest
 
 from .mixins import UpdateSummariesByMaster, SlaveSummarized, Summarized
 
@@ -16,7 +14,7 @@ class CheckAllSummaries(dd.Action):
 
     def run_from_ui(self, ar, fix=None):
         for sm in rt.models_by_base(Summarized, toplevel_only=True):
-            dd.logger.info("Updating summary data for %s ...", sm._meta.verbose_name_plural)
+            ar.logger.info("Update summary data for %s ...", sm._meta.verbose_name_plural)
             sm.check_all_summaries()
 
         ar.set_response(refresh=True)
@@ -53,5 +51,7 @@ def masters_with_summaries():
 
 
 @dd.schedule_daily()
-def checksummaries():
-    rt.login().run(settings.SITE.site_config.check_all_summaries)
+def checksummaries(ar):
+    # BaseRequest(parent=ar).run(settings.SITE.site_config.check_all_summaries)
+    # rt.login().run(settings.SITE.site_config.check_all_summaries)
+    settings.SITE.site_config.check_all_summaries.run_from_session(ar)
