@@ -4,7 +4,6 @@
 """Defines some "system features", especially the :class:`SiteConfig` model.
 See :doc:`/specs/system`.
 
-
 """
 
 from lino import ad, _
@@ -21,7 +20,7 @@ class Plugin(ad.Plugin):
     needs_plugins = ['lino.modlib.printing']
 
     use_dashboard_layouts = False
-    """Whether to use system.DashboardLayouts.
+    """Whether to use system.DashboardLayouts. This feature is broken.
     """
 
     def setup_config_menu(self, site, user_type, m):
@@ -45,3 +44,6 @@ class Plugin(ad.Plugin):
                     yield E.div(*chunks)
 
             site.add_welcome_handler(welcome_messages)
+
+    def get_requirements(self, site):
+        yield "num2words"
