@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2022 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from etgen.html import E
@@ -15,15 +15,15 @@ from django.apps import apps ; get_models = apps.get_models
 from lino.api import dd, rt
 from lino.core import actions
 from lino.core.utils import full_model_name
+from lino.core.utils import is_devserver
 from lino.core.roles import SiteStaff
 from lino.core.actors import resolve_action
 
 from lino.modlib.printing.choicelists import BuildMethods
 from lino.modlib.checkdata.choicelists import Checker
 
-
 # import them here to have them on rt.models.system:
-from .choicelists import YesNo, Genders, PeriodEvents, DashboardLayouts
+from .choicelists import YesNo, Genders, PeriodEvents, DashboardLayouts, DurationUnits, Recurrences, Weekdays
 from .mixins import Lockable
 
 
@@ -66,7 +66,7 @@ class SiteConfig(dd.Model):
     This is Lino's equivalent of Django's :setting:`SITE_ID` setting.
     Lino applications don't need ``django.contrib.sites`` (`The
     "sites" framework
-    <https://docs.djangoproject.com/en/4.1/ref/contrib/sites/>`_)
+    <https://docs.djangoproject.com/en/5.0/ref/contrib/sites/>`_)
     because an analog functionality is provided by
     :mod:`lino.modlib.system`.
     """
@@ -87,7 +87,7 @@ class SiteConfig(dd.Model):
     site_company = dd.ForeignKey(
         "contacts.Company",
         blank=True, null=True,
-        verbose_name=_("Site operator"),
+        verbose_name=_("Site owner"),
         related_name='site_company_sites')
 
     _site_config = None
@@ -102,6 +102,7 @@ class SiteConfig(dd.Model):
         site = settings.SITE
 
         if not site._startup_done:
+            site.logger.debug("site_config is None because startup not done")
             return None
 
         if cls._site_config is None:
@@ -132,6 +133,7 @@ class SiteConfig(dd.Model):
                 # said "SiteConfig 1 does not exist"
                 # cannot save the instance here because the db table possibly doesn't yet exit.
                 #~ self._site_config.save()
+            cls._site_config.on_startup()
         return cls._site_config
 
     def __str__(self):
@@ -158,6 +160,18 @@ class SiteConfig(dd.Model):
     #             kw[fld.attname] = getattr(other, fld.attname)
     #     self.update(**kw)
 
+    def on_startup(self):
+        # if not self.site_company:
+        #     raise Exception("20230423")
+        if self.site_company:
+            # print("20230423", self.site_company)
+            settings.SITE.copyright_name = str(self.site_company)
+            if self.site_company.url:
+                settings.SITE.copyright_url = self.site_company.url
+
+    # def full_clean(self, *args, **kw):
+    #     super().full_clean(*args, **kw)
+
     def save(self, *args, **kw):
         cls = self.__class__
         if cls._site_config is None:
