@@ -90,7 +90,7 @@ class Plugin(ad.Plugin):
     def on_init(self):
         super().on_init()
         if self.site.default_ui != "lino.modlib.extjs":
-            self.deactivate()
+            self.hide()
 
     def get_used_libs(self, html=False):
         if html is not None:
