@@ -1,11 +1,7 @@
 # Copyright 2009-2018 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-from builtins import object
-
-import logging
-logger = logging.getLogger(__name__)
-
+from lino import logger
 
 from django.db import models
 from django.utils.translation import gettext_lazy as _
