@@ -2,10 +2,7 @@
 # Copyright 2009-2015 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-from builtins import str
-
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 from django import http
 from django.conf import settings
