@@ -1,11 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2022 Rumma & Ko Ltd
+# Copyright 2008-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import os
 from os.path import join, exists
 import glob
 from pathlib import Path
+from html import escape
 
 from django.db import models
 from django.db.models.fields.files import FieldFile
@@ -21,12 +22,16 @@ from lino.core.utils import model_class_path
 from lino import mixins
 from lino.modlib.gfks.mixins import Controllable
 from lino.modlib.users.mixins import UserAuthored, My
-from lino.modlib.office.roles import OfficeUser, OfficeStaff, OfficeOperator
+# from lino.modlib.office.roles import OfficeUser, OfficeStaff, OfficeOperator
+from lino.modlib.office.roles import OfficeStaff
 from lino.mixins import Referrable
 from lino.modlib.checkdata.choicelists import Checker
+from lino.modlib.publisher.mixins import Publishable
 
+from .actions import CameraStream
 from .choicelists import Shortcuts, UploadAreas
 from .mixins import UploadController, UploadBase
+from .roles import UploadsReader
 # from .mixins import FileUsable
 from lino.core import constants
 
@@ -89,7 +94,7 @@ class UploadType(mixins.BabelNamed):
     shortcut = Shortcuts.field(blank=True)
 
 
-class Upload(UploadBase, UserAuthored, Controllable):
+class Upload(UploadBase, UserAuthored, Controllable, Publishable):
 
     class Meta(object):
         abstract = dd.is_abstract_model(__name__, 'Upload')
@@ -106,6 +111,11 @@ class Upload(UploadBase, UserAuthored, Controllable):
     description = models.CharField(
         _("Description"), max_length=200, blank=True)
 
+    copyright = models.CharField(
+        _("Copyright"), max_length=100, blank=True)
+
+    camera_stream = CameraStream()
+
     def __str__(self):
         if self.description:
             s = self.description
@@ -129,6 +139,28 @@ class Upload(UploadBase, UserAuthored, Controllable):
             return cmd
         return None
 
+    def get_file_url(self):
+        if self.file.name:
+            return settings.SITE.build_media_url(self.file.name)
+        if self.library_file and self.volume_id and self.volume.base_url:
+            return settings.SITE.build_static_url(
+                self.volume.base_url, self.library_file)
+            # return self.volume.base_url + self.library_file
+        return None
+
+    def get_real_file_size(self):
+        if self.file:
+            return self.file.size
+        if self.volume_id and self.library_file:
+            pth = os.path.join(self.volume.root_dir, self.library_file)
+            return os.path.getsize(pth)
+
+    def disabled_fields(self, ar):
+        df = super().disabled_fields(ar)
+        if ar.renderer.front_end.app_label != 'react':
+            df.add('camera_stream')
+        return df
+
     @dd.displayfield(_("Description"))
     def description_link(self, ar):
         s = str(self)
@@ -151,10 +183,54 @@ class Upload(UploadBase, UserAuthored, Controllable):
         return M.objects.filter(upload_area=upload_area)
 
     def full_clean(self, *args, **kw):
-        super(Upload, self).full_clean(*args, **kw)
+        super().full_clean(*args, **kw)
         if self.type is not None:
             self.upload_area = self.type.upload_area
 
+    def get_gallery_item(self, ar):
+        d = super().get_gallery_item(ar)
+        d.update(title=str(self), id=self.pk)
+        cmd = self.get_memo_command(ar)
+        if cmd is not None:
+            d.update(memo_cmd=cmd)
+        return d
+
+    @dd.htmlbox()
+    def preview(self, ar):
+        url = self.get_file_url()
+        if url is None or url.endswith(".pdf"):
+            txt = _("No preview available")
+            return '<p style="text-align: center;padding: 2em;">({})</p>'.format(txt)
+        return '<img src="{}" style="max-width: 100%; max-height: 20em">'.format(url)
+
+    @dd.htmlbox(_("Thumbnail"))
+    def thumbnail(self, ar):
+        # url = settings.SITE.build_media_url(self.file.name)
+        url = self.get_file_url()
+        return '<img src="{}" style="height: 15ch; max-width: 22.5ch">'.format(url)
+
+    @dd.htmlbox(_("Thumbnail Medium"))
+    def thumbnail_medium(self, ar):
+        # url = settings.SITE.build_media_url(self.file.name)
+        url = self.get_file_url()
+        return '<img src="{}" style="width: 30ch;">'.format(url)
+
+    @dd.htmlbox(_("Thumbnail Large"))
+    def thumbnail_large(self, ar):
+        # url = settings.SITE.build_media_url(self.file.name)
+        url = self.get_file_url()
+        return '<img src="{}" style="width: 70ch;">'.format(url)
+
+    def as_page(self, ar, **kwargs):
+        yield "<h1>{}</h1>".format(self)
+        url = self.get_file_url()
+        yield '<img src="{}" style="width: 100%;">'.format(url)
+        if self.description:
+            yield escape(self.description)
+        if self.copyright:
+            yield _("Copyright") + " "
+            yield escape(self.copyright)
+
 
 # class FileUsage(FileUsable):
 #     class Meta(object):
@@ -258,19 +334,31 @@ class UploadTypes(dd.Table):
     uploads.UploadsByType
     """
 
+class UploadDetail(dd.DetailLayout):
 
-class Uploads(dd.Table):
-    model = 'uploads.Upload'
-    required_roles = dd.login_required((OfficeUser, OfficeOperator))
-    column_names = "file type user owner description *"
-    order_by = ['-id']
+    main = """
+    left preview
+    """
 
-    detail_layout = dd.DetailLayout("""
+    left = """
     file user
     volume:10 library_file:40
     upload_area type description
     owner
-    """, window_size=(80, 'auto'))
+    copyright
+    """
+
+    window_size = (80, 'auto')
+
+
+class Uploads(dd.Table):
+    model = 'uploads.Upload'
+    # required_roles = dd.login_required((OfficeUser, OfficeOperator))
+    required_roles = dd.login_required(UploadsReader)
+    column_names = "file type user owner description id *"
+    order_by = ['-id']
+
+    detail_layout = 'uploads.UploadDetail'
 
     insert_layout = """
     type
@@ -287,7 +375,7 @@ class Uploads(dd.Table):
 
     @classmethod
     def get_request_queryset(cls, ar, **filter):
-        qs = super(Uploads, cls).get_request_queryset(ar, **filter)
+        qs = super().get_request_queryset(ar, **filter)
         pv = ar.param_values
         if pv.user:
             qs = qs.filter(user=pv.user)
@@ -307,7 +395,8 @@ class UploadsByType(Uploads):
 
 
 class MyUploads(My, Uploads):
-    required_roles = dd.login_required((OfficeUser, OfficeOperator))
+    required_roles = dd.login_required(UploadsReader)
+    # required_roles = dd.login_required((OfficeUser, OfficeOperator))
     column_names = "file library_file description user owner *"
     # order_by = ["modified"]
 
@@ -322,7 +411,8 @@ class MyUploads(My, Uploads):
     #     return kw
 
 class AreaUploads(Uploads):
-    required_roles = dd.login_required((OfficeUser, OfficeOperator))
+    # required_roles = dd.login_required((OfficeUser, OfficeOperator))
+    required_roles = dd.login_required(UploadsReader)
     stay_in_grid = True
     # _upload_area = UploadAreas.general
     display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
@@ -377,18 +467,13 @@ class AreaUploads(Uploads):
                     m,  text,  # _("Edit"),
                     # icon_name='application_form',
                     title=_("Edit metadata of the uploaded file."))
-                if m.file.name:
-                    url = settings.SITE.build_media_url(m.file.name)
-                elif m.volume_id and m.volume.base_url and m.library_file:
-                    url = m.volume.base_url + m.library_file
-                else:
-                    url = None
+                url = m.get_file_url()
                 if url:
                     show = ar.renderer.href_button(
                         url,
                         # u"\u21A7",  # DOWNWARDS ARROW FROM BAR (↧)
                         # u"\u21E8",
-                        u"\u21f2",  # SOUTH EAST ARROW TO CORNER (⇲)
+                        "\u21f2",  # SOUTH EAST ARROW TO CORNER (⇲)
                         style="text-decoration:none;",
                         # _(" [show]"),  # fmt(m),
                         target='_blank',
@@ -484,13 +569,12 @@ def before_analyze(sender, **kwargs):
                 after_show = ar.get_status()
                 obj = sar.data_iterator[0]
                 items.append(sar.renderer.href_button(
-                    sender.build_media_url(obj.file.name),
+                    obj.get_file_url(),
                     _("show"),
                     target='_blank',
                     icon_name='page_go',
                     style="vertical-align:-30%;",
-                    title=_("Open the uploaded file in a "
-                            "new browser window")))
+                    title=_("Open the uploaded file in a new browser window")))
                 after_show.update(record_id=obj.pk)
                 items.append(sar.window_action_button(
                     sar.ah.actor.detail_action,
