@@ -22,7 +22,7 @@ def send_welcome_email(ar, obj, recipients):
     subject = _("Welcome on {site}").format(
         site=settings.SITE.title or settings.SITE.verbose_name)
     body = obj.get_welcome_email_body(ar)
-    rt.send_email(subject, sender, body, recipients)
+    ar.send_email(subject, sender, body, recipients)
 
 class CheckedSubmitInsert(SubmitInsert):
     """Like the standard :class:`lino.core.actions.SubmitInsert`, but
@@ -214,7 +214,7 @@ class ChangePassword(dd.Action):
                 obj.save()
                 done_for.append(obj)
             else:
-                ar.info("Incorrect current password for %s." % obj)
+                ar.debug("Incorrect current password for %s." % obj)
 
         # if ar.request is not None:
         #     auth.login(ar.request, obj)
@@ -301,6 +301,7 @@ def get_social_auth_links_func(content_header, flex_row, ar=None):
         return tostring(E.div(*elems))
     return text_fn
 
+
 class SignIn(dd.Action):
     label = _("Sign in")
     select_rows = False
@@ -310,7 +311,7 @@ class SignIn(dd.Action):
         social_auth_links=dd.Constant(
             get_social_auth_links_func(gettext("Or sign in with"), flex_row=True))
     )
-    if not settings.SITE.has_feature('third_party_authentication'):
+    if not dd.get_plugin_setting('users', 'third_party_authentication'):
         parameters['social_auth_links'] = dd.DummyField()
 
     params_layout = dd.Panel("""
@@ -329,16 +330,17 @@ class SignIn(dd.Action):
         # print("20210212 SignIn.run_from_ui()", ipdict.ip_records)
         validate_sessions_limit(ar.request)
         pv = ar.action_param_values
+        # ar.subst_user = ar.request.subst_user = None
         user = auth.authenticate(
             ar.request, username=pv.username, password=pv.password)
         if user is None:
-            ar.error(_("Failed to log in as {}.".format(pv.username)))
+            ar.error(_("Failed to sign in as {}.".format(pv.username)))
         else:
             # user.is_authenticated:
             auth.login(ar.request, user)
             # gurl = ar.renderer.front_end.build_plain_url()
             ar.success(
-                _("Now logged in as {}").format(user),
+                _("Now signed in as {}").format(user),
                 close_window=True,
                 goto_url='/')
 
@@ -355,7 +357,7 @@ class CreateAccount(dd.Action):
         social_auth_links=dd.Constant(
             get_social_auth_links_func(gettext("Create account with"), flex_row=False))
     )
-    if not settings.SITE.has_feature('third_party_authentication'):
+    if not settings.SITE.plugins.users.third_party_authentication:
         parameters['social_auth_links'] = dd.DummyField()
 
     params_layout = """
@@ -405,21 +407,6 @@ class ConnectAccount(dd.Action):
 
 
 class SignInWithSocialAuth(SignIn):
-    # 20171207 nice as an example of a action dialog window with a
-    # HtmlBox, but we don't currently use it.
-    parameters = dict(
-        social_auth_links=dd.HtmlBox(
-            # _("Other authentications"),
-            default=E.div(*settings.SITE.get_social_auth_links())),
-        # social_auth_links=dd.Constant(
-        #     settings.SITE.get_social_auth_links),
-        # social=social_auth_field(),
-        username=dd.CharField(_("Username")),
-        password=dd.PasswordField(_("Password"), blank=True)
-    )
-    # params_layout = dd.ActionParamsLayout("""
     params_layout = dd.Panel("""
-    username
-    password
     social_auth_links
-    """, label_align="left", window_size=(60,10))
+    """)
