@@ -2,7 +2,7 @@
 # Copyright 2010-2020 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 from django.conf import settings
 from lino.modlib.users.choicelists import UserTypes
