@@ -118,6 +118,7 @@ class UserAuthored(Authored):
         inserts the *real* user, not subst_user.
         This is important for cal.Event.
         """
+        # raise Exception("20230331 {}".format(ar.user))
         if ar and self.user_id is None:
             u = ar.user
             if u is not None:
@@ -193,7 +194,7 @@ class StartPlan(dd.Action):
     #     print("20180905 {} on {} {}".format(name, owner, self.label))
     #     return super(StartPlan, self).attach_to_actor(owner, name)
 
-    def get_options(self, ar):
+    def get_plan_options(self, ar):
         return {}
 
     def get_plan_model(self, ar):
@@ -201,7 +202,7 @@ class StartPlan(dd.Action):
         return ar.actor.model
 
     def run_from_ui(self, ar, **kw):
-        options = self.get_options(ar)
+        options = self.get_plan_options(ar)
         pm = self.get_plan_model(ar)
         plan = pm.run_start_plan(ar.get_user(), **options)
         # plan = self.defining_actor.model.run_start_plan(
@@ -215,6 +216,7 @@ class UpdatePlan(dd.Action):
     label = _("Update plan")
     icon_name = 'lightning'
     sort_index = 53
+    # button_text = "F"
 
     def run_from_ui(self, ar, **kw):
         for plan in ar.selected_rows:
