@@ -2,15 +2,15 @@
 # Copyright 2011-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-import datetime
+from datetime import timedelta
 from django.db import models
 from django.db.models import Q
 from django.conf import settings
 from django.contrib.auth.base_user import AbstractBaseUser, BaseUserManager
 from django.utils import timezone
 
-from lino.api import dd, rt, _
 from etgen.html import E
+from lino.api import dd, rt, _
 from lino.core import userprefs
 # from lino.core.fields import NullCharField
 from lino.core.roles import SiteAdmin
@@ -26,7 +26,7 @@ from .actions import MySettings
 # from .actions import SignIn
 from lino.modlib.about.choicelists import TimeZones, DateFormats
 from lino.modlib.system.choicelists import DashboardLayouts
-from lino.modlib.printing.mixins import Printable
+from lino.modlib.publisher.mixins import Publishable
 
 from lino.core.roles import Supervisor
 
@@ -68,7 +68,7 @@ class UserManager(BaseUserManager):
         return self._create_user(username, email, password, **extra_fields)
 
 
-class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange):
+class User(AbstractBaseUser, Contactable, CreatedModified, Publishable, DateRange):
     class Meta(object):
         app_label = 'users'
         verbose_name = _('User')
@@ -146,7 +146,7 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
     def is_verification_code_expired(self):
         if self.verification_code_sent_on is None:
             return False
-        return (self.verification_code_sent_on + datetime.timedelta(
+        return (self.verification_code_sent_on + timedelta(
             minutes=dd.plugins.users.verification_code_expires
         ) < timezone.now())
 
@@ -330,6 +330,16 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
     def get_anonymous_user(cls):
         return settings.SITE.get_anonymous_user()
 
+    @classmethod
+    def filter_active_users(self, qs, today, prefix=''):
+        qs = qs.filter(
+            Q(**{prefix+"start_date__isnull":True}) |
+            Q(**{prefix+"start_date__lte": today}))
+        qs = qs.filter(
+            Q(**{prefix+"end_date__isnull":True}) |
+            Q(**{prefix+"end_date__gte": today}))
+        return qs
+
     # @dd.action(label=_("Send e-mail"),
     #            show_in_toolbar=True, show_in_workflow=False,
     #            button_text="✉")  # u"\u2709"
@@ -426,5 +436,5 @@ def setup_memo_commands(sender=None, **kwargs):
 
 from .ui import *
 
-if settings.SITE.has_feature('third_party_authentication'):
+if dd.get_plugin_setting('users', 'third_party_authentication'):
     Me.connect_account = ConnectAccount()
