@@ -1,13 +1,13 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-# python setup.py test -s tests.PackagesTests
+# python setup.py test -s tests.test_packages
 
 import sys
 
 SETUP_INFO = dict(
     name='lino',
-    version='23.3.2',
+    version='24.1.1',
     description="A framework for writing desktop-like sustainably free "
                 "web applications using Django and ExtJS or React",
     license='COPYING',
@@ -29,8 +29,7 @@ install_requires = [
     'django-localflavor',  # lino.modlib.sepa
     'django-click',  # for passwd command
     'openpyxl',  # removed version requirement 'openpyxl==3.0.1',
-    'html2text',
-    'schedule']
+    'html2text']
 
 install_requires.append('Sphinx')  # lino.utils.restify
 install_requires.append('docutils')  # lino.modlib.memo.mixins
@@ -130,6 +129,7 @@ lino.modlib.extjs
 lino.modlib.forms
 lino.modlib.gfks
 lino.modlib.help
+lino.modlib.help.fixtures
 lino.modlib.help.management
 lino.modlib.help.management.commands
 lino.modlib.ipdict
@@ -147,8 +147,6 @@ lino.management.commands
 lino.modlib.odata
 lino.modlib.memo
 lino.modlib.office
-lino.modlib.chat
-lino.modlib.chat.fixtures
 lino.modlib.checkdata
 lino.modlib.checkdata.fixtures
 lino.modlib.checkdata.management
@@ -190,6 +188,7 @@ SETUP_INFO.update(message_extractors={
     'lino': [
         ('**/sandbox/**', 'ignore', None),
         ('**/cache/**', 'ignore', None),
+        ('**.tpl.py', 'ignore', None),
         ('**.py', 'python', None),
         ('**/linoweb.js', 'jinja2', None),
         # ~ ('**.js',                'javascript', None),
@@ -219,7 +218,7 @@ SETUP_INFO.update(include_package_data=True)
 # add_package_data('lino.config', '*.html')
 # add_package_data('lino.config', '*.tmpl')
 # add_package_data('lino.config', 'about/*.tmpl')
-# add_package_data('lino.config', 'makedocs/*.tmpl')
+# add_package_data('lino.config', 'makehelp/*.tmpl')
 # add_package_data('lino.modlib.bootstrap3', 'config/bootstrap3/*.html')
 # add_package_data('lino.modlib.extjs', 'config/extjs/*.html')
 # add_package_data('lino.modlib.extjs', 'config/extjs/*.js')
