@@ -72,7 +72,7 @@ from django.utils import translation
 from django.utils.encoding import force_str
 
 import rstgen
-from atelier.sphinxconf.insert_input import Py2rstDirective
+from rstgen.sphinxconf.insert_input import Py2rstDirective
 
 from lino.api import dd, rt, _
 from lino.core import actors
