@@ -189,7 +189,7 @@ class HelpTextExtractor(object):
                 writeln("}")
 
     def store_content(self, node):
-        # logger.info("20200815 store_content")
+        # logger.info("20231216 store_content %r", node)
         sig = []
         content = []
         for c in node.children:
@@ -209,6 +209,8 @@ class HelpTextExtractor(object):
         # content = [
         #     p.astext() for p in node.traverse(addnodes.desc_content)]
         # content = [p for p in content if not p.startswith("Bases:")]
+        # logger.info("20231216 store_content %s : %s", sig, sig['ids'])
+
         if not content:
             return
         content = '\n'.join(content)
@@ -227,18 +229,26 @@ class HelpTextExtractor(object):
         # else:
         #     logger.info("20200815 store_content sig['names'] is {}".format(sig['names']))
         for name in sig['ids']:
+            # if name == "lino.core.model.Model":
+            #     raise Exception(name)
             self.sig2dict(name, content)
 
     def sig2dict(self, name, value):
-        for e in useless_starts:
-            if name.startswith(e):
-                return
-        for e in useless_endings:
-            if name.endswith(e):
-                return
-        name = simplify_name(name)
+        if not name.startswith("lino.core.model.Model"):
+            for e in useless_starts:
+                if name.startswith(e):
+                    return
+            for e in useless_endings:
+                if name.endswith(e):
+                    return
+            name = simplify_name(name)
         for root, d in self.name2dict.items():
             if name.startswith(root):
+                value = " ".join(value.split())  # replace all whitspace by single space
+                if value.endswith('"'):
+                    value += " "
+                if value.startswith('"'):
+                    value = " " + value
                 d[name] = value
 
 
