@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """:mod:`lino.utils` (the top-level module) contains a few often-used
@@ -44,7 +44,6 @@ function for general use. It has also many subpackages and submodules.
     requests
     restify
     screenshots
-    sendchanges
     sqllog
     ssin
     test
@@ -55,18 +54,21 @@ function for general use. It has also many subpackages and submodules.
 
 """
 
-#~ import logging
-#~ logger = logging.getLogger(__name__)
 from past.utils import old_div
-from future.types import newstr
 import sys
 import datetime
+import logging
+import traceback
 from dateutil.relativedelta import relativedelta
 import re
 from decimal import Decimal
 from collections import OrderedDict
+from urllib.parse import urlencode
 # import locale
 import dateparser
+from io import StringIO
+import contextlib
+from html2text import HTML2Text
 
 # import rstgen
 from etgen.utils import join_elems
@@ -76,6 +78,25 @@ from lino.utils.code import codefiles, codetime
 
 from rstgen.utils import confirm, i2d, i2t
 
+
+def read_exception(excinfo):
+    # TODO: why not use traceback.format_exc(excinfo) intead of this?
+    f = StringIO()
+    traceback.print_exception(*excinfo, file=f)
+    f.seek(0)
+    try:
+        return f.read()
+    finally:
+        f.close()
+
+
+def buildurl(root, *args, **kw):
+    assert root.endswith("/")
+    url = root + "/".join(args)
+    if len(kw):
+        url += "?" + urlencode(kw, True)
+    return url
+
 class AttrDict(dict):
 
     """
@@ -132,6 +153,7 @@ def date_offset(ref, days=0, **offset):
         return ref + datetime.timedelta(**offset)
     return ref
 
+
 def iif(condition, true_value, false_value=None):
     """
     "Inline If" : an ``if`` statement as a function.
@@ -165,8 +187,11 @@ def isiterable(x):
         return False
     return True
 
+
 def is_string(s):
     """Return True if the specified value is a string.
+
+    TODO: remove this.
     """
     # if six.PY2:
     #     return isinstance(s, six.string_types) or isinstance(s, newstr)
@@ -175,44 +200,45 @@ def is_string(s):
 def isidentifier(s):
     """
     Check whether the given string can be used as a Python identifier.
+
+    TODO: remove this.
     """
     # if six.PY2:
     #     return re.match("[_A-Za-z][_a-zA-Z0-9]*$", s)
     return s.isidentifier()
 
 
-def ispure(s):
-    """Returns `True` if the specified string `s` is either None, or
-    contains only ASCII characters, or is a validly encoded unicode
-    string.
+# def ispure(s):
+#     """Returns `True` if the specified string `s` is either None, or
+#     contains only ASCII characters, or is a validly encoded unicode
+#     string.
+#
+#     """
+#     if s is None:
+#         return True
+#     if isinstance(s, str):
+#         return True
+#     if type(s) == bytes:
+#         try:
+#             s.decode('ascii')
+#         except UnicodeDecodeError:
+#             return False
+#         return True
+#     return False
 
-    """
-    if s is None:
-        return True
-    if isinstance(s, (str, newstr)):
-        return True
-    if type(s) == bytes:
-        try:
-            s.decode('ascii')
-        except UnicodeDecodeError:
-            return False
-        return True
-    return False
-
-
-def assert_pure(s):
-    """
-    raise an Exception if the given string is not :func:`ispure`.
-    """
-    #~ assert ispure(s), "%r: not pure" % s
-    if s is None:
-        return
-    if isinstance(s, str):
-        return True
-    try:
-        s.decode('ascii')
-    except UnicodeDecodeError as e:
-        raise Exception("%r is not pure : %s" % (s, e))
+# def assert_pure(s):
+#     """
+#     raise an Exception if the given string is not :func:`ispure`.
+#     """
+#     #~ assert ispure(s), "%r: not pure" % s
+#     if s is None:
+#         return
+#     if isinstance(s, str):
+#         return True
+#     try:
+#         s.decode('ascii')
+#     except UnicodeDecodeError as e:
+#         raise Exception("%r is not pure : %s" % (s, e))
 
 def join_words(*words):
     """
@@ -579,13 +605,18 @@ class SumCollector(object):
         if value is None:
             return
         if k in self._sums:
+            # print("20230614 a", k, "=", self._sums[k], "+", value)
             self._sums[k] += value
         else:
+            # print("20230614 b", k, "=", value)
             self._sums[k] = value
 
     def __getattr__(self, k):
         return self._sums.get(k)
 
+    def __getitem__(self, k):
+        return self._sums.get(k)
+
     def items(self, *args, **kwargs):
         return self._sums.items(*args, **kwargs)
 
@@ -615,38 +646,37 @@ def get_client_ip_address(request):
     return ip or "(unknown)"  # see ticket #2605
 
 
-def DelayedValue(ar, fieldname, obj):
-    return dict(delayed_value_url="values/{}/{}/{}".format(
-            str(ar.actor).replace(".","/"), obj.pk, fieldname))
+class MissingRow:
+    """
+    Represents a :term:`database row` that is expected to exist but doesn't.
 
-# class DelayedValue:
-#     """
-#
-#     Creates an url for the related value and passes it to the frontend for the
-#     value to be fetched later by the frontend.
-#
-#     """
-#
-#     def __init__(self, actor, fieldname, obj):
-#         if fieldname is None:
-#             raise Exception("20210617 {}".format(field))
-#         # a = ar.actor
-#         self.url = "values/{}/{}/{}".format(
-#             str(actor).replace(".","/"), obj.pk, fieldname)
-#         # print(self, self.url)
-#         # self.field = field
-#         # self.obj = obj
-#
-#     def get_url(self):
-#         return self.url
-#
-#     def __repr__(self):
-#         return "DelayedValue({})".format(self.url)
+    Used for example by :class:`lino.core.choicelists.PointingChoice`, or
+    internally for reporting why the master instance for an action request could
+    not be found.
+
+    """
+    def __init__(self, msg):
+        self.message = msg
+
+    def __str__(self):
+        return "MissingRow({})".format(self.message)
+
+    def __repr__(self):
+        return "MissingRow({!r})".format(self.message)
 
 
-def _test():
-    import doctest
-    doctest.testmod()
+@contextlib.contextmanager
+def logging_disabled(level):
+    try:
+        logging.disable(level)
+        yield
+    finally:
+        logging.disable(logging.NOTSET)
 
-if __name__ == "__main__":
-    _test()
+
+def html2text(html, **kwargs):
+    text_maker = HTML2Text()
+    text_maker.unicode_snob = True
+    for k, v in kwargs.items():
+        setattr(text_maker, k, v)
+    return text_maker.handle(html)
