@@ -60,7 +60,7 @@ class Addressable(object):
 
     def has_address(self):
         """
-        Checks whether the address is non empty and returns a boolean value.
+        Returns `True` if the address location is non empty.
         """
         return len(list(self.address_location_lines())) > 0
 
