@@ -23,6 +23,12 @@ GFK_HACK = re.compile(r'^<a href="javascript:Lino\.(\w+\.\w+)\.detail\.run\(.*,\
 
 from django.db import models
 from django.conf import settings
+from django.core.exceptions import BadRequest
+try:
+    from django.contrib.contenttypes.models import ContentType
+except RuntimeError:
+    pass
+    # Happens when the site doesn't use contenttypes. Ignore silently.
 
 # from lino.api import rt
 from lino.core import constants
@@ -354,17 +360,16 @@ class Chooser(FieldChooser):
         # ba = tbl.get_url_action(tbl.default_elem_action_name)
         # 20120202
         if tbl.master_field is not None:
-            from django.contrib.contenttypes.models import ContentType
             rqdata = getrqdata(ar.request)
             if tbl.master is not None:
                 master = tbl.master
             else:
                 mt = rqdata.get(constants.URL_PARAM_MASTER_TYPE)
-                # ContentType = rt.models.contenttypes.ContentType
                 try:
                     master = ContentType.objects.get(pk=mt).model_class()
                 except ContentType.DoesNotExist:
-                    master = None
+                    # master = None
+                    raise BadRequest("Invalid content type {}={}".format(constants.URL_PARAM_MASTER_TYPE, mt))
 
             pk = rqdata.get(constants.URL_PARAM_MASTER_PK, None)
             if pk and master:
