@@ -19,7 +19,7 @@ One possibility might be to write a special Jinja Template class...
 
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 from os.path import join, abspath, dirname, isdir
