@@ -1,75 +1,13 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2016 Rumma & Ko Ltd
+# Copyright 2012-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-# $ python setup.py test -s tests.UtilsTests.test_demonames
-
 """
-Example usage:
-
-The first five Belgians:
-
->>> for i in range(5):
-...     print(LAST_NAMES_BELGIUM.pop())
-Adam
-Adami
-Adriaen
-Adriaensen
-Aelter
-
->>> from lino.utils.demonames import LAST_NAMES_RUSSIA
-
-Next comes a group of five Russians:
-
->>> for i in range(5):
-...     print(LAST_NAMES_RUSSIA.pop())
-Abezgauz
-Aleksandrov
-Altukhov
-Alvang
-Ankundinov
-
-Or here is a mixture of nationalities, for each Belgian comes one foreigner:
-
->>> from lino.utils.demonames import LAST_NAMES_MUSLIM
->>> LAST_NAMES = Cycler(LAST_NAMES_BELGIUM,
-...     LAST_NAMES_RUSSIA, LAST_NAMES_BELGIUM, LAST_NAMES_MUSLIM)
-
->>> for i in range(10):
-...     print(LAST_NAMES.pop())
-Aelters
-Arent
-Aelterman
-Abad
-Aerens
-Arnold
-Aerts
-Abbas
-Aertsens
-Arshan
-
-Sources:
-
-The raw data was originally copied from:
-
-- Belgian last names from http://www.lavoute.org/debuter/Belgique.htm
-- French last names from http://www.nom-famille.com/noms-les-plus-portes-en-france.html
-- Russian last names from http://www.meetmylastname.com/prd/articles/24
-- French first names from
-  http://meilleursprenoms.com/site/LesClassiques/LesClassiques.htm
-- African, Muslim and Russian names from
-  http://www.babynames.org.uk
-  and http://genealogy.familyeducation.com
-  
-- Streets of Liège (STREETS_OF_LIEGE) are from
-  http://fr.wikipedia.org/wiki/Liste_des_rues_de_Li%C3%A8ge
-  
+Generate random Belgian names.
 
+Example usage in :doc:`/topics/utils`.
 """
 
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import re
 STREET_RE = re.compile(r"\*\s*\[\[(.+)\]\]\s*$")
 
@@ -97,7 +35,7 @@ def splitter3(s):
 
 
 LAST_NAMES_BELGIUM = u"""
- 
+
 A
 
 Adam
@@ -128,7 +66,7 @@ Aerens
 
 Aerts
 
-Aertsens 
+Aertsens
 
 Albumazard
 
@@ -164,7 +102,7 @@ Baert
 
 Bartholomeeus
 
-Bastien 
+Bastien
 
 Bastin
 
@@ -220,9 +158,9 @@ Borremans
 
 Borsu
 
-Borsus 
+Borsus
 
-Borsut 
+Borsut
 
 Bosmans
 
@@ -256,7 +194,7 @@ Brug
 
 Bruggesman
 
-Bruynseel 
+Bruynseel
 
 Bruynseels
 
@@ -274,11 +212,11 @@ Buyle
 
 C
 
-Calbert 
+Calbert
 
 Callebaut
 
-Callebert 
+Callebert
 
 Callebout
 
@@ -286,13 +224,13 @@ Camby
 
 Cappelaere
 
-Cappelaire 
+Cappelaire
 
-Cappelier 
+Cappelier
 
-Cappeliez 
+Cappeliez
 
-Cappellier 
+Cappellier
 
 Carbonez
 
@@ -372,9 +310,9 @@ Corringer
 Coryn
 Coudyser
 Couhysder
-Coutijser 
-Coutiser 
-Crab 
+Coutijser
+Coutiser
+Crab
 Crabbe
 Crama
 
@@ -408,15 +346,15 @@ Daems
 
 Dalmans
 
-Damard 
+Damard
 
 Damart
 
 Danis
 
-Dany 
+Dany
 
-Danys 
+Danys
 
 Dapvril
 
@@ -510,7 +448,7 @@ De Muyncke
 
 De Naeyer
 
-De Nayer 
+De Nayer
 
  De Pannemacker
 
@@ -522,7 +460,7 @@ De Pauw
 
 De Pelsemaeker
 
-De Pester 
+De Pester
 
 De Potter
 
@@ -556,7 +494,7 @@ De Smeytere
 
 De Smidt
 
-De Smit 
+De Smit
 
  De Smyter
 
@@ -636,7 +574,7 @@ Dejonghe
 
 Dekale
 
-Dekimpe 
+Dekimpe
 
 Dekoch
 
@@ -646,11 +584,11 @@ Dekyndt
 
 Delacuvellerie
 
-Delafosse 
+Delafosse
 
-Delahaye 
+Delahaye
 
-Delahayes 
+Delahayes
 
 Delbouille
 
@@ -662,11 +600,11 @@ Delflache
 
 Delfosse
 
-Delgat 
+Delgat
 
 Delhaye
 
-Delhoste 
+Delhoste
 
 Delhotte
 
@@ -676,9 +614,9 @@ Delmer
 
 Delobbe
 
-Delobe 
+Delobe
 
-Delobes 
+Delobes
 
 Delplace
 
@@ -718,31 +656,31 @@ Depelsemacker
 
 Depelsemaeker
 
-Depelsenaire 
+Depelsenaire
 
-Depelseneer 
+Depelseneer
 
-Depercenaire 
+Depercenaire
 
-Depester 
+Depester
 
-Depiéreux 
+Depiéreux
 
-Depierreux 
+Depierreux
 
-Depireux 
+Depireux
 
 Depoorter
 
-Depoortere 
+Depoortere
 
-Depooter 
+Depooter
 
-Depootere 
+Depootere
 
-Deporter 
+Deporter
 
-Deportere 
+Deportere
 
 Depoterre
 
@@ -768,7 +706,7 @@ Desmeytere
 
 Desmidt
 
-Desmidts 
+Desmidts
 
 Desmit
 
@@ -780,17 +718,17 @@ Desmyttere
 
  Despineto
 
-Després 
+Després
 
-Despret 
+Despret
 
-Desprets 
+Desprets
 
-Despretz 
+Despretz
 
-Desprey 
+Desprey
 
-Desprez 
+Desprez
 
 Destoute
 
@@ -844,11 +782,11 @@ Dominicus
 
 Dondaine
 
-Dondeine 
+Dondeine
 
-Dondenne 
+Dondenne
 
-Dondeyne 
+Dondeyne
 
 Doolaeg(h)e
 
@@ -976,7 +914,7 @@ Gehucht
 
 Geiregat
 
-Geeregat 
+Geeregat
 
 Gendebien
 
@@ -988,7 +926,7 @@ Gérard
 
 Gerlache
 
-Gerlaxhe 
+Gerlaxhe
 
 Germay
 
@@ -1076,7 +1014,7 @@ Hamers
 
 Hanssens
 
-Hardas 
+Hardas
 
 Hardat
 
@@ -1092,15 +1030,15 @@ Hendriks
 
 Henry
 
-Herbrand 
+Herbrand
 
-Herbrandt 
+Herbrandt
 
-Herbrant 
+Herbrant
 
 Herman
 
-Hermann 
+Hermann
 
 Hermans
 
@@ -1134,9 +1072,9 @@ Hinker
 
 Hinkle
 
-Hoefnagel 
+Hoefnagel
 
-Hoefnagels 
+Hoefnagels
 
 Holemans
 
@@ -1156,9 +1094,9 @@ I
 
 Ickx
 
-Istace 
+Istace
 
-Istasse 
+Istasse
 
 J
 
@@ -1230,17 +1168,17 @@ Kaisin
 
 Keetels
 
-Kenens 
+Kenens
 
-Kenes 
+Kenes
 
-Kenis 
+Kenis
 
-Kennens 
+Kennens
 
-Kennes 
+Kennes
 
-Kennis 
+Kennis
 
 Kesteloot
 
@@ -1250,19 +1188,19 @@ Ketelsmit
 
 Kiecken
 
-Kimpe 
+Kimpe
 
-Kinnen 
+Kinnen
 
-Klein 
+Klein
 
 Kleineman
 
-Kleiner 
+Kleiner
 
 Kleinerman
 
-Kleinman 
+Kleinman
 
 Klerk
 
@@ -1292,19 +1230,19 @@ Labbez
 
 Lacroix
 
-Laenen 
+Laenen
 
-Laenens 
+Laenens
 
-Lafontaine 
+Lafontaine
 
 Lambert
 
 Lambrechts
 
-Lanen 
+Lanen
 
-Lanens 
+Lanens
 
 Langlez
 
@@ -1360,11 +1298,11 @@ Lemounie
 
 Lenaerts
 
-Lénel 
+Lénel
 
 Lénelle
 
-Lennel 
+Lennel
 
 Léonard
 
@@ -1380,9 +1318,9 @@ Lescohy
 
 Lesoil
 
-Lesoile 
+Lesoile
 
-Lesoille 
+Lesoille
 
 Levecq
 
@@ -1416,15 +1354,15 @@ Liétart
 
 Lievens
 
-Lievesoons 
+Lievesoons
 
-Lievevrouw 
+Lievevrouw
 
 Lievrouw
 
 Liévrouw
 
-Lievrow 
+Lievrow
 
 Linglay
 
@@ -1436,11 +1374,11 @@ Lisenborgh
 
 Lisenborgs
 
-Locreille 
+Locreille
 
 Locrel
 
-Locrelle 
+Locrelle
 
 Lode
 
@@ -1464,7 +1402,7 @@ Ludovicus
 
 Lugen
 
-Lugens 
+Lugens
 
 Lust
 
@@ -1476,7 +1414,7 @@ Luyrik
 
 Luyten
 
-Lyphoudt 
+Lyphoudt
 
 Lyphout
 
@@ -1494,9 +1432,9 @@ Mahieu
 
 Maka
 
-Malchamp 
+Malchamp
 
-Malchamps 
+Malchamps
 
 Malmedier
 
@@ -1542,9 +1480,9 @@ Mathy
 
 Matthys
 
-Mauchamp 
+Mauchamp
 
-Mauchamps 
+Mauchamps
 
 Maurichon
 
@@ -1566,7 +1504,7 @@ Meester
 
 Meeus
 
-Melaerts 
+Melaerts
 
 Mellaerts
 
@@ -1586,9 +1524,9 @@ Mertens
 
 Mertes
 
-Merts 
+Merts
 
-Mertz 
+Mertz
 
 Meulemans
 
@@ -1616,7 +1554,7 @@ Mochamps
 
 Moens
 
-Moeyaert 
+Moeyaert
 
 Moiling
 
@@ -1640,7 +1578,7 @@ Moreau
 
 Mouyart
 
-Moyaert 
+Moyaert
 
 Mullenders
 
@@ -1670,7 +1608,7 @@ Neuret
 
 Neurot
 
-Neuts 
+Neuts
 
 Neuven
 
@@ -1690,7 +1628,7 @@ Niklaas
 
 Noël
 
-Nuts 
+Nuts
 
 Nuttin
 
@@ -1774,7 +1712,7 @@ Poyon
 
 Praat
 
-Premereur 
+Premereur
 
 Premmereur
 
@@ -1798,7 +1736,7 @@ Puttemans
 
 Puttemans
 
-Putman 
+Putman
 
 Q
 
@@ -1828,13 +1766,13 @@ Raucent
 
 Rauscent
 
-Rausin 
+Rausin
 
 Raussain
 
 Raussent
 
-Raussin 
+Raussin
 
 Raveydts
 
@@ -1872,7 +1810,7 @@ Rousseau
 
 S
 
-Saintmaux 
+Saintmaux
 
 Saint-Maux
 
@@ -1916,7 +1854,7 @@ Simons
 
 Sinnesaël
 
-Sinnesal 
+Sinnesal
 
 Slagmolder
 
@@ -1948,25 +1886,25 @@ Sprecher
 
 Stas
 
-Stass 
+Stass
 
-Stassaert 
+Stassaert
 
-Stassar 
+Stassar
 
-Stassard 
+Stassard
 
-Stassart 
+Stassart
 
-Stasse 
+Stasse
 
-Stassiaux 
+Stassiaux
 
-Stassin 
+Stassin
 
-Stassinet 
+Stassinet
 
-Statius 
+Statius
 
 Steculorum
 
@@ -2082,7 +2020,7 @@ Van Damme
 
 Van de Loo
 
-Van de Pas 
+Van de Pas
 
 Van de Poel
 
@@ -2122,7 +2060,7 @@ Van der Brug
 
 Van der Gucht
 
-Van der Pas 
+Van der Pas
 
 Van der Slijke
 
@@ -2130,7 +2068,7 @@ Van der Slikke
 
 Van der Slycke
 
-Van der Vleuten 
+Van der Vleuten
 
 Van Doren
 
@@ -2188,7 +2126,7 @@ Van Steerteghen
 
 Van Steirteghem
 
-Van Vleuten 
+Van Vleuten
 
 Vanbattel
 
@@ -2198,7 +2136,7 @@ Vandamme
 
 Vandenberghe
 
-Vandenbossche 
+Vandenbossche
 
 Vandenbussche
 
@@ -2276,17 +2214,17 @@ Verhoeven
 
 Verlinden
 
-Vermeer 
+Vermeer
 
 Vermeersch
 
 Vermeiren
 
-Vermeren 
+Vermeren
 
 Vermeulen
 
-Vermotte 
+Vermotte
 
 Verplaetse
 
@@ -2312,15 +2250,15 @@ Vette
 
 Viatour
 
- Vieutemps 
+ Vieutemps
 
-Vieutems 
+Vieutems
 
 Vieuxtemps
 
-Vilain 
+Vilain
 
-Vincent 
+Vincent
 
 Vinchent
 
@@ -2376,33 +2314,33 @@ W
 
 Wagemans
 
-Wagenmann 
+Wagenmann
 
-Waghon 
+Waghon
 
 Wagon
 
 Walle
 
-Wastiaux 
+Wastiaux
 
-Watrigant 
+Watrigant
 
-Watriquant 
-
-Watteau 
+Watriquant
 
 Watteau
 
-Watteaux 
+Watteau
 
 Watteaux
 
-Wattecamp 
+Watteaux
+
+Wattecamp
 
 Wattecamps
 
-Wattecant 
+Wattecant
 
 Watteel
 
@@ -2410,15 +2348,15 @@ Wattel
 
 Wattelle
 
-Wattiau 
+Wattiau
 
-Wattiaux 
+Wattiaux
 
-Wattieaux 
+Wattieaux
 
 Wauters
 
-Weers 
+Weers
 
 Weerts
 
@@ -2830,7 +2768,7 @@ Cet article dresse une liste (incomplète) des voies ([[voirie]]s et [[Place (vo
 * [[Rue de la Légia]]
 * [[Rue Lemille]]
 * [[Passage Lemonnier]]
-* [[Rue Léon Mignon (Liège)|Rue Léon Mignon]] 
+* [[Rue Léon Mignon (Liège)|Rue Léon Mignon]]
 * [[Rue Léopold]]
 * [[Rue Libotte]]
 * [[Rue de Londres (Liège)|Rue de Londres]]
@@ -2851,7 +2789,7 @@ Cet article dresse une liste (incomplète) des voies ([[voirie]]s et [[Place (vo
 * [[Avenue Maurice Destenay]]
 * [[Rue Méan]]
 * [[Quai sur Meuse]]
-* [[Rue Mississippi]] 
+* [[Rue Mississippi]]
 * [[Rue du Mont Saint-Martin]]
 * [[Rue Montagne Sainte-Walburge]]
 </div>
@@ -4941,13 +4879,7 @@ Weserstraße
 def streets_of_eupen():
     r"""Yield an almost complete list of street names in Eupen.
 
-    >>> for s in list(streets_of_eupen())[:5]:
-    ...     print(s)
-    Aachener Straße
-    Akazienweg
-    Alter Malmedyer Weg
-    Am Bahndamm
-    Am Berg
+    Examples in :doc:`/topics/utils`.
 
     """
     for ln in STREETS_OF_EUPEN.splitlines():
@@ -4959,13 +4891,7 @@ def streets_of_eupen():
 def streets_of_liege():
     """Yield an almost complete list of street names in Liège.
 
-    >>> for s in list(streets_of_liege())[:5]:
-    ...     print(s)
-    Place du 20-Août
-    Rue de l'Abattoir
-    Rue des Abeilles
-    Rue des Acacias
-    Rue de l'Académie
+    Examples in :doc:`/topics/utils`.
 
 
     """
