@@ -137,19 +137,26 @@ class Analyzer(object):
 
         return rstgen.ul(items)
 
-    def show_database_structure(self):
-        """Show a bullet list of all models and their fields."""
+    def show_database_structure(self, sort_fields=False, sort_models=True):
+        """Show a bullet list of all models and their fields.
+
+        Both the list of models and the fields of each model can optionally be
+        sorted alphabetically. The models are sorted by default, the fields not.
+
+        """
         self.analyze()
         items = []
         for model in get_models():
-            names = []
-            # for f, m in model._meta.get_fields_with_model():
-            for f in model._meta.concrete_fields:
-                names.append(f.name)
-            items.append(
-                "{0} : {1}".format(fmn(model), ', '.join(names)))
+            # names = []
+            # for f in model._meta.concrete_fields:
+            #     names.append(f.name)
+            names = [f.name for f in model._meta.concrete_fields]
+            if sort_fields:
+                names = sorted(names)
+            items.append("{0} : {1}".format(fmn(model), ', '.join(names)))
 
-        items = sorted(items)
+        if sort_models:
+            items = sorted(items)
         return rstgen.ul(items)
 
     def show_fields(self, model, field_names=None, languages=None):
@@ -355,7 +362,7 @@ def layout_fields(ba):
     wl = ba.get_window_layout() or ba.action.params_layout
     if wl is None:
         return ''
-    lh = wl.get_layout_handle(settings.SITE.kernel.default_ui)
+    lh = wl.get_layout_handle()
     elems = [str(f.name) for f in lh._data_elems if not isinstance(f, DummyField)]
     return ', '.join(elems)
     # return fill(' '.join(elems), 50)
@@ -413,15 +420,14 @@ def py2rst(self, doctestfmt=False, fmt=None):
     if isinstance(self, actions.Action):
         s = str(self)
         if self.params_layout:
-            lh = self.params_layout.get_layout_handle(
-                settings.SITE.kernel.default_ui)
+            lh = self.params_layout.get_layout_handle()
             s += '\n'
             s += py2rst(lh.main, doctestfmt, fmt)
         return s
 
 
     if isinstance(self, BaseLayout):
-        lh = self.get_layout_handle(settings.SITE.kernel.default_ui)
+        lh = self.get_layout_handle()
         return py2rst(lh.main, doctestfmt, fmt)
 
     if isinstance(self, Wrapper):
