@@ -1,7 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2022 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-# $ doctest lino/utils/format_date.py
 
 """See :doc:`/topics/datetime`.
 """
@@ -25,7 +24,6 @@ def naturaltime(v):
     return hnaturaltime(v + delta)
 
 
-
 def monthname(n):
     """
     Return the monthname for month # n in current language.
@@ -46,7 +44,7 @@ def fdmy(d):
 
 def format_date(d, format='medium'):
     """Return the given date `d` formatted with `Babel's date formatting
-    <http://babel.edgewall.org/wiki/Documentation/dates.html>`_ and
+    <https://babel.pocoo.org/en/latest/dates.html>`_ and
     using Django's current language.
 
     """
@@ -110,3 +108,10 @@ def day_and_weekday(d):
         return "-"
     return defaultfilters.date(d, 'D d.')
     # return d.strftime("%a%d")
+
+
+def ftl(t):
+    # "format time long"
+    return "{} ({})".format(
+        t.strftime(settings.SITE.datetime_format_strftime),
+        naturaltime(t))
