@@ -29,8 +29,7 @@ More about the usage of this module is in :doc:`/topics/formatting`.
 # from future import standard_library
 # standard_library.install_aliases()
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 from io import StringIO
 from lxml import etree
