@@ -4,10 +4,6 @@ http://code.activestate.com/recipes/496882/
 Author: Michael Palmer 13 Jul 2006
 a regex-based JavaScript code compression kludge
 '''
-from __future__ import division
-from __future__ import print_function
-from builtins import range
-from builtins import object
 from past.utils import old_div
 import re
 
