@@ -2,7 +2,7 @@
 # Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-r"""A framework for generating Javascript from Python.
+"""A framework for generating Javascript from Python.
 
 See also :doc:`/specs/jsgen`.
 
@@ -17,11 +17,13 @@ import json
 
 from django.conf import settings
 from django.utils.functional import Promise
+from django.utils.safestring import SafeString
 from django.utils.encoding import force_str
 from django.db.models.fields import NOT_PROVIDED
 
 from etgen import etree
 from lino.utils import IncompleteDate
+from lino.utils import MissingRow
 from lino.utils.quantities import Quantity
 from lino.utils import curry
 # from lino.utils import DelayedValue
@@ -376,7 +378,7 @@ def declare_vars(v):
 
 
 def py2js(v, compact=True):
-    """Note that None values are rendered as ``null`` (not ``undefined``.
+    """Note that None values are rendered as ``null`` (not ``undefined``).
 
     """
     # if isinstance(v, DelayedValue):
@@ -390,16 +392,14 @@ def py2js(v, compact=True):
     # if isinstance(v,LanguageInfo):
         # return v.django_code
 
+    if isinstance(v, SafeString):
+        # print("20231228")
+        return json.dumps(v)
     if isinstance(v, Value):
         return v.as_ext()
-        # v = v.as_ext()
-        # if not isinstance(v, basestring):
-            # raise Exception("20120121b %r is of type %s" % (v,type(v)))
-        # return v
     if isinstance(v, Promise):
         # v = force_str(v)
         return json.dumps(force_str(v.encode('utf8')))
-
     if isinstance(v, types.GeneratorType):
         return "".join([py2js(x, compact=compact) for x in v])
     if etree.iselement(v):
@@ -416,6 +416,8 @@ def py2js(v, compact=True):
         # print 20120114, repr(v)
         # raise Exception("Please call the function yourself")
         return "\n".join([ln for ln in v()])
+    if isinstance(v, MissingRow):
+        raise Exception("Cannot render {}".format(v))
     if isinstance(v, js_code):
         return str(v.s)  # v.s might be a unicode
     if v is None:
@@ -470,7 +472,7 @@ def py2js(v, compact=True):
         return repr(v)
     # return json.encoder.encode_basestring(v)
     # print repr(v)
-    # https://docs.djangoproject.com/en/4.1/topics/serialization/
+    # https://docs.djangoproject.com/en/5.0/topics/serialization/
     # if not isinstance(v, (str,unicode)):
         # raise Exception("20120121 %r is of type %s" % (v,type(v)))
     return json.dumps(v, sort_keys=True,
