@@ -40,8 +40,7 @@ which we include here to make it usable in Python 2.6 too.
 
 """
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 
 # ~ ENCODING = 'latin1' # the encoding used by the mdb file
