@@ -12,7 +12,7 @@ TextFields) in the Django model, one for each
 See :doc:`/dev/mldbc/index`
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 from django.conf import settings
 from django.db import models
