@@ -9,7 +9,7 @@ See :doc:`/dev/mti`.
 See also :class:`lino.mixins.polymorphic`.
 
 """
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 from django.db import models
 from django.db import router
