@@ -20,9 +20,7 @@ State : works for me, but very young and probably full of bugs.
 Usage example in :doc:`/topics/utils`.
 
 """
-import logging
-# ~ logging.basicConfig(level='DEBUG') # uncomment this when debugging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 
