@@ -17,8 +17,8 @@ class Quantity(Decimal):
     def __new__(cls, value=None, context=None):
         if value is NotImplemented:
             return value
-        if isinstance(value, str):
-            value = Decimal(value)
+        # if isinstance(value, str):
+        #     value = Decimal(value)
         self = Decimal.__new__(cls, value, context)
         self._text = str(value)
         return self
@@ -43,8 +43,11 @@ class Quantity(Decimal):
         return self.__class__(Decimal.__add__(self, other, **kwargs))
     __radd__ = __add__
 
-    def __sub__(self, *args, **kw):
-        return self.__class__(Decimal.__sub__(self, *args, **kw))
+    def __sub__(self, other, **kwargs):
+        # print("20230616 __sub__(", self, other, ")")
+        other = convert_from(other, **kwargs)
+        return self.__class__(Decimal.__sub__(self, other, **kwargs))
+    # __rsub__ = __sub__
 
     def __rsub__(self, *args, **kw):
         return self.__class__(Decimal.__rsub__(self, *args, **kw))
@@ -52,12 +55,13 @@ class Quantity(Decimal):
     def __mul__(self, other, **kwargs):
         other = convert_from(other, **kwargs)
         return self.__class__(Decimal.__mul__(self, other, **kwargs))
+    __rmul__ = __mul__
 
-    def __rmul__(self, other, **kwargs):
-        other = convert_from(other, **kwargs)
-        return self.__class__(Decimal.__rmul__(self, other, **kwargs))
-        # return Decimal.__rmul__(self, other, **kwargs)
-        # see Luc's blog 20190410
+    # def __rmul__(self, other, **kwargs):
+    #     other = convert_from(other, **kwargs)
+    #     return self.__class__(Decimal.__rmul__(self, other, **kwargs))
+    #     # return Decimal.__rmul__(self, other, **kwargs)
+    #     # see Luc's blog 20190410
 
     def __truediv__(self, *args, **kw):
         return self.__class__(Decimal.__truediv__(self, *args, **kw))
@@ -65,6 +69,18 @@ class Quantity(Decimal):
     __div__ = __truediv__
     __rdiv__ = __rtruediv__
 
+    def __neg__(self, **kwargs):
+        return self.__class__(Decimal.__neg__(self, **kwargs))
+
+    def __eq__(self, other):
+        if other in (None, '', [], (), {}):
+            return NotImplemented
+        return Decimal(self).__eq__(Decimal(other))
+        # try:
+        #     return Decimal(self).__eq__(Decimal(other))
+        # except Exception:
+        #     raise Exception("20231014 {} {}".format(repr(self), repr(other)))
+
     def deconstruct(self):
         return (self.__module__ + "." + self.__class__.__name__, (self._text,), {})
 
@@ -72,6 +88,7 @@ class Quantity(Decimal):
 class Percentage(Quantity):
 
     def __new__(cls, value="0%", context=None):
+        # print("20230617 Percentage.__new__()")
         if value is NotImplemented:
             return value
         if isinstance(value, str):
@@ -112,19 +129,34 @@ class Duration(Quantity):
             cv = Decimal(hours) + Decimal(minutes) * DEC2HOUR
             text = '%d:%02d' % (hours, minutes)
         else:
-            text = str(value)
+            text = str(value).strip()
             if ':' in text:
+                minus = False
+                if text.startswith("-"):
+                    minus = True
+                    text = text[1:]
                 try:
                     h, m = text.split(':')
                 except ValueError:
                     raise ValueError("Cannot convert %r to Duration" % value)
                 cv = Decimal(h) + Decimal(m) * DEC2HOUR
+                if minus:
+                    cv = -cv
+                    text = "-" + text
             else:
+                # print("20231230", repr(value))
                 cv = Decimal(value)
+                minus = False
+                if cv < 0:
+                    minus = True
+                    cv = -cv
                 hours = int(cv)
                 minutes = ((cv - hours) / DEC2HOUR).to_integral()
                 # minutes = old_div((hours - int(self)), DEC2HOUR)
                 text = '%d:%02d' % (hours, minutes)
+                if minus:
+                    text = "-" + text
+                    cv = -cv
         self = Decimal.__new__(cls, cv, context)
         self._text = text
         return self
@@ -142,16 +174,22 @@ class Duration(Quantity):
         return self.__class__(Decimal.__radd__(self, other, **kwargs))
 
     def __rsub__(self, other, **kwargs):
-        # subtract a Duration from a datetime.datatime
+        # subtract a Duration from a datetime.datetime
         if isinstance(other, datetime.datetime):
             return other - self.as_timedelta()
-        other = convert_from(other, **kwargs)
+        # return self.__rsub__(other, **kwargs)
+        # other = convert_from(other, **kwargs)
         return self.__class__(Decimal.__rsub__(self, other, **kwargs))
 
     def as_timedelta(self):
         h, m = self._text.split(':')
         return datetime.timedelta(seconds=int(h)*60*60 + int(m)*60)
 
+    def __mul__(self, other, **kwargs):
+        other = convert_from(other, **kwargs)
+        return self.__class__(Decimal.__mul__(self, other, **kwargs))
+    __rmul__ = __mul__
+
 
 def convert_from(value, context=None):
     if isinstance(value, str):
@@ -182,7 +220,7 @@ def parse(s):
 
 def parse_decimal(s):
     if '.' in s and ',' in s:
-        raise Exception("Invalid decimal value %r" % s)
+        raise ValueError("Invalid decimal value %r" % s)
     s = s.replace(',', '.')
     return Quantity(s)
 
