@@ -122,7 +122,7 @@ class EmptyTable(Frame):
     hide_navigator = True
     default_list_action_name = 'show'
     # default_elem_action_name = 'show'
-    display_mode_main = None  # for Actor
+    display_mode = None  # for Actor
     build_method = None
 
     @classmethod
