@@ -2,13 +2,8 @@
 # Copyright 2013-2014 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-"""
-"""
-from builtins import str
-from builtins import object
 
-import logging
-logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 
