@@ -8,7 +8,7 @@ cases (not Django test cases, which are defined in
 
 """
 
-import logging ; logger = logging.getLogger(__name__)
+from lino import logger
 
 import os
 import json
@@ -174,7 +174,8 @@ class DemoTestCase(PythonTestCase, CommonTestCase):
             constants.URL_PARAM_FIELD_VALUES: [username, pwd],
             constants.URL_PARAM_ACTION_NAME: 'sign_in'}
         from django.conf import settings
-        url = settings.SITE.site_prefix + "api/about/About/-99998"
+        # url = settings.SITE.site_prefix + "api/about/About/-99998"
+        url = settings.SITE.kernel.editing_front_end.build_plain_url("api/about/About/-99998")
         res = self.client.post(url, data)
         self.assertEqual(res.status_code, 200)
         content = res.content.decode()
